@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 10912 $
- * $Id: advancedcompileroptionsdlg.cpp 10912 2016-09-25 16:10:13Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/compilergcc/advancedcompileroptionsdlg.cpp $
+ * $Revision: 13355 $
+ * $Id: advancedcompileroptionsdlg.cpp 13355 2023-09-17 13:52:36Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/compilergcc/advancedcompileroptionsdlg.cpp $
  */
 
 #include "sdk.h"
@@ -33,22 +33,22 @@
 inline wxString ControlCharsToString(const wxString& src)
 {
     wxString ret = src;
-    ret.Replace(_T("\t"), _T("\\t"));
-    ret.Replace(_T("\n"), _T("\\n"));
-    ret.Replace(_T("\r"), _T("\\r"));
-    ret.Replace(_T("\a"), _T("\\a"));
-    ret.Replace(_T("\b"), _T("\\b"));
+    ret.Replace("\t", "\\t");
+    ret.Replace("\n", "\\n");
+    ret.Replace("\r", "\\r");
+    ret.Replace("\a", "\\a");
+    ret.Replace("\b", "\\b");
     return ret;
 }
 
 wxString StringToControlChars(const wxString& src)
 {
     wxString ret = src;
-    ret.Replace(_T("\\t"), _T("\t"));
-    ret.Replace(_T("\\n"), _T("\n"));
-    ret.Replace(_T("\\r"), _T("\r"));
-    ret.Replace(_T("\\a"), _T("\a"));
-    ret.Replace(_T("\\b"), _T("\b"));
+    ret.Replace("\\t", "\t");
+    ret.Replace("\\n", "\n");
+    ret.Replace("\\r", "\r");
+    ret.Replace("\\a", "\a");
+    ret.Replace("\\b", "\b");
     return ret;
 }
 
@@ -72,7 +72,7 @@ AdvancedCompilerOptionsDlg::AdvancedCompilerOptionsDlg(wxWindow* parent, const w
     m_LastExtIndex(-1)
 {
     //ctor
-    wxXmlResource::Get()->LoadObject(this, parent, _T("dlgAdvancedCompilerOptions"),_T("wxScrollingDialog"));
+    wxXmlResource::Get()->LoadObject(this, parent, "dlgAdvancedCompilerOptions", "wxScrollingDialog");
     XRCCTRL(*this, "wxID_OK", wxButton)->SetDefault();
     ReadCompilerOptions();
     m_bDirty = false;
@@ -98,8 +98,9 @@ void AdvancedCompilerOptionsDlg::ReadCompilerOptions()
         m_Commands[i] = compiler->GetCommandToolsVector((CommandType)i);
         lst->Append(Compiler::CommandTypeDescriptions[i]);
     }
+
     lst->SetSelection(0);
-    DisplayCommand(0,0);
+    DisplayCommand(0, 0);
     ReadExtensions(0);
 
     // switches
@@ -130,7 +131,7 @@ void AdvancedCompilerOptionsDlg::ReadCompilerOptions()
     XRCCTRL(*this, "chkUse83Paths",           wxCheckBox)->SetValue(switches.Use83Paths);
 
     m_Regexes = compiler->GetRegExArray();
-    m_SelectedRegex = m_Regexes.size() > 0 ? 0 : -1;
+    m_SelectedRegex = (m_Regexes.size() > 0) ? 0 : -1;
     FillRegexes();
 }
 
@@ -166,17 +167,17 @@ void AdvancedCompilerOptionsDlg::WriteCompilerOptions()
     switches.UseFullSourcePaths      = XRCCTRL(*this, "chkUseFullSourcePaths",   wxCheckBox)->GetValue();
     {
         wxString value               = XRCCTRL(*this, "txtIncludeDirSeparator",  wxTextCtrl)->GetValue();
-        if (!value.IsEmpty())
+        if (!value.empty())
             switches.includeDirSeparator = value[0];
     }
     {
         wxString value               = XRCCTRL(*this, "txtLibDirSeparator",      wxTextCtrl)->GetValue();
-        if (!value.IsEmpty())
+        if (!value.empty())
             switches.libDirSeparator = value[0];
     }
     {
         wxString value               = XRCCTRL(*this, "txtObjectSeparator",      wxTextCtrl)->GetValue();
-        if (!value.IsEmpty())
+        if (!value.empty())
             switches.objectSeparator = value[0];
     }
     switches.statusSuccess           = XRCCTRL(*this, "spnStatusSuccess",        wxSpinCtrl)->GetValue();
@@ -187,26 +188,32 @@ void AdvancedCompilerOptionsDlg::WriteCompilerOptions()
 
 void AdvancedCompilerOptionsDlg::ReadExtensions(int nr)
 {
-    wxChoice* cmb = XRCCTRL(*this, "lstExt", wxChoice);
-    cmb->Clear();
+    wxChoice* cho = XRCCTRL(*this, "lstExt", wxChoice);
+    cho->Clear();
     for (size_t i = 0; i < m_Commands[nr].size(); ++i)
-        cmb->Append(GetStringFromArray(m_Commands[nr][i].extensions, DEFAULT_ARRAY_SEP, false));
-    cmb->SetSelection(cmb->FindString(wxEmptyString));
+        cho->Append(GetStringFromArray(m_Commands[nr][i].extensions, DEFAULT_ARRAY_SEP, false));
+
+    cho->SetSelection(cho->FindString(wxEmptyString));
 }
 
 CompilerTool* AdvancedCompilerOptionsDlg::GetCompilerTool(int cmd, int ext)
 {
-    const wxChoice* cmb = XRCCTRL(*this, "lstExt", wxChoice);
+    wxChoice* cho = XRCCTRL(*this, "lstExt", wxChoice);
     for (size_t i = 0; i < m_Commands[cmd].size(); ++i)
     {
-        if (cmb->GetString(ext).IsEmpty() && m_Commands[cmd][i].extensions.GetCount() == 0)
+        wxString extension;
+        if (ext < int(cho->GetCount()))
+            extension = cho->GetString(ext);
+
+        if (extension.empty() && m_Commands[cmd][i].extensions.GetCount() == 0)
             return &m_Commands[cmd][i];
 
-        int selExt = m_Commands[cmd][i].extensions.Index(cmb->GetString(ext));
+        const int selExt = m_Commands[cmd][i].extensions.Index(extension);
         if (selExt != -1)
             return &m_Commands[cmd][i];
     }
-    return 0;
+
+    return nullptr;
 }
 
 void AdvancedCompilerOptionsDlg::DisplayCommand(int cmd, int ext)
@@ -216,13 +223,14 @@ void AdvancedCompilerOptionsDlg::DisplayCommand(int cmd, int ext)
     if (CompilerTool* tool = GetCompilerTool(cmd,ext))
     {
         text->SetValue(tool->command);
-        gen->SetValue(GetStringFromArray(tool->generatedFiles, _T("\n"), false));
+        gen->SetValue(GetStringFromArray(tool->generatedFiles, '\n', false));
     }
     else
     {
         text->Clear();
         gen->Clear();
     }
+
     m_LastCmdIndex = cmd;
     m_LastExtIndex = ext;
 }
@@ -238,15 +246,17 @@ void AdvancedCompilerOptionsDlg::SaveCommands(int cmd, int ext)
 {
     if (cmd == -1 || ext == -1)
         return;
+
     if (CompilerTool* tool = GetCompilerTool(cmd, ext))
     {
         wxTextCtrl* text = XRCCTRL(*this, "txtCommand",   wxTextCtrl);
         wxTextCtrl* gen  = XRCCTRL(*this, "txtGenerated", wxTextCtrl);
         if (text->GetValue() != tool->command) // last command was changed; save it
             tool->command = text->GetValue();
-        wxString gens = GetStringFromArray(tool->generatedFiles, _T("\n"), false);
+
+        const wxString gens(GetStringFromArray(tool->generatedFiles, '\n', false));
         if (gen->GetValue() != gens) // last genfiles are changed; save it
-            tool->generatedFiles = GetArrayFromString(gen->GetValue(), _T("\n"));
+            tool->generatedFiles = GetArrayFromString(gen->GetValue(), '\n');
     }
 }
 
@@ -260,6 +270,7 @@ void AdvancedCompilerOptionsDlg::FillRegexes()
         RegExStruct& rs = m_Regexes[i];
         list->Append(rs.desc);
     }
+
     list->SetSelection(m_SelectedRegex);
     FillRegexDetails(m_SelectedRegex);
 }
@@ -268,9 +279,9 @@ void AdvancedCompilerOptionsDlg::FillRegexDetails(int index)
 {
     if (index == -1)
     {
-        XRCCTRL(*this, "txtRegexDesc",     wxTextCtrl)->SetValue(_T(""));
+        XRCCTRL(*this, "txtRegexDesc",     wxTextCtrl)->SetValue(wxString());
         XRCCTRL(*this, "cmbRegexType",     wxComboBox)->SetSelection(-1);
-        XRCCTRL(*this, "txtRegex",         wxTextCtrl)->SetValue(_T(""));
+        XRCCTRL(*this, "txtRegex",         wxTextCtrl)->SetValue(wxString());
         XRCCTRL(*this, "spnRegexMsg1",     wxSpinCtrl)->SetValue(0);
         XRCCTRL(*this, "spnRegexMsg2",     wxSpinCtrl)->SetValue(0);
         XRCCTRL(*this, "spnRegexMsg3",     wxSpinCtrl)->SetValue(0);
@@ -309,53 +320,54 @@ void AdvancedCompilerOptionsDlg::SaveRegexDetails(int index)
 void AdvancedCompilerOptionsDlg::OnCommandsChange(wxCommandEvent& WXUNUSED(event))
 {
     CheckForChanges();
-    int cmd = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
+    const int cmd = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
     ReadExtensions(cmd); // can change the extension cmb list !!!!!!!!!!!!!!!
-    int ext = XRCCTRL(*this, "lstExt",      wxChoice)->GetSelection();
+    const int ext = XRCCTRL(*this, "lstExt",      wxChoice)->GetSelection();
     DisplayCommand(cmd, ext);
 }
 
 void AdvancedCompilerOptionsDlg::OnExtChange(wxCommandEvent& WXUNUSED(event))
 {
     CheckForChanges();
-    int cmd = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
-    int ext = XRCCTRL(*this, "lstExt",      wxChoice)->GetSelection();
+    const int cmd = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
+    const int ext = XRCCTRL(*this, "lstExt",      wxChoice)->GetSelection();
     DisplayCommand(cmd, ext);
 }
 
 void AdvancedCompilerOptionsDlg::OnAddExt(wxCommandEvent& WXUNUSED(event))
 {
-    wxString ext = cbGetTextFromUser(_("Please enter a semi-colon separated list of extensions, without the leading dot:"), _("New extension"));
+    wxString ext = cbGetTextFromUser(_("Please enter a semi-colon separated list of extensions, without the leading dot:"),
+                                     _("New extension"), wxString(), this);
     ext.Trim(false);
     ext.Trim(true);
-    if (!ext.IsEmpty())
+    if (!ext.empty())
     {
-        int nr = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
-        CompilerTool* ptool = GetCompilerTool(nr,0);
+        const int nr = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
+        CompilerTool* ptool = GetCompilerTool(nr, 0);
         CompilerTool tool(ptool ? ptool->command : wxString(), ext);
         m_Commands[nr].push_back(tool);
         ReadExtensions(nr);
-        wxChoice* cmb = XRCCTRL(*this, "lstExt", wxChoice);
-        cmb->SetStringSelection(ext);
-        DisplayCommand(nr,cmb->GetSelection());
+        wxChoice* cho = XRCCTRL(*this, "lstExt", wxChoice);
+        cho->SetStringSelection(ext);
+        DisplayCommand(nr, cho->GetSelection());
     }
 }
 
 void AdvancedCompilerOptionsDlg::OnDelExt(wxCommandEvent& WXUNUSED(event))
 {
-    if (cbMessageBox(_("Are you sure you want to remove this extension set from the list?"), _T("Confirmation"), wxYES_NO, this) == wxID_YES)
+    if (cbMessageBox(_("Are you sure you want to remove this extension set from the list?"), _("Confirmation"), wxYES_NO, this) == wxID_YES)
     {
-        int nr = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
-        wxChoice* cmb = XRCCTRL(*this, "lstExt", wxChoice);
-        wxString extS = cmb->GetStringSelection();
-        if (!extS.IsEmpty())
+        const int nr = XRCCTRL(*this, "lstCommands", wxChoice)->GetSelection();
+        wxChoice* cho = XRCCTRL(*this, "lstExt", wxChoice);
+        const wxString extS(cho->GetStringSelection());
+        if (!extS.empty())
         {
-            int ext = cmb->GetSelection();
+            const int ext = cho->GetSelection();
             m_Commands[nr].erase(m_Commands[nr].begin() + ext);
             ReadExtensions(nr);
-            cmb->SetSelection(0);
+            cho->SetSelection(0);
             m_LastExtIndex = -1;
-            DisplayCommand(nr,0);
+            DisplayCommand(nr, 0);
         }
         else
             cbMessageBox(_("Can't remove default commands!"), _("Error"), wxICON_ERROR, this);
@@ -383,7 +395,7 @@ void AdvancedCompilerOptionsDlg::OnRegexChange(wxCommandEvent& WXUNUSED(event))
 void AdvancedCompilerOptionsDlg::OnRegexAdd(wxCommandEvent& WXUNUSED(event))
 {
     SaveRegexDetails(m_SelectedRegex);
-    m_Regexes.push_back(RegExStruct(_("New regular expression"), cltError, _T(""), 0));
+    m_Regexes.push_back(RegExStruct(_("New regular expression"), cltError, wxString(), 0));
     m_SelectedRegex = m_Regexes.size() - 1;
     FillRegexes();
 }
@@ -395,6 +407,7 @@ void AdvancedCompilerOptionsDlg::OnRegexDelete(wxCommandEvent& WXUNUSED(event))
         m_Regexes.erase((m_Regexes.begin() + m_SelectedRegex));
         if (m_SelectedRegex >= (int)m_Regexes.size())
             --m_SelectedRegex;
+
         FillRegexes();
     }
 }
@@ -410,10 +423,12 @@ void AdvancedCompilerOptionsDlg::OnRegexDefaults(wxCommandEvent& WXUNUSED(event)
         Compiler* compiler = CompilerFactory::GetCompiler(m_CompilerId);
         if (!compiler)
             return;
+
         compiler->LoadDefaultRegExArray(true);
         m_Regexes = compiler->GetRegExArray();
         while (m_SelectedRegex >= (int)m_Regexes.size())
             --m_SelectedRegex;
+
         FillRegexes();
     }
 }
@@ -448,8 +463,9 @@ void AdvancedCompilerOptionsDlg::OnRegexTest(wxCommandEvent& WXUNUSED(event))
 {
     if (m_SelectedRegex == -1)
         return;
-    wxString text = XRCCTRL(*this, "txtRegexTest", wxTextCtrl)->GetValue();
-    if (text.IsEmpty())
+
+    const wxString text(XRCCTRL(*this, "txtRegexTest", wxTextCtrl)->GetValue());
+    if (text.empty())
     {
         cbMessageBox(_("Please enter a compiler line in the \"Compiler output\" text box..."), _("Error"), wxICON_ERROR, this);
         return;
@@ -465,7 +481,8 @@ void AdvancedCompilerOptionsDlg::OnRegexTest(wxCommandEvent& WXUNUSED(event))
 
     // test-run
     compiler->SetRegExArray(m_Regexes);
-    CompilerLineType clt = compiler->CheckForWarningsAndErrors(text);
+    long regex_id; wxString regex_desc;
+    CompilerLineType clt = compiler->CheckForWarningsAndErrors(text, regex_id, regex_desc);
 
     // restore regexes
     compiler->SetRegExArray(regex_copy);
@@ -476,13 +493,15 @@ void AdvancedCompilerOptionsDlg::OnRegexTest(wxCommandEvent& WXUNUSED(event))
                  "Type: %s message\n"
                  "Filename: %s\n"
                  "Line number: %s\n"
-                 "Message: %s"),
+                 "Message: %s\n\n"
+                 "Matching regex-id: %ld ('%s')"),
                     clt == cltNormal ? _("Normal")
                  : (clt == cltInfo   ? _("Info")
                  : (clt == cltError  ? _("Error") : _("Warning") ) ),
-                compiler->GetLastErrorFilename().wx_str(),
-                compiler->GetLastErrorLine().wx_str(),
-                compiler->GetLastError().wx_str()
+                compiler->GetLastErrorFilename(),
+                compiler->GetLastErrorLine(),
+                compiler->GetLastError(),
+                regex_id, regex_desc
               );
 
     cbMessageBox(msg, _("Test results"), wxICON_INFORMATION, this);
@@ -504,5 +523,6 @@ void AdvancedCompilerOptionsDlg::EndModal(int retCode)
         if (compiler)
             compiler->SetRegExArray(m_Regexes);
     }
+
     wxScrollingDialog::EndModal(retCode);
 }
