@@ -49,12 +49,14 @@ BrowseTrackerConfPanel::BrowseTrackerConfPanel(BrowseTracker& browseTrackerPlugi
 	m_pConfigPanel->Cfg_BrowseMarksEnabled->Connect( wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler( BrowseTrackerConfPanel::OnEnableBrowseMarks ), NULL, this );
 	m_pConfigPanel->Cfg_WrapJumpEntries->Connect( wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler( BrowseTrackerConfPanel::OnWrapJumpEntries ), NULL, this );
 	m_pConfigPanel->Cfg_ShowToolbar->Connect( wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler( BrowseTrackerConfPanel::OnShowToolbar ), NULL, this );
+	m_pConfigPanel->Cfg_ActivatePrevEd->Connect( wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler( BrowseTrackerConfPanel::OnActivatePrevEd ), NULL, this ); //2020/06/15
+	m_pConfigPanel->Cfg_JumpTrackerSpinCtrl->Connect( wxEVT_SPINCTRL, wxSpinEventHandler( BrowseTrackerConfPanel::OnJumpTrackerSpinCtrl ), NULL, this );
 	m_pConfigPanel->Cfg_ToggleKey->Connect( wxEVT_COMMAND_RADIOBOX_SELECTED, wxCommandEventHandler( BrowseTrackerConfPanel::OnToggleBrowseMarkKey ), NULL, this );
 	m_pConfigPanel->Cfg_ClearAllKey->Connect( wxEVT_COMMAND_RADIOBOX_SELECTED, wxCommandEventHandler( BrowseTrackerConfPanel::OnClearAllBrowseMarksKey ), NULL, this );
 
     // FIXME (ph#): Something fishy here. On the first use of View/BrowseTracker/Settings
     // the BrowseMark is not set to the BookMark style when selected.
-    // It does work when the Editor/Config BrowseTracker settings is used
+    // It does work when the Editor/Config BrowseTracker settings is used.
     // save some old data for later comparison
     m_BrowseTrackerPlugin.m_OldUserMarksStyle = m_BrowseTrackerPlugin.m_UserMarksStyle;
     m_BrowseTrackerPlugin.m_OldBrowseMarksEnabled = m_BrowseTrackerPlugin.m_BrowseMarksEnabled;
@@ -85,6 +87,10 @@ void BrowseTrackerConfPanel::OnApply()
     m_BrowseTrackerPlugin.m_ConfigShowToolbar   = m_pConfigPanel->Cfg_ShowToolbar->GetValue();
     m_BrowseTrackerPlugin.ShowBrowseTrackerToolBar(m_BrowseTrackerPlugin.m_ConfigShowToolbar);
 
+    m_BrowseTrackerPlugin.m_CfgActivatePrevEd   = m_pConfigPanel->Cfg_ActivatePrevEd->GetValue(); //2020/06/15
+
+    m_BrowseTrackerPlugin.m_CfgJumpViewRowCount = m_pConfigPanel->Cfg_JumpTrackerSpinCtrl->GetValue();
+
     // write user options to config file
 	m_BrowseTrackerPlugin.SaveUserOptions( m_BrowseTrackerPlugin.GetBrowseTrackerCfgFilename() );
 	// call validation/update routine
@@ -95,8 +101,6 @@ void BrowseTrackerConfPanel::GetUserOptions(wxString configFullPath)
 // ----------------------------------------------------------------------------
 {
     // Read user options from storage file
-    wxString m_ConfigFullPath = configFullPath;
-
     m_BrowseTrackerPlugin.ReadUserOptions( configFullPath );
 
     #if defined(__WXMSW__)
@@ -111,7 +115,10 @@ void BrowseTrackerConfPanel::GetUserOptions(wxString configFullPath)
 	m_pConfigPanel->Cfg_LeftMouseDelay->SetValue( m_BrowseTrackerPlugin.m_LeftMouseDelay ) ;
 	m_pConfigPanel->Cfg_ClearAllKey->SetSelection( m_BrowseTrackerPlugin.m_ClearAllKey ) ;
 
-    //-m_pConfigPanel->Cfg_ShowToolbar->SetValue(m_BrowseTrackerPlugin.IsViewToolbarEnabled());
+    m_pConfigPanel->Cfg_ActivatePrevEd->SetValue(m_BrowseTrackerPlugin.m_CfgActivatePrevEd); //2020/06/15
+    m_pConfigPanel->Cfg_JumpTrackerSpinCtrl->SetValue(m_BrowseTrackerPlugin.m_CfgJumpViewRowCount);
+
+//-m_pConfigPanel->Cfg_ShowToolbar->SetValue(m_BrowseTrackerPlugin.IsViewToolbarEnabled());
     m_pConfigPanel->Cfg_ShowToolbar->SetValue(m_BrowseTrackerPlugin.m_ConfigShowToolbar);
 
 }//Init
@@ -156,16 +163,40 @@ void BrowseTrackerConfPanel::OnWrapJumpEntries( wxCommandEvent& event )
     // Enable Jump entry wraps if "Wrap Jum0 Entries" is checked
     if ( not m_pConfigPanel->Cfg_WrapJumpEntries->IsChecked() )
     {
-        m_pConfigPanel->Cfg_WrapJumpEntries->Enable(false);
+        //-?m_pConfigPanel->Cfg_WrapJumpEntries->Enable(false); //dont disable 2020/12/22
     }
 
     if ( m_pConfigPanel->Cfg_WrapJumpEntries->IsChecked() )
     {
-        m_pConfigPanel->Cfg_WrapJumpEntries->Enable(true);
+        //_m_pConfigPanel->Cfg_WrapJumpEntries->Enable(true);   //dont disable 2020/12/22
     }
     event.Skip();
 }
 // ----------------------------------------------------------------------------
+void BrowseTrackerConfPanel::OnActivatePrevEd( wxCommandEvent& event ) //2020/12/22
+// ----------------------------------------------------------------------------
+{
+    // Enable switching to previous editor when current closed
+    if ( not m_pConfigPanel->Cfg_ActivatePrevEd->IsChecked() )
+    {
+       //- m_pConfigPanel->Cfg_ActivatePrevEd->Enable(false); dont do this
+    }
+
+    if ( m_pConfigPanel->Cfg_ActivatePrevEd->IsChecked() )
+    {
+        //-m_pConfigPanel->Cfg_ActivatePrevEd->Enable(true); dont do this
+    }
+    event.Skip();
+}
+// ----------------------------------------------------------------------------
+void BrowseTrackerConfPanel::OnJumpTrackerSpinCtrl( wxSpinEvent& event )
+// ----------------------------------------------------------------------------
+{
+
+    //int debugLook = m_pConfigPanel->Cfg_JumpTrackerSpinCtrl->GetValue();
+
+}
+// ----------------------------------------------------------------------------
 void BrowseTrackerConfPanel::OnShowToolbar( wxCommandEvent& event )
 // ----------------------------------------------------------------------------
 {
