@@ -24,6 +24,7 @@
 #define CONFIGPANEL_H
 
 //(*Headers(ConfigPanel)
+#include <cbstyledtextctrl.h>
 #include <wx/button.h>
 #include <wx/checkbox.h>
 #include <wx/choice.h>
@@ -431,63 +432,63 @@ class ConfigPanel: public cbConfigurationPanel
     protected:
 
         //(*Identifiers(ConfigPanel)
-        static const long ID_RADIOBOX_BLOCKCOMMENTS;
-        static const long ID_TEXTCTRL_BLOCKCOMMENT;
-        static const long ID_RADIOBOX_LINECOMMENTS;
-        static const long ID_TEXTCTRL_LINECOMMENT;
-        static const long ID_PANEL2;
-        static const long ID_TEXTCTRL_PROJECTNUMBER;
-        static const long ID_CHECKBOX_USEAUTOVERSION;
-        static const long ID_TEXTCTRLOUTPUT_DIRECTORY;
-        static const long ID_STATICTEXT5;
-        static const long ID_CHOICE_OUTPUT_LANGUAGE;
-        static const long ID_CHECKBOX_EXTRACT_ALL;
-        static const long ID_CHECKBOX_EXTRACTPRIVATE;
-        static const long ID_CHECKBOX_EXTRACTSTATIC;
-        static const long ID_CHECKBOX_WARNINGS;
-        static const long ID_CHECKBOX_WARN_IF_DOC_ERROR;
-        static const long ID_CHECKBOX_WARN_IF_UNDOCUMENTED;
-        static const long ID_CHECKBOX_WARN_NO_PARAMDOC;
-        static const long ID_CHECKBOX_ALPHABETICAL_INDEX;
-        static const long ID_PANEL3;
-        static const long ID_CHECKBOX_GENERATE_HTML;
-        static const long ID_CHECKBOX_GENERATE_HTMLHELP;
-        static const long ID_CHECKBOX_GENERATE_CHI;
-        static const long ID_CHECKBOX_BINARY_TOC;
-        static const long ID_CHECKBOX_GENERATE_LATEX;
-        static const long ID_CHECKBOX_GENERATE_RTF;
-        static const long ID_CHECKBOX_GENERATE_MAN;
-        static const long ID_CHECKBOX_GENERATE_XML;
-        static const long ID_CHECKBOX_GENERATE_AUTOGEN_DEF;
-        static const long ID_CHECKBOX_GENERATE_PERLMOD;
-        static const long ID_CHECKBOX_ENABLE_PREPROCESSING;
-        static const long ID_CHECKBOX_CLASS_DIAGRAMS;
-        static const long ID_CHECKBOX_HAVE_DOT;
-        static const long ID_PANEL4;
-        static const long ID_STATICTEXT2;
-        static const long ID_TEXTCTRL_PATHDOXYGEN;
-        static const long ID_BUTTON_BROWSEDOXYGEN;
-        static const long ID_STATICTEXT4;
-        static const long ID_TEXTCTRL_PATHDOXYWIZARD;
-        static const long ID_BUTTON_BROWSEDOXYWIZARD;
-        static const long ID_STATICTEXT3;
-        static const long ID_TEXTCTRL_PATHHHC;
-        static const long ID_BUTTON_BROWSEHHC;
-        static const long ID_STATICTEXT6;
-        static const long ID_TEXTCTRL_PATHDOT;
-        static const long ID_BUTTON_BROWSEDOT;
-        static const long ID_STATICTEXT7;
-        static const long ID_TEXTCTRL_PATHCHMVIEWER;
-        static const long ID_BUTTON_BROWSECHMVIEWER;
-        static const long ID_CHECKBOX_OVERWRITEDOXYFILE;
-        static const long ID_CHECKBOX_PROMPTB4OVERWRITING;
-        static const long ID_CHECKBOX_USEATINTAGS;
-        static const long ID_CHECKBOX_LOADTEMPLATE;
-        static const long ID_CHECKBOX_USEINTERNALVIEWER;
-        static const long ID_CHECKBOX_RUNHTML;
-        static const long ID_CHECKBOX_RUNCHM;
-        static const long ID_PANEL1;
-        static const long ID_NOTEBOOK_PREFS;
+        static const wxWindowID ID_RADIOBOX_BLOCKCOMMENTS;
+        static const wxWindowID ID_TEXTCTRL_BLOCKCOMMENT;
+        static const wxWindowID ID_RADIOBOX_LINECOMMENTS;
+        static const wxWindowID ID_TEXTCTRL_LINECOMMENT;
+        static const wxWindowID ID_PANEL2;
+        static const wxWindowID ID_TEXTCTRL_PROJECTNUMBER;
+        static const wxWindowID ID_CHECKBOX_USEAUTOVERSION;
+        static const wxWindowID ID_TEXTCTRLOUTPUT_DIRECTORY;
+        static const wxWindowID ID_STATICTEXT5;
+        static const wxWindowID ID_CHOICE_OUTPUT_LANGUAGE;
+        static const wxWindowID ID_CHECKBOX_EXTRACT_ALL;
+        static const wxWindowID ID_CHECKBOX_EXTRACTPRIVATE;
+        static const wxWindowID ID_CHECKBOX_EXTRACTSTATIC;
+        static const wxWindowID ID_CHECKBOX_WARNINGS;
+        static const wxWindowID ID_CHECKBOX_WARN_IF_DOC_ERROR;
+        static const wxWindowID ID_CHECKBOX_WARN_IF_UNDOCUMENTED;
+        static const wxWindowID ID_CHECKBOX_WARN_NO_PARAMDOC;
+        static const wxWindowID ID_CHECKBOX_ALPHABETICAL_INDEX;
+        static const wxWindowID ID_PANEL3;
+        static const wxWindowID ID_CHECKBOX_GENERATE_HTML;
+        static const wxWindowID ID_CHECKBOX_GENERATE_HTMLHELP;
+        static const wxWindowID ID_CHECKBOX_GENERATE_CHI;
+        static const wxWindowID ID_CHECKBOX_BINARY_TOC;
+        static const wxWindowID ID_CHECKBOX_GENERATE_LATEX;
+        static const wxWindowID ID_CHECKBOX_GENERATE_RTF;
+        static const wxWindowID ID_CHECKBOX_GENERATE_MAN;
+        static const wxWindowID ID_CHECKBOX_GENERATE_XML;
+        static const wxWindowID ID_CHECKBOX_GENERATE_AUTOGEN_DEF;
+        static const wxWindowID ID_CHECKBOX_GENERATE_PERLMOD;
+        static const wxWindowID ID_CHECKBOX_ENABLE_PREPROCESSING;
+        static const wxWindowID ID_CHECKBOX_CLASS_DIAGRAMS;
+        static const wxWindowID ID_CHECKBOX_HAVE_DOT;
+        static const wxWindowID ID_PANEL4;
+        static const wxWindowID ID_STATICTEXT2;
+        static const wxWindowID ID_TEXTCTRL_PATHDOXYGEN;
+        static const wxWindowID ID_BUTTON_BROWSEDOXYGEN;
+        static const wxWindowID ID_STATICTEXT4;
+        static const wxWindowID ID_TEXTCTRL_PATHDOXYWIZARD;
+        static const wxWindowID ID_BUTTON_BROWSEDOXYWIZARD;
+        static const wxWindowID ID_STATICTEXT3;
+        static const wxWindowID ID_TEXTCTRL_PATHHHC;
+        static const wxWindowID ID_BUTTON_BROWSEHHC;
+        static const wxWindowID ID_STATICTEXT6;
+        static const wxWindowID ID_TEXTCTRL_PATHDOT;
+        static const wxWindowID ID_BUTTON_BROWSEDOT;
+        static const wxWindowID ID_STATICTEXT7;
+        static const wxWindowID ID_TEXTCTRL_PATHCHMVIEWER;
+        static const wxWindowID ID_BUTTON_BROWSECHMVIEWER;
+        static const wxWindowID ID_CHECKBOX_OVERWRITEDOXYFILE;
+        static const wxWindowID ID_CHECKBOX_PROMPTB4OVERWRITING;
+        static const wxWindowID ID_CHECKBOX_USEATINTAGS;
+        static const wxWindowID ID_CHECKBOX_LOADTEMPLATE;
+        static const wxWindowID ID_CHECKBOX_USEINTERNALVIEWER;
+        static const wxWindowID ID_CHECKBOX_RUNHTML;
+        static const wxWindowID ID_CHECKBOX_RUNCHM;
+        static const wxWindowID ID_PANEL1;
+        static const wxWindowID ID_NOTEBOOK_PREFS;
         //*)
 
     private:
