@@ -2,6 +2,7 @@
 #include "makefiledlg.h"
 
 #include <sdk.h>
+#include "configmanager.h"
 #ifndef CB_PRECOMP
     #include <wx/filedlg.h>
 #endif
@@ -12,9 +13,9 @@
 //*)
 
 //(*IdInit(MakefileDlg)
-const long MakefileDlg::ID_STATICTEXT2 = wxNewId();
-const long MakefileDlg::ID_TEXTCTRL1 = wxNewId();
-const long MakefileDlg::ID_BUTTON1 = wxNewId();
+const wxWindowID MakefileDlg::ID_STATICTEXT2 = wxNewId();
+const wxWindowID MakefileDlg::ID_TEXTCTRL1 = wxNewId();
+const wxWindowID MakefileDlg::ID_BUTTON1 = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(MakefileDlg,wxDialog)
@@ -37,13 +38,12 @@ MakefileDlg::MakefileDlg(wxWindow* parent,wxWindowID id)
 	BoxSizer4 = new wxBoxSizer(wxHORIZONTAL);
 	StaticText2 = new wxStaticText(this, ID_STATICTEXT2, _("Choose a name for the make file:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
 	BoxSizer4->Add(StaticText2, 0, wxALL, 5);
-	wxSize __SpacerSize_1 = wxDLG_UNIT(this,wxSize(100,-1));
-	BoxSizer4->Add(__SpacerSize_1.GetWidth(),__SpacerSize_1.GetHeight(),0, wxALL|wxEXPAND, 5);
+	BoxSizer4->Add(100,-1,0, wxALL|wxEXPAND, 5);
 	BoxSizer2->Add(BoxSizer4, 0, wxALL|wxEXPAND, 5);
 	BoxSizer3 = new wxBoxSizer(wxHORIZONTAL);
 	tcMakefileName = new wxTextCtrl(this, ID_TEXTCTRL1, _("Text"), wxDefaultPosition, wxSize(-1,-1), 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
 	BoxSizer3->Add(tcMakefileName, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	btChooseFileName = new wxButton(this, ID_BUTTON1, _("..."), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON1"));
+	btChooseFileName = new wxButton(this, ID_BUTTON1, _T("..."), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON1"));
 	BoxSizer3->Add(btChooseFileName, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	BoxSizer2->Add(BoxSizer3, 1, wxALL|wxEXPAND, 0);
 	BoxSizer1->Add(BoxSizer2, 1, wxALL|wxEXPAND, 5);
@@ -53,11 +53,11 @@ MakefileDlg::MakefileDlg(wxWindow* parent,wxWindowID id)
 	StdDialogButtonSizer1->Realize();
 	BoxSizer1->Add(StdDialogButtonSizer1, 0, wxALL|wxALIGN_RIGHT, 5);
 	SetSizer(BoxSizer1);
-	BoxSizer1->Fit(this);
 	BoxSizer1->SetSizeHints(this);
+	Center();
 
-	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&MakefileDlg::OnbtChooseFileNameClick);
-	Connect(wxID_ANY,wxEVT_INIT_DIALOG,(wxObjectEventFunction)&MakefileDlg::OnInit);
+	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(MakefileDlg::OnbtChooseFileNameClick));
+	Connect(wxID_ANY,wxEVT_INIT_DIALOG,wxInitDialogEventHandler(MakefileDlg::OnInit));
 	//*)
 }
 
@@ -84,8 +84,9 @@ wxString MakefileDlg::GetFilename()
 
 void MakefileDlg::OnbtChooseFileNameClick(wxCommandEvent& event)
 {
-    wxFileDialog saveFileDialog(this, _("Choose file name"), wxEmptyString, wxEmptyString, _T("All files (*)|*"), wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
+    wxFileDialog saveFileDialog(this, _("Choose file name"), wxEmptyString, wxEmptyString, "All files (*)|*", wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
     saveFileDialog.SetPath(tcMakefileName->GetValue());
+    PlaceWindow(&saveFileDialog);
     if (saveFileDialog.ShowModal() != wxID_OK)
         return;
     tcMakefileName->SetValue(saveFileDialog.GetPath());
