@@ -28,9 +28,9 @@ class MakefileDlg: public wxDialog
 	protected:
 
 		//(*Identifiers(MakefileDlg)
-		static const long ID_STATICTEXT2;
-		static const long ID_TEXTCTRL1;
-		static const long ID_BUTTON1;
+		static const wxWindowID ID_STATICTEXT2;
+		static const wxWindowID ID_TEXTCTRL1;
+		static const wxWindowID ID_BUTTON1;
 		//*)
 
 	private:
