@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with HexEditor. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: HexEditLineBuffer.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/HexEditor/HexEditLineBuffer.cpp $
+* $Revision: 12602 $
+* $Id: HexEditLineBuffer.cpp 12602 2021-12-21 07:26:04Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/HexEditor/HexEditLineBuffer.cpp $
 */
 
 #include "HexEditLineBuffer.h"
@@ -34,9 +34,9 @@ HexEditLineBuffer::HexEditLineBuffer( unsigned length )
     }
     else
     {
-        m_Buffer = 0L;
-        m_Position = 0L;
-        m_End = 0L;
+        m_Buffer = nullptr;
+        m_Position = nullptr;
+        m_End = nullptr;
     }
     Reset();
 }
