@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with HexEditor. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 11221 $
-* $Id: HexEditPanel.cpp 11221 2017-10-31 07:56:15Z fuscated $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/HexEditor/HexEditPanel.cpp $
+* $Revision: 13552 $
+* $Id: HexEditPanel.cpp 13552 2024-09-14 04:37:44Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/HexEditor/HexEditPanel.cpp $
 */
 #include <sdk.h>
 
@@ -54,8 +54,8 @@
 #include "SearchDialog.h"
 
 //(*InternalHeaders(HexEditPanel)
-#include <wx/string.h>
 #include <wx/intl.h>
+#include <wx/string.h>
 //*)
 
 
@@ -74,71 +74,71 @@ namespace
 }
 
 //(*IdInit(HexEditPanel)
-const long HexEditPanel::ID_STATICTEXT1 = wxNewId();
-const long HexEditPanel::ID_BUTTON10 = wxNewId();
-const long HexEditPanel::ID_BUTTON9 = wxNewId();
-const long HexEditPanel::ID_STATICLINE2 = wxNewId();
-const long HexEditPanel::ID_BUTTON7 = wxNewId();
-const long HexEditPanel::ID_BUTTON4 = wxNewId();
-const long HexEditPanel::ID_BUTTON6 = wxNewId();
-const long HexEditPanel::ID_BUTTON5 = wxNewId();
-const long HexEditPanel::ID_STATICLINE1 = wxNewId();
-const long HexEditPanel::ID_BUTTON1 = wxNewId();
-const long HexEditPanel::ID_BUTTON8 = wxNewId();
-const long HexEditPanel::ID_CHECKBOX1 = wxNewId();
-const long HexEditPanel::ID_PANEL1 = wxNewId();
-const long HexEditPanel::ID_SCROLLBAR1 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT2 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT3 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT4 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT5 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT6 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT7 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT8 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT9 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT10 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT11 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT12 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT13 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT14 = wxNewId();
-const long HexEditPanel::ID_TEXTCTRL1 = wxNewId();
-const long HexEditPanel::ID_BUTTON3 = wxNewId();
-const long HexEditPanel::ID_BUTTON2 = wxNewId();
-const long HexEditPanel::ID_STATICTEXT15 = wxNewId();
-const long HexEditPanel::ID_TIMER1 = wxNewId();
-const long HexEditPanel::ID_MENUITEM2 = wxNewId();
-const long HexEditPanel::ID_MENUITEM1 = wxNewId();
-const long HexEditPanel::ID_MENUITEM3 = wxNewId();
-const long HexEditPanel::ID_MENUITEM4 = wxNewId();
-const long HexEditPanel::ID_MENUITEM5 = wxNewId();
-const long HexEditPanel::ID_MENUITEM6 = wxNewId();
-const long HexEditPanel::ID_MENUITEM7 = wxNewId();
-const long HexEditPanel::ID_MENUITEM8 = wxNewId();
-const long HexEditPanel::ID_MENUITEM9 = wxNewId();
-const long HexEditPanel::ID_MENUITEM11 = wxNewId();
-const long HexEditPanel::ID_MENUITEM12 = wxNewId();
-const long HexEditPanel::ID_MENUITEM13 = wxNewId();
-const long HexEditPanel::ID_MENUITEM14 = wxNewId();
-const long HexEditPanel::ID_MENUITEM15 = wxNewId();
-const long HexEditPanel::ID_MENUITEM16 = wxNewId();
-const long HexEditPanel::ID_MENUITEM17 = wxNewId();
-const long HexEditPanel::ID_MENUITEM18 = wxNewId();
-const long HexEditPanel::ID_MENUITEM32 = wxNewId();
-const long HexEditPanel::ID_MENUITEM10 = wxNewId();
-const long HexEditPanel::ID_MENUITEM20 = wxNewId();
-const long HexEditPanel::ID_MENUITEM21 = wxNewId();
-const long HexEditPanel::ID_MENUITEM22 = wxNewId();
-const long HexEditPanel::ID_MENUITEM23 = wxNewId();
-const long HexEditPanel::ID_MENUITEM24 = wxNewId();
-const long HexEditPanel::ID_MENUITEM25 = wxNewId();
-const long HexEditPanel::ID_MENUITEM26 = wxNewId();
-const long HexEditPanel::ID_MENUITEM27 = wxNewId();
-const long HexEditPanel::ID_MENUITEM19 = wxNewId();
-const long HexEditPanel::ID_MENUITEM29 = wxNewId();
-const long HexEditPanel::ID_MENUITEM30 = wxNewId();
-const long HexEditPanel::ID_MENUITEM31 = wxNewId();
-const long HexEditPanel::ID_MENUITEM33 = wxNewId();
-const long HexEditPanel::ID_MENUITEM28 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT1 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON10 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON9 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICLINE2 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON7 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON4 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON6 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON5 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICLINE1 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON1 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON8 = wxNewId();
+const wxWindowID HexEditPanel::ID_CHECKBOX1 = wxNewId();
+const wxWindowID HexEditPanel::ID_PANEL1 = wxNewId();
+const wxWindowID HexEditPanel::ID_SCROLLBAR1 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT2 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT3 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT4 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT5 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT6 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT7 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT8 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT9 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT10 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT11 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT12 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT13 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT14 = wxNewId();
+const wxWindowID HexEditPanel::ID_TEXTCTRL1 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON3 = wxNewId();
+const wxWindowID HexEditPanel::ID_BUTTON2 = wxNewId();
+const wxWindowID HexEditPanel::ID_STATICTEXT15 = wxNewId();
+const wxWindowID HexEditPanel::ID_TIMER1 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM2 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM1 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM3 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM4 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM5 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM6 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM7 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM8 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM9 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM11 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM12 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM13 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM14 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM15 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM16 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM17 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM18 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM32 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM10 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM20 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM21 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM22 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM23 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM24 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM25 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM26 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM27 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM19 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM29 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM30 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM31 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM33 = wxNewId();
+const wxWindowID HexEditPanel::ID_MENUITEM28 = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(HexEditPanel,EditorBase)
@@ -149,7 +149,7 @@ END_EVENT_TABLE()
 HexEditPanel::EditorsSet HexEditPanel::m_AllEditors;
 
 HexEditPanel::HexEditPanel( const wxString& fileName, const wxString& title )
-    : EditorBase( (wxWindow*)Manager::Get()->GetEditorManager()->GetNotebook(), fileName )
+    : EditorBase( (wxWindow*)Manager::Get()->GetEditorManager()->GetNotebook(), fileName, true)
     , m_FileName( fileName )
     , m_Content( 0 )
     , m_DrawFont( 0 )
@@ -161,7 +161,7 @@ HexEditPanel::HexEditPanel( const wxString& fileName, const wxString& title )
     --- Begin of comment which prevents calling Create() --
 
     //(*Initialize(HexEditPanel)
-    Create(parent, wxID_ANY, wxDefaultPosition, wxSize(79,51), wxTAB_TRAVERSAL, _T("wxID_ANY"));
+    Create(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("wxID_ANY"));
 
     --- End of comment which prevents calling Create() --
     */
@@ -208,31 +208,31 @@ HexEditPanel::HexEditPanel( const wxString& fileName, const wxString& title )
     FlexGridSizer1->AddGrowableCol(7);
     StaticText1 = new wxStaticText(this, ID_STATICTEXT2, _("Byte:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
     FlexGridSizer1->Add(StaticText1, 1, wxEXPAND, 5);
-    m_ByteVal = new wxStaticText(this, ID_STATICTEXT3, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
+    m_ByteVal = new wxStaticText(this, ID_STATICTEXT3, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
     FlexGridSizer1->Add(m_ByteVal, 1, wxEXPAND, 5);
     FlexGridSizer1->Add(5,5,1, wxALIGN_CENTER_VERTICAL, 5);
     StaticText3 = new wxStaticText(this, ID_STATICTEXT4, _("Word:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT4"));
     FlexGridSizer1->Add(StaticText3, 1, wxEXPAND, 5);
-    m_WordVal = new wxStaticText(this, ID_STATICTEXT5, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT5"));
+    m_WordVal = new wxStaticText(this, ID_STATICTEXT5, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT5"));
     FlexGridSizer1->Add(m_WordVal, 1, wxEXPAND, 5);
     FlexGridSizer1->Add(5,5,1, wxALIGN_CENTER_VERTICAL, 5);
     StaticText2 = new wxStaticText(this, ID_STATICTEXT6, _("Dword:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT6"));
     FlexGridSizer1->Add(StaticText2, 1, wxEXPAND, 5);
-    m_DwordVal = new wxStaticText(this, ID_STATICTEXT7, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT7"));
+    m_DwordVal = new wxStaticText(this, ID_STATICTEXT7, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT7"));
     FlexGridSizer1->Add(m_DwordVal, 1, wxEXPAND, 5);
     StaticText4 = new wxStaticText(this, ID_STATICTEXT8, _("Float:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT8"));
     FlexGridSizer1->Add(StaticText4, 1, wxEXPAND, 5);
-    m_FloatVal = new wxStaticText(this, ID_STATICTEXT9, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT9"));
+    m_FloatVal = new wxStaticText(this, ID_STATICTEXT9, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT9"));
     FlexGridSizer1->Add(m_FloatVal, 1, wxEXPAND, 5);
     FlexGridSizer1->Add(5,5,1, wxALIGN_CENTER_VERTICAL, 5);
     StaticText6 = new wxStaticText(this, ID_STATICTEXT10, _("Double:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT10"));
     FlexGridSizer1->Add(StaticText6, 1, wxEXPAND, 5);
-    m_DoubleVal = new wxStaticText(this, ID_STATICTEXT11, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT11"));
+    m_DoubleVal = new wxStaticText(this, ID_STATICTEXT11, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT11"));
     FlexGridSizer1->Add(m_DoubleVal, 1, wxEXPAND, 5);
     FlexGridSizer1->Add(5,5,1, wxALIGN_CENTER_VERTICAL, 5);
     StaticText8 = new wxStaticText(this, ID_STATICTEXT12, _("L-Double:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT12"));
     FlexGridSizer1->Add(StaticText8, 1, wxEXPAND, 5);
-    m_LDoubleVal = new wxStaticText(this, ID_STATICTEXT13, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT13"));
+    m_LDoubleVal = new wxStaticText(this, ID_STATICTEXT13, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT13"));
     FlexGridSizer1->Add(m_LDoubleVal, 1, wxEXPAND, 5);
     PreviewSizer->Add(FlexGridSizer1, 0, wxBOTTOM|wxLEFT|wxRIGHT|wxEXPAND, 5);
     BoxSizer4 = new wxBoxSizer(wxHORIZONTAL);
@@ -242,9 +242,9 @@ HexEditPanel::HexEditPanel( const wxString& fileName, const wxString& title )
     BoxSizer4->Add(m_Expression, 1, wxLEFT|wxALIGN_CENTER_VERTICAL, 5);
     Button3 = new wxButton(this, ID_BUTTON3, _("v"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON3"));
     BoxSizer4->Add(Button3, 0, wxRIGHT|wxEXPAND, 5);
-    Button2 = new wxButton(this, ID_BUTTON2, _("\?"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON2"));
+    Button2 = new wxButton(this, ID_BUTTON2, _T("\?"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON2"));
     BoxSizer4->Add(Button2, 0, wxRIGHT|wxEXPAND, 5);
-    m_ExpressionVal = new wxStaticText(this, ID_STATICTEXT15, _("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT15"));
+    m_ExpressionVal = new wxStaticText(this, ID_STATICTEXT15, _T("-9999999999"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT15"));
     BoxSizer4->Add(m_ExpressionVal, 1, wxLEFT|wxALIGN_CENTER_VERTICAL, 5);
     PreviewSizer->Add(BoxSizer4, 0, wxBOTTOM|wxLEFT|wxRIGHT|wxEXPAND, 5);
     BoxSizer1->Add(PreviewSizer, 0, wxEXPAND, 5);
@@ -269,121 +269,120 @@ HexEditPanel::HexEditPanel( const wxString& fileName, const wxString& title )
     MenuItem9 = new wxMenuItem((&m_ColsModeMenu), ID_MENUITEM9, _("Any"), wxEmptyString, wxITEM_NORMAL);
     m_ColsModeMenu.Append(MenuItem9);
     MenuItem10 = new wxMenu();
-    MenuItem11 = new wxMenuItem(MenuItem10, ID_MENUITEM11, _("1"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem11 = new wxMenuItem(MenuItem10, ID_MENUITEM11, _T("1"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem11);
-    MenuItem12 = new wxMenuItem(MenuItem10, ID_MENUITEM12, _("2"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem12 = new wxMenuItem(MenuItem10, ID_MENUITEM12, _T("2"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem12);
-    MenuItem13 = new wxMenuItem(MenuItem10, ID_MENUITEM13, _("3"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem13 = new wxMenuItem(MenuItem10, ID_MENUITEM13, _T("3"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem13);
-    MenuItem14 = new wxMenuItem(MenuItem10, ID_MENUITEM14, _("4"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem14 = new wxMenuItem(MenuItem10, ID_MENUITEM14, _T("4"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem14);
-    MenuItem15 = new wxMenuItem(MenuItem10, ID_MENUITEM15, _("5"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem15 = new wxMenuItem(MenuItem10, ID_MENUITEM15, _T("5"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem15);
-    MenuItem16 = new wxMenuItem(MenuItem10, ID_MENUITEM16, _("6"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem16 = new wxMenuItem(MenuItem10, ID_MENUITEM16, _T("6"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem16);
-    MenuItem17 = new wxMenuItem(MenuItem10, ID_MENUITEM17, _("7"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem17 = new wxMenuItem(MenuItem10, ID_MENUITEM17, _T("7"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem17);
-    MenuItem18 = new wxMenuItem(MenuItem10, ID_MENUITEM18, _("8"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem18 = new wxMenuItem(MenuItem10, ID_MENUITEM18, _T("8"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem18);
     MenuItem10->AppendSeparator();
     MenuItem32 = new wxMenuItem(MenuItem10, ID_MENUITEM32, _("Other"), wxEmptyString, wxITEM_NORMAL);
     MenuItem10->Append(MenuItem32);
     m_ColsModeMenu.Append(ID_MENUITEM10, _("Exactly"), MenuItem10, wxEmptyString);
     MenuItem19 = new wxMenu();
-    MenuItem20 = new wxMenuItem(MenuItem19, ID_MENUITEM20, _("2"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem20 = new wxMenuItem(MenuItem19, ID_MENUITEM20, _T("2"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem20);
-    MenuItem21 = new wxMenuItem(MenuItem19, ID_MENUITEM21, _("3"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem21 = new wxMenuItem(MenuItem19, ID_MENUITEM21, _T("3"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem21);
-    MenuItem22 = new wxMenuItem(MenuItem19, ID_MENUITEM22, _("4"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem22 = new wxMenuItem(MenuItem19, ID_MENUITEM22, _T("4"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem22);
-    MenuItem23 = new wxMenuItem(MenuItem19, ID_MENUITEM23, _("5"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem23 = new wxMenuItem(MenuItem19, ID_MENUITEM23, _T("5"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem23);
-    MenuItem24 = new wxMenuItem(MenuItem19, ID_MENUITEM24, _("6"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem24 = new wxMenuItem(MenuItem19, ID_MENUITEM24, _T("6"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem24);
-    MenuItem25 = new wxMenuItem(MenuItem19, ID_MENUITEM25, _("7"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem25 = new wxMenuItem(MenuItem19, ID_MENUITEM25, _T("7"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem25);
-    MenuItem26 = new wxMenuItem(MenuItem19, ID_MENUITEM26, _("8"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem26 = new wxMenuItem(MenuItem19, ID_MENUITEM26, _T("8"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem26);
     MenuItem19->AppendSeparator();
     MenuItem27 = new wxMenuItem(MenuItem19, ID_MENUITEM27, _("Other"), wxEmptyString, wxITEM_NORMAL);
     MenuItem19->Append(MenuItem27);
     m_ColsModeMenu.Append(ID_MENUITEM19, _("Multiple of"), MenuItem19, wxEmptyString);
     MenuItem28 = new wxMenu();
-    MenuItem29 = new wxMenuItem(MenuItem28, ID_MENUITEM29, _("2"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem29 = new wxMenuItem(MenuItem28, ID_MENUITEM29, _T("2"), wxEmptyString, wxITEM_NORMAL);
     MenuItem28->Append(MenuItem29);
-    MenuItem30 = new wxMenuItem(MenuItem28, ID_MENUITEM30, _("4"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem30 = new wxMenuItem(MenuItem28, ID_MENUITEM30, _T("4"), wxEmptyString, wxITEM_NORMAL);
     MenuItem28->Append(MenuItem30);
-    MenuItem31 = new wxMenuItem(MenuItem28, ID_MENUITEM31, _("8"), wxEmptyString, wxITEM_NORMAL);
+    MenuItem31 = new wxMenuItem(MenuItem28, ID_MENUITEM31, _T("8"), wxEmptyString, wxITEM_NORMAL);
     MenuItem28->Append(MenuItem31);
     MenuItem28->AppendSeparator();
     MenuItem33 = new wxMenuItem(MenuItem28, ID_MENUITEM33, _("Other"), wxEmptyString, wxITEM_NORMAL);
     MenuItem28->Append(MenuItem33);
     m_ColsModeMenu.Append(ID_MENUITEM28, _("Power of"), MenuItem28, wxEmptyString);
-    SetSizer(BoxSizer1);
-    Layout();
+    BoxSizer1->SetSizeHints(this);
 
-    Connect(ID_BUTTON10,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton6Click);
-    Connect(ID_BUTTON9,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton5Click);
-    Connect(ID_BUTTON7,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::Onm_ColsModeClick);
-    Connect(ID_BUTTON4,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton4Click);
-    Connect(ID_BUTTON6,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::Onm_BlockSizeClick);
-    Connect(ID_BUTTON5,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::Onm_EndianessClick);
-    Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton1Click);
-    Connect(ID_BUTTON8,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton4Click1);
-    Connect(ID_CHECKBOX1,wxEVT_COMMAND_CHECKBOX_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnCheckBox1Click);
-    m_DrawArea->Connect(wxEVT_PAINT,(wxObjectEventFunction)&HexEditPanel::OnContentPaint,0,this);
-    m_DrawArea->Connect(wxEVT_ERASE_BACKGROUND,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaEraseBackground,0,this);
-    m_DrawArea->Connect(wxEVT_KEY_DOWN,(wxObjectEventFunction)&HexEditPanel::OnSpecialKeyDown,0,this);
-    m_DrawArea->Connect(wxEVT_CHAR,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaKeyDown,0,this);
-    m_DrawArea->Connect(wxEVT_LEFT_DOWN,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaLeftDown,0,this);
-    m_DrawArea->Connect(wxEVT_LEFT_UP,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaLeftUp,0,this);
-    m_DrawArea->Connect(wxEVT_MOTION,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaMouseMove,0,this);
-    m_DrawArea->Connect(wxEVT_LEAVE_WINDOW,(wxObjectEventFunction)&HexEditPanel::OnDrawAreaLeftUp,0,this);
-    m_DrawArea->Connect(wxEVT_MOUSEWHEEL,(wxObjectEventFunction)&HexEditPanel::OnContentMouseWheel,0,this);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_TOP,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_BOTTOM,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_LINEUP,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_LINEDOWN,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_PAGEUP,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_PAGEDOWN,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_THUMBTRACK,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_THUMBRELEASE,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_CHANGED,(wxObjectEventFunction)&HexEditPanel::OnContentScroll);
-    Connect(ID_TEXTCTRL1,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&HexEditPanel::Onm_ExpressionText);
-    Connect(ID_TEXTCTRL1,wxEVT_COMMAND_TEXT_ENTER,(wxObjectEventFunction)&HexEditPanel::OnExpressionTextEnter);
-    Connect(ID_BUTTON3,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton3Click1);
-    Connect(ID_BUTTON2,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&HexEditPanel::OnButton2Click);
-    Connect(ID_TIMER1,wxEVT_TIMER,(wxObjectEventFunction)&HexEditPanel::OnReparseTimerTrigger);
-    Connect(ID_MENUITEM2,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBaseBin);
-    Connect(ID_MENUITEM1,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBaseHex);
-    Connect(ID_MENUITEM3,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetEndianessBig);
-    Connect(ID_MENUITEM4,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetEndianessLittle);
-    Connect(ID_MENUITEM5,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBlockSize1);
-    Connect(ID_MENUITEM6,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBlockSize2);
-    Connect(ID_MENUITEM7,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBlockSize4);
-    Connect(ID_MENUITEM8,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetBlockSize8);
-    Connect(ID_MENUITEM9,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul1);
-    Connect(ID_MENUITEM11,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue1);
-    Connect(ID_MENUITEM12,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue2);
-    Connect(ID_MENUITEM13,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue3);
-    Connect(ID_MENUITEM14,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue4);
-    Connect(ID_MENUITEM15,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue5);
-    Connect(ID_MENUITEM16,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue6);
-    Connect(ID_MENUITEM17,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue7);
-    Connect(ID_MENUITEM18,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValue8);
-    Connect(ID_MENUITEM32,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsValueOther);
-    Connect(ID_MENUITEM20,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul2);
-    Connect(ID_MENUITEM21,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul3);
-    Connect(ID_MENUITEM22,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul4);
-    Connect(ID_MENUITEM23,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul5);
-    Connect(ID_MENUITEM24,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul6);
-    Connect(ID_MENUITEM25,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul7);
-    Connect(ID_MENUITEM26,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMul8);
-    Connect(ID_MENUITEM27,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsMulOther);
-    Connect(ID_MENUITEM29,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsPower2);
-    Connect(ID_MENUITEM30,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsPower4);
-    Connect(ID_MENUITEM31,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsPower8);
-    Connect(ID_MENUITEM33,wxEVT_COMMAND_MENU_SELECTED,(wxObjectEventFunction)&HexEditPanel::OnSetColsPowerOther);
+    Connect(ID_BUTTON10,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton6Click));
+    Connect(ID_BUTTON9,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton5Click));
+    Connect(ID_BUTTON7,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::Onm_ColsModeClick));
+    Connect(ID_BUTTON4,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton4Click));
+    Connect(ID_BUTTON6,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::Onm_BlockSizeClick));
+    Connect(ID_BUTTON5,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::Onm_EndianessClick));
+    Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton1Click));
+    Connect(ID_BUTTON8,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton4Click1));
+    Connect(ID_CHECKBOX1,wxEVT_COMMAND_CHECKBOX_CLICKED,wxCommandEventHandler(HexEditPanel::OnCheckBox1Click));
+    m_DrawArea->Connect(wxEVT_PAINT,wxPaintEventHandler(HexEditPanel::OnContentPaint), NULL, this);
+    m_DrawArea->Connect(wxEVT_ERASE_BACKGROUND,wxEraseEventHandler(HexEditPanel::OnDrawAreaEraseBackground), NULL, this);
+    m_DrawArea->Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(HexEditPanel::OnSpecialKeyDown), NULL, this);
+    m_DrawArea->Connect(wxEVT_CHAR,wxKeyEventHandler(HexEditPanel::OnDrawAreaKeyDown), NULL, this);
+    m_DrawArea->Connect(wxEVT_LEFT_DOWN,wxMouseEventHandler(HexEditPanel::OnDrawAreaLeftDown), NULL, this);
+    m_DrawArea->Connect(wxEVT_LEFT_UP,wxMouseEventHandler(HexEditPanel::OnDrawAreaLeftUp), NULL, this);
+    m_DrawArea->Connect(wxEVT_MOTION,wxMouseEventHandler(HexEditPanel::OnDrawAreaMouseMove), NULL, this);
+    m_DrawArea->Connect(wxEVT_LEAVE_WINDOW,wxMouseEventHandler(HexEditPanel::OnDrawAreaLeftUp), NULL, this);
+    m_DrawArea->Connect(wxEVT_MOUSEWHEEL,wxMouseEventHandler(HexEditPanel::OnContentMouseWheel), NULL, this);
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_TOP,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_BOTTOM,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_LINEUP,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_LINEDOWN,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_PAGEUP,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_PAGEDOWN,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_THUMBTRACK,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_THUMBRELEASE,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_SCROLLBAR1,wxEVT_SCROLL_CHANGED,wxScrollEventHandler(HexEditPanel::OnContentScroll));
+    Connect(ID_TEXTCTRL1,wxEVT_COMMAND_TEXT_UPDATED,wxCommandEventHandler(HexEditPanel::Onm_ExpressionText));
+    Connect(ID_TEXTCTRL1,wxEVT_COMMAND_TEXT_ENTER,wxCommandEventHandler(HexEditPanel::OnExpressionTextEnter));
+    Connect(ID_BUTTON3,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton3Click1));
+    Connect(ID_BUTTON2,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(HexEditPanel::OnButton2Click));
+    Connect(ID_TIMER1,wxEVT_TIMER,wxTimerEventHandler(HexEditPanel::OnReparseTimerTrigger));
+    Connect(ID_MENUITEM2,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBaseBin));
+    Connect(ID_MENUITEM1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBaseHex));
+    Connect(ID_MENUITEM3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetEndianessBig));
+    Connect(ID_MENUITEM4,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetEndianessLittle));
+    Connect(ID_MENUITEM5,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBlockSize1));
+    Connect(ID_MENUITEM6,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBlockSize2));
+    Connect(ID_MENUITEM7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBlockSize4));
+    Connect(ID_MENUITEM8,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetBlockSize8));
+    Connect(ID_MENUITEM9,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul1));
+    Connect(ID_MENUITEM11,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue1));
+    Connect(ID_MENUITEM12,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue2));
+    Connect(ID_MENUITEM13,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue3));
+    Connect(ID_MENUITEM14,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue4));
+    Connect(ID_MENUITEM15,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue5));
+    Connect(ID_MENUITEM16,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue6));
+    Connect(ID_MENUITEM17,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue7));
+    Connect(ID_MENUITEM18,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValue8));
+    Connect(ID_MENUITEM32,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsValueOther));
+    Connect(ID_MENUITEM20,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul2));
+    Connect(ID_MENUITEM21,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul3));
+    Connect(ID_MENUITEM22,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul4));
+    Connect(ID_MENUITEM23,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul5));
+    Connect(ID_MENUITEM24,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul6));
+    Connect(ID_MENUITEM25,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul7));
+    Connect(ID_MENUITEM26,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMul8));
+    Connect(ID_MENUITEM27,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsMulOther));
+    Connect(ID_MENUITEM29,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsPower2));
+    Connect(ID_MENUITEM30,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsPower4));
+    Connect(ID_MENUITEM31,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsPower8));
+    Connect(ID_MENUITEM33,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler(HexEditPanel::OnSetColsPowerOther));
     //*)
 
     // We connect these events manually
@@ -1170,7 +1169,7 @@ bool HexEditPanel::SaveAs()
                       fname.GetFullName(),
                       _T("*.*"),//m_filecontent->GetWildcard(),
                       wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
-
+    PlaceWindow(&dlg);
     if (dlg.ShowModal() != wxID_OK) // cancelled out
     {
         UpdateModified();
@@ -1426,7 +1425,8 @@ void HexEditPanel::ProcessGoto()
               " * Hexadecimal ( 1AB, 0x1AB, 1ABh )\n"
               " * Offset from current ( +100, -100, +0x1AB )"),
             _("Goto offset"),
-            str );
+            str,
+            this);
 
         if ( str.IsEmpty() ) return;
         str.Trim( true ).Trim( false );
@@ -1519,6 +1519,7 @@ void HexEditPanel::ProcessSearch()
     if ( !m_Content->GetSize() ) return;
 
     SearchDialog dlg( this, m_Content, m_Current );
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() == wxID_OK )
     {
         m_Current = dlg.GetOffset();
@@ -1533,7 +1534,9 @@ void HexEditPanel::ProcessSearch()
 
 void HexEditPanel::OnButton1Click(wxCommandEvent& /*event*/)
 {
-    ExpressionTester( 0, m_Content, m_Current).ShowModal();
+    ExpressionTester dlg(this, m_Content, m_Current);
+    PlaceWindow(&dlg);
+    dlg.ShowModal();
 }
 
 void HexEditPanel::ReparseExpression()
@@ -1576,7 +1579,8 @@ void HexEditPanel::OnExpressionTextEnter(wxCommandEvent& /*event*/)
 void HexEditPanel::OnButton3Click1(wxCommandEvent& event)
 {
     SelectStoredExpressionDlg dlg( this, m_Expression->GetValue() );
-    if ( dlg.ShowModal() == wxID_OK )
+    PlaceWindow(&dlg);
+    if (dlg.ShowModal() == wxID_OK)
     {
         m_Expression->SetValue( dlg.GetExpression() );
         OnExpressionTextEnter(event);
@@ -1827,7 +1831,9 @@ void HexEditPanel::OnButton4Click1(wxCommandEvent& /*event*/)
 
     if ( !test ) return;
 
-    TestCasesDlg( this, *test ).ShowModal();
+    TestCasesDlg dlg(this, *test);
+    PlaceWindow(&dlg);
+    dlg.ShowModal();
 }
 
 
