@@ -15,21 +15,21 @@
 * You should have received a copy of the GNU General Public License
 * along with HexEditor. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 11221 $
-* $Id: HexEditPanel.h 11221 2017-10-31 07:56:15Z fuscated $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/HexEditor/HexEditPanel.h $
+* $Revision: 13570 $
+* $Id: HexEditPanel.h 13570 2024-09-14 05:03:57Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/HexEditor/HexEditPanel.h $
 */
 
 #ifndef HEXEDITPANEL_H
 #define HEXEDITPANEL_H
 
 //(*Headers(HexEditPanel)
-#include <wx/scrolbar.h>
-#include <wx/checkbox.h>
-#include <wx/sizer.h>
 #include <wx/button.h>
+#include <wx/checkbox.h>
 #include <wx/menu.h>
 #include <wx/panel.h>
+#include <wx/scrolbar.h>
+#include <wx/sizer.h>
 #include <wx/statline.h>
 #include <wx/stattext.h>
 #include <wx/textctrl.h>
@@ -74,149 +74,149 @@ class HexEditPanel: public EditorBase
         typedef FileContentBase::OffsetT OffsetT;
 
         //(*Declarations(HexEditPanel)
+        wxBoxSizer* BoxSizer1;
+        wxBoxSizer* BoxSizer2;
+        wxBoxSizer* BoxSizer3;
+        wxBoxSizer* BoxSizer4;
+        wxBoxSizer* PreviewSizer;
+        wxButton* Button1;
+        wxButton* Button2;
+        wxButton* Button3;
+        wxButton* Button4;
+        wxButton* Button5;
+        wxButton* Button6;
+        wxButton* m_BlockSize;
+        wxButton* m_ColsModeBtn;
+        wxButton* m_DigitBits;
+        wxButton* m_Endianess;
+        wxCheckBox* CheckBox1;
+        wxFlexGridSizer* FlexGridSizer1;
+        wxMenu m_BaseMenu;
+        wxMenu m_BlockSizeMenu;
+        wxMenu m_ColsModeMenu;
+        wxMenu m_EndianessMenu;
+        wxMenu* MenuItem10;
+        wxMenu* MenuItem19;
+        wxMenu* MenuItem28;
+        wxMenuItem* MenuItem11;
+        wxMenuItem* MenuItem12;
+        wxMenuItem* MenuItem13;
+        wxMenuItem* MenuItem14;
+        wxMenuItem* MenuItem15;
+        wxMenuItem* MenuItem16;
+        wxMenuItem* MenuItem17;
+        wxMenuItem* MenuItem18;
+        wxMenuItem* MenuItem1;
+        wxMenuItem* MenuItem20;
+        wxMenuItem* MenuItem21;
+        wxMenuItem* MenuItem22;
+        wxMenuItem* MenuItem23;
+        wxMenuItem* MenuItem24;
+        wxMenuItem* MenuItem25;
+        wxMenuItem* MenuItem26;
+        wxMenuItem* MenuItem27;
         wxMenuItem* MenuItem29;
         wxMenuItem* MenuItem2;
-        wxMenu m_ColsModeMenu;
-        wxMenuItem* MenuItem23;
-        wxBoxSizer* PreviewSizer;
-        wxMenu* MenuItem10;
-        wxMenuItem* MenuItem31;
-        wxMenuItem* MenuItem1;
-        wxButton* m_ColsModeBtn;
-        wxMenu* MenuItem19;
-        wxFlexGridSizer* FlexGridSizer1;
         wxMenuItem* MenuItem30;
-        wxTextCtrl* m_Expression;
-        wxBoxSizer* BoxSizer3;
-        wxStaticLine* StaticLine2;
-        wxMenu m_EndianessMenu;
-        wxStaticText* m_ExpressionVal;
-        wxStaticText* m_LDoubleVal;
-        wxMenuItem* MenuItem16;
-        wxMenuItem* MenuItem12;
-        wxMenuItem* MenuItem25;
-        wxButton* m_BlockSize;
-        wxScrollBar* m_ContentScroll;
-        wxStaticText* m_FloatVal;
+        wxMenuItem* MenuItem31;
         wxMenuItem* MenuItem32;
-        wxButton* Button4;
-        wxMenuItem* MenuItem20;
-        wxStaticText* m_DwordVal;
-        wxButton* Button1;
-        wxPanel* m_DrawArea;
-        wxCheckBox* CheckBox1;
-        wxButton* Button2;
         wxMenuItem* MenuItem33;
-        wxButton* Button3;
-        wxMenu m_BaseMenu;
-        wxMenuItem* MenuItem24;
-        wxBoxSizer* BoxSizer2;
-        wxMenuItem* MenuItem15;
-        wxStaticText* StaticText1;
-        wxMenuItem* MenuItem21;
-        wxMenuItem* MenuItem17;
-        wxStaticText* StaticText3;
-        wxMenu m_BlockSizeMenu;
         wxMenuItem* MenuItem3;
-        wxStaticLine* StaticLine1;
-        wxButton* Button5;
-        wxMenuItem* MenuItem9;
-        wxStaticText* StaticText8;
-        wxStaticText* m_WordVal;
-        wxBoxSizer* BoxSizer4;
-        wxMenuItem* MenuItem11;
-        wxMenu* MenuItem28;
-        wxMenuItem* MenuItem22;
-        wxMenuItem* MenuItem5;
-        wxStaticText* StaticText4;
-        wxTimer ReparseTimer;
-        wxBoxSizer* BoxSizer1;
-        wxStaticText* m_DoubleVal;
-        wxStaticText* StaticText5;
-        wxStaticText* StaticText2;
-        wxMenuItem* MenuItem27;
-        wxMenuItem* MenuItem18;
-        wxMenuItem* MenuItem7;
-        wxMenuItem* MenuItem6;
         wxMenuItem* MenuItem4;
-        wxMenuItem* MenuItem26;
-        wxStaticText* StaticText6;
-        wxMenuItem* MenuItem13;
-        wxStaticText* m_ByteVal;
-        wxStaticText* m_Status;
+        wxMenuItem* MenuItem5;
+        wxMenuItem* MenuItem6;
+        wxMenuItem* MenuItem7;
         wxMenuItem* MenuItem8;
-        wxButton* Button6;
-        wxMenuItem* MenuItem14;
-        wxButton* m_Endianess;
-        wxButton* m_DigitBits;
+        wxMenuItem* MenuItem9;
+        wxPanel* m_DrawArea;
+        wxScrollBar* m_ContentScroll;
+        wxStaticLine* StaticLine1;
+        wxStaticLine* StaticLine2;
+        wxStaticText* StaticText1;
+        wxStaticText* StaticText2;
+        wxStaticText* StaticText3;
+        wxStaticText* StaticText4;
+        wxStaticText* StaticText5;
+        wxStaticText* StaticText6;
+        wxStaticText* StaticText8;
+        wxStaticText* m_ByteVal;
+        wxStaticText* m_DoubleVal;
+        wxStaticText* m_DwordVal;
+        wxStaticText* m_ExpressionVal;
+        wxStaticText* m_FloatVal;
+        wxStaticText* m_LDoubleVal;
+        wxStaticText* m_Status;
+        wxStaticText* m_WordVal;
+        wxTextCtrl* m_Expression;
+        wxTimer ReparseTimer;
         //*)
 
         //(*Identifiers(HexEditPanel)
-        static const long ID_STATICTEXT1;
-        static const long ID_BUTTON10;
-        static const long ID_BUTTON9;
-        static const long ID_STATICLINE2;
-        static const long ID_BUTTON7;
-        static const long ID_BUTTON4;
-        static const long ID_BUTTON6;
-        static const long ID_BUTTON5;
-        static const long ID_STATICLINE1;
-        static const long ID_BUTTON1;
-        static const long ID_BUTTON8;
-        static const long ID_CHECKBOX1;
-        static const long ID_PANEL1;
-        static const long ID_SCROLLBAR1;
-        static const long ID_STATICTEXT2;
-        static const long ID_STATICTEXT3;
-        static const long ID_STATICTEXT4;
-        static const long ID_STATICTEXT5;
-        static const long ID_STATICTEXT6;
-        static const long ID_STATICTEXT7;
-        static const long ID_STATICTEXT8;
-        static const long ID_STATICTEXT9;
-        static const long ID_STATICTEXT10;
-        static const long ID_STATICTEXT11;
-        static const long ID_STATICTEXT12;
-        static const long ID_STATICTEXT13;
-        static const long ID_STATICTEXT14;
-        static const long ID_TEXTCTRL1;
-        static const long ID_BUTTON3;
-        static const long ID_BUTTON2;
-        static const long ID_STATICTEXT15;
-        static const long ID_TIMER1;
-        static const long ID_MENUITEM2;
-        static const long ID_MENUITEM1;
-        static const long ID_MENUITEM3;
-        static const long ID_MENUITEM4;
-        static const long ID_MENUITEM5;
-        static const long ID_MENUITEM6;
-        static const long ID_MENUITEM7;
-        static const long ID_MENUITEM8;
-        static const long ID_MENUITEM9;
-        static const long ID_MENUITEM11;
-        static const long ID_MENUITEM12;
-        static const long ID_MENUITEM13;
-        static const long ID_MENUITEM14;
-        static const long ID_MENUITEM15;
-        static const long ID_MENUITEM16;
-        static const long ID_MENUITEM17;
-        static const long ID_MENUITEM18;
-        static const long ID_MENUITEM32;
-        static const long ID_MENUITEM10;
-        static const long ID_MENUITEM20;
-        static const long ID_MENUITEM21;
-        static const long ID_MENUITEM22;
-        static const long ID_MENUITEM23;
-        static const long ID_MENUITEM24;
-        static const long ID_MENUITEM25;
-        static const long ID_MENUITEM26;
-        static const long ID_MENUITEM27;
-        static const long ID_MENUITEM19;
-        static const long ID_MENUITEM29;
-        static const long ID_MENUITEM30;
-        static const long ID_MENUITEM31;
-        static const long ID_MENUITEM33;
-        static const long ID_MENUITEM28;
+        static const wxWindowID ID_STATICTEXT1;
+        static const wxWindowID ID_BUTTON10;
+        static const wxWindowID ID_BUTTON9;
+        static const wxWindowID ID_STATICLINE2;
+        static const wxWindowID ID_BUTTON7;
+        static const wxWindowID ID_BUTTON4;
+        static const wxWindowID ID_BUTTON6;
+        static const wxWindowID ID_BUTTON5;
+        static const wxWindowID ID_STATICLINE1;
+        static const wxWindowID ID_BUTTON1;
+        static const wxWindowID ID_BUTTON8;
+        static const wxWindowID ID_CHECKBOX1;
+        static const wxWindowID ID_PANEL1;
+        static const wxWindowID ID_SCROLLBAR1;
+        static const wxWindowID ID_STATICTEXT2;
+        static const wxWindowID ID_STATICTEXT3;
+        static const wxWindowID ID_STATICTEXT4;
+        static const wxWindowID ID_STATICTEXT5;
+        static const wxWindowID ID_STATICTEXT6;
+        static const wxWindowID ID_STATICTEXT7;
+        static const wxWindowID ID_STATICTEXT8;
+        static const wxWindowID ID_STATICTEXT9;
+        static const wxWindowID ID_STATICTEXT10;
+        static const wxWindowID ID_STATICTEXT11;
+        static const wxWindowID ID_STATICTEXT12;
+        static const wxWindowID ID_STATICTEXT13;
+        static const wxWindowID ID_STATICTEXT14;
+        static const wxWindowID ID_TEXTCTRL1;
+        static const wxWindowID ID_BUTTON3;
+        static const wxWindowID ID_BUTTON2;
+        static const wxWindowID ID_STATICTEXT15;
+        static const wxWindowID ID_TIMER1;
+        static const wxWindowID ID_MENUITEM2;
+        static const wxWindowID ID_MENUITEM1;
+        static const wxWindowID ID_MENUITEM3;
+        static const wxWindowID ID_MENUITEM4;
+        static const wxWindowID ID_MENUITEM5;
+        static const wxWindowID ID_MENUITEM6;
+        static const wxWindowID ID_MENUITEM7;
+        static const wxWindowID ID_MENUITEM8;
+        static const wxWindowID ID_MENUITEM9;
+        static const wxWindowID ID_MENUITEM11;
+        static const wxWindowID ID_MENUITEM12;
+        static const wxWindowID ID_MENUITEM13;
+        static const wxWindowID ID_MENUITEM14;
+        static const wxWindowID ID_MENUITEM15;
+        static const wxWindowID ID_MENUITEM16;
+        static const wxWindowID ID_MENUITEM17;
+        static const wxWindowID ID_MENUITEM18;
+        static const wxWindowID ID_MENUITEM32;
+        static const wxWindowID ID_MENUITEM10;
+        static const wxWindowID ID_MENUITEM20;
+        static const wxWindowID ID_MENUITEM21;
+        static const wxWindowID ID_MENUITEM22;
+        static const wxWindowID ID_MENUITEM23;
+        static const wxWindowID ID_MENUITEM24;
+        static const wxWindowID ID_MENUITEM25;
+        static const wxWindowID ID_MENUITEM26;
+        static const wxWindowID ID_MENUITEM27;
+        static const wxWindowID ID_MENUITEM19;
+        static const wxWindowID ID_MENUITEM29;
+        static const wxWindowID ID_MENUITEM30;
+        static const wxWindowID ID_MENUITEM31;
+        static const wxWindowID ID_MENUITEM33;
+        static const wxWindowID ID_MENUITEM28;
         //*)
 
         //(*Handlers(HexEditPanel)
