@@ -14,9 +14,7 @@
 #include "TextCtrl.h"
 
 #include <wx/clipbrd.h>
-#if wxCHECK_VERSION(3, 0, 0)
-    #include <wx/dcsvg.h>
-#endif
+#include <wx/dcsvg.h>
 #include <wx/wfstream.h>
 
 #if wxUSE_POSTSCRIPT
@@ -1006,7 +1004,7 @@ NassiBrick *NassiView::GenerateNewBrick(NassiTools tool)
         case NASSI_TOOL_RETURN:
             brick = new NassiReturnBrick();
             brick->SetTextByNumber( _("returning 0"), 0);
-            brick->SetTextByNumber( _("NULL"), 1);
+            brick->SetTextByNumber( "NULL", 1);
             break;
         case NASSI_TOOL_WHILE:
             brick = new NassiWhileBrick();
@@ -1214,7 +1212,9 @@ HooverDrawlet *NassiView::OnDragOver(const wxPoint &pos, wxDragResult &def, bool
 
 void NassiView::ExportCSource()
 {
-    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""), _("C sources (*.c)|*.c"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""),
+                     _("C sources (*.c)|*.c"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() != wxID_OK ) return;
     wxString filename = dlg.GetPath();
     if ( filename.empty() ) return;
@@ -1275,7 +1275,9 @@ void NassiView::ExportVHDLSource(){}
 
 void NassiView::ExportStrukTeX()
 {
-    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""), _("LaTeX files (*.tex)|*.tex"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""),
+                     _("LaTeX files (*.tex)|*.tex"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() != wxID_OK ) return;
     wxString filename = dlg.GetPath();
     if ( filename.empty() ) return;
@@ -1348,7 +1350,9 @@ void NassiView::ExportStrukTeX()
 #if wxUSE_POSTSCRIPT
 void NassiView::ExportPS()
 {
-    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""), _("PostScript files (*.ps)|*.ps"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"), _T(""), _T(""),
+                     _("PostScript files (*.ps)|*.ps"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() != wxID_OK ) return;
     wxString filename = dlg.GetPath();
     if ( filename.empty() ) return;
@@ -1433,10 +1437,11 @@ void NassiView::ExportPS()
 }
 #endif
 
-#if wxCHECK_VERSION(3, 0, 0)
 void NassiView::ExportSVG()
 {
-    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"),_T(""),_T(""),_("SVG files (*.SVG)|*.SVG"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"),_T(""),_T(""),
+                     _("SVG files (*.SVG)|*.SVG"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() != wxID_OK ) return;
     wxString filename = dlg.GetPath();
     if ( filename.empty() ) return;
@@ -1515,11 +1520,12 @@ void NassiView::ExportSVG()
     }
     delete graphFabric;
 }
-#endif
 
 void NassiView::ExportBitmap()
 {
-    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"),_T(""),_T(""),_("PNG files (*.png)|*.png"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    wxFileDialog dlg( m_diagramwindow, _("Choose a file to exporting into"),_T(""),_T(""),
+                     _("PNG files (*.png)|*.png"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+    PlaceWindow(&dlg);
     if ( dlg.ShowModal() != wxID_OK ) return;
     wxString filename = dlg.GetPath();
     if ( filename.empty() ) return;
