@@ -15,11 +15,7 @@ RedLineDrawlet::~RedLineDrawlet()
 
 bool RedLineDrawlet::Draw(wxDC &dc)
 {
-#if wxCHECK_VERSION(3, 0, 0)
     wxRasterOperationMode old_lf = dc.GetLogicalFunction();
-#else
-    int old_lf = dc.GetLogicalFunction();
-#endif
     dc.SetLogicalFunction(wxXOR);
 
     wxPen old_pen = dc.GetPen();
