@@ -2,46 +2,46 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 10864 $
- * $Id: ProjectOptionsManipulatorDlg.cpp 10864 2016-06-09 16:04:27Z mortenmacfly $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/ProjectOptionsManipulator/ProjectOptionsManipulatorDlg.cpp $
+ * $Revision: 13627 $
+ * $Id: ProjectOptionsManipulatorDlg.cpp 13627 2025-03-02 18:17:10Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/ProjectOptionsManipulator/ProjectOptionsManipulatorDlg.cpp $
  */
 
 #include "ProjectOptionsManipulatorDlg.h"
 
 //(*InternalHeaders(ProjectOptionsManipulatorDlg)
-#include <wx/sizer.h>
-#include <wx/stattext.h>
-#include <wx/radiobox.h>
-#include <wx/textctrl.h>
+#include <wx/button.h>
 #include <wx/checkbox.h>
 #include <wx/choice.h>
 #include <wx/intl.h>
-#include <wx/button.h>
+#include <wx/radiobox.h>
+#include <wx/sizer.h>
+#include <wx/stattext.h>
 #include <wx/string.h>
+#include <wx/textctrl.h>
 //*)
 
 //(*IdInit(ProjectOptionsManipulatorDlg)
-const long ProjectOptionsManipulatorDlg::ID_CHO_SCAN = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHO_SCAN_PROJECTS = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_RBO_OPERATION = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHO_OPTION_LEVEL = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_TXT_OPTION_SEARCH = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_BTN_SEARCH_COMPILER_SRC = wxNewId();
-const long ProjectOptionsManipulatorDlg::TD_TXT_OPTION_REPLACE = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_BTN_SEARCH_COMPILER_DEST = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTION_REPLACE_PATTERN = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_RBO_OPTION_SEARCH = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_COMPILER = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_RES_COMPILER = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_COMPILER_PATH = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER_PATH = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_RES_COMP_PATH = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER_LIBS = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_CUSTOM_VAR = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_TXT_CUSTOM_VAR = wxNewId();
-const long ProjectOptionsManipulatorDlg::ID_CHO_TARGET_TYPE = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHO_SCAN = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHO_SCAN_PROJECTS = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_RBO_OPERATION = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHO_OPTION_LEVEL = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_TXT_OPTION_SEARCH = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_BTN_SEARCH_COMPILER_SRC = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::TD_TXT_OPTION_REPLACE = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_BTN_SEARCH_COMPILER_DEST = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTION_REPLACE_PATTERN = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_RBO_OPTION_SEARCH = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_COMPILER = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_RES_COMPILER = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_COMPILER_PATH = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER_PATH = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_RES_COMP_PATH = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_LINKER_LIBS = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHK_OPTIONS_CUSTOM_VAR = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_TXT_CUSTOM_VAR = wxNewId();
+const wxWindowID ProjectOptionsManipulatorDlg::ID_CHO_TARGET_TYPE = wxNewId();
 //*)
 
 #include <wx/choicdlg.h>
@@ -63,20 +63,20 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 {
 	//(*Initialize(ProjectOptionsManipulatorDlg)
 	wxBoxSizer* bszCustomVar;
-	wxStaticText* lblOptionReplace;
-	wxStaticText* lblOptionsLevel;
+	wxBoxSizer* bszMainH;
 	wxBoxSizer* bszOperation;
 	wxBoxSizer* bszScan;
 	wxFlexGridSizer* flsOptions;
 	wxFlexGridSizer* flsReplace;
-	wxStaticText* lblOptionSearch;
-	wxStdDialogButtonSizer* sbzOKCancel;
-	wxStaticBoxSizer* sbsScope;
-	wxStaticBoxSizer* sbsItem;
-	wxBoxSizer* bszMainH;
-	wxStaticText* lblScanColon;
 	wxFlexGridSizer* flsSearch;
+	wxStaticBoxSizer* sbsItem;
+	wxStaticBoxSizer* sbsScope;
+	wxStaticText* lblOptionReplace;
+	wxStaticText* lblOptionSearch;
+	wxStaticText* lblOptionsLevel;
+	wxStaticText* lblScanColon;
 	wxStaticText* lblScanWithin;
+	wxStdDialogButtonSizer* sbzOKCancel;
 
 	Create(parent, id, _("Project Options Plugin"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER, _T("id"));
 	bszMainH = new wxBoxSizer(wxVERTICAL);
@@ -87,7 +87,7 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	m_ChoScan->SetSelection( m_ChoScan->Append(_("Workspace")) );
 	m_ChoScan->Append(_("Project"));
 	bszScan->Add(m_ChoScan, 0, wxLEFT|wxEXPAND, 5);
-	lblScanColon = new wxStaticText(this, wxID_ANY, _(":"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	lblScanColon = new wxStaticText(this, wxID_ANY, _T(":"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	bszScan->Add(lblScanColon, 0, wxLEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_ChoScanProjects = new wxChoice(this, ID_CHO_SCAN_PROJECTS, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_CHO_SCAN_PROJECTS"));
 	m_ChoScanProjects->Disable();
@@ -98,15 +98,15 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	bszOperation = new wxBoxSizer(wxVERTICAL);
 	wxString __wxRadioBoxChoices_1[7] =
 	{
-		_("Search for option present"),
-		_("Search for option NOT present"),
-		_("Remove option"),
-		_("Add option"),
-		_("Change option"),
-		_("Remove files w/o target"),
-		_("Replace compiler")
+	    _("Search for option present"),
+	    _("Search for option NOT present"),
+	    _("Remove option"),
+	    _("Add option"),
+	    _("Change option"),
+	    _("Remove files w/o target"),
+	    _("Replace compiler")
 	};
-	m_RboOperation = new wxRadioBox(this, ID_RBO_OPERATION, _("Operation:"), wxDefaultPosition, wxDefaultSize, 7, __wxRadioBoxChoices_1, 1, 0, wxDefaultValidator, _T("ID_RBO_OPERATION"));
+	m_RboOperation = new wxRadioBox(this, ID_RBO_OPERATION, _("Operation:"), wxDefaultPosition, wxDefaultSize, 7, __wxRadioBoxChoices_1, 1, wxRA_SPECIFY_COLS, wxDefaultValidator, _T("ID_RBO_OPERATION"));
 	m_RboOperation->SetSelection(0);
 	bszOperation->Add(m_RboOperation, 0, wxEXPAND, 5);
 	lblOptionsLevel = new wxStaticText(this, wxID_ANY, _("Search for option:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
@@ -125,7 +125,7 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	m_TxtOptionSearch = new wxTextCtrl(this, ID_TXT_OPTION_SEARCH, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TXT_OPTION_SEARCH"));
 	m_TxtOptionSearch->SetToolTip(_("This is the compiler/linker option or path, linker lib or custom var to search for..."));
 	flsSearch->Add(m_TxtOptionSearch, 1, wxEXPAND, 5);
-	m_BtnSearchCompilerSrc = new wxButton(this, ID_BTN_SEARCH_COMPILER_SRC, _("..."), wxDefaultPosition, wxSize(23,23), 0, wxDefaultValidator, _T("ID_BTN_SEARCH_COMPILER_SRC"));
+	m_BtnSearchCompilerSrc = new wxButton(this, ID_BTN_SEARCH_COMPILER_SRC, _T("..."), wxDefaultPosition, wxSize(23,23), 0, wxDefaultValidator, _T("ID_BTN_SEARCH_COMPILER_SRC"));
 	m_BtnSearchCompilerSrc->Disable();
 	m_BtnSearchCompilerSrc->SetToolTip(_("Select compiler to search for"));
 	flsSearch->Add(m_BtnSearchCompilerSrc, 0, wxLEFT|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
@@ -137,7 +137,7 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	m_TxtOptionReplace = new wxTextCtrl(this, TD_TXT_OPTION_REPLACE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("TD_TXT_OPTION_REPLACE"));
 	m_TxtOptionReplace->Disable();
 	flsReplace->Add(m_TxtOptionReplace, 1, wxEXPAND, 5);
-	m_BtnSearchCompilerDest = new wxButton(this, ID_BTN_SEARCH_COMPILER_DEST, _("..."), wxDefaultPosition, wxSize(23,23), 0, wxDefaultValidator, _T("ID_BTN_SEARCH_COMPILER_DEST"));
+	m_BtnSearchCompilerDest = new wxButton(this, ID_BTN_SEARCH_COMPILER_DEST, _T("..."), wxDefaultPosition, wxSize(23,23), 0, wxDefaultValidator, _T("ID_BTN_SEARCH_COMPILER_DEST"));
 	m_BtnSearchCompilerDest->Disable();
 	m_BtnSearchCompilerDest->SetToolTip(_("Select compiler to replace with"));
 	flsReplace->Add(m_BtnSearchCompilerDest, 0, wxLEFT|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
@@ -149,8 +149,8 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	sbsItem->Add(m_ChkOptionReplacePattern, 0, wxTOP|wxLEFT|wxRIGHT|wxEXPAND, 5);
 	wxString __wxRadioBoxChoices_2[2] =
 	{
-		_("Search for \"equals option\""),
-		_("Search for \"contains option\"")
+	    _("Search for \"equals option\""),
+	    _("Search for \"contains option\"")
 	};
 	m_RboOptionSearch = new wxRadioBox(this, ID_RBO_OPTION_SEARCH, _("When searching..."), wxDefaultPosition, wxDefaultSize, 2, __wxRadioBoxChoices_2, 1, 0, wxDefaultValidator, _T("ID_RBO_OPTION_SEARCH"));
 	m_RboOptionSearch->SetSelection(0);
@@ -198,16 +198,17 @@ ProjectOptionsManipulatorDlg::ProjectOptionsManipulatorDlg(wxWindow* parent,wxWi
 	sbzOKCancel->AddButton(new wxButton(this, wxID_OK, wxEmptyString));
 	sbzOKCancel->AddButton(new wxButton(this, wxID_CANCEL, wxEmptyString));
 	sbzOKCancel->Realize();
+	dynamic_cast <wxButton *> (this->FindWindow(wxID_OK))->SetDefault();
 	bszMainH->Add(sbzOKCancel, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);
 	SetSizer(bszMainH);
-	bszMainH->Fit(this);
 	bszMainH->SetSizeHints(this);
+	Center();
 
-	Connect(ID_CHO_SCAN,wxEVT_COMMAND_CHOICE_SELECTED,wxCommandEventHandler(ProjectOptionsManipulatorDlg::OnScanSelect));
-	Connect(ID_RBO_OPERATION,wxEVT_COMMAND_RADIOBOX_SELECTED,wxCommandEventHandler(ProjectOptionsManipulatorDlg::OnOperationSelect));
-	Connect(ID_BTN_SEARCH_COMPILER_SRC,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(ProjectOptionsManipulatorDlg::OnSearchCompilerClick));
-	Connect(ID_BTN_SEARCH_COMPILER_DEST,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(ProjectOptionsManipulatorDlg::OnSearchCompilerClick));
-	Connect(ID_CHO_TARGET_TYPE,wxEVT_COMMAND_CHOICE_SELECTED,wxCommandEventHandler(ProjectOptionsManipulatorDlg::OnTargetTypeSelect));
+	Connect(ID_CHO_SCAN, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction)&ProjectOptionsManipulatorDlg::OnScanSelect);
+	Connect(ID_RBO_OPERATION, wxEVT_COMMAND_RADIOBOX_SELECTED, (wxObjectEventFunction)&ProjectOptionsManipulatorDlg::OnOperationSelect);
+	Connect(ID_BTN_SEARCH_COMPILER_SRC, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction)&ProjectOptionsManipulatorDlg::OnSearchCompilerClick);
+	Connect(ID_BTN_SEARCH_COMPILER_DEST, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction)&ProjectOptionsManipulatorDlg::OnSearchCompilerClick);
+	Connect(ID_CHO_TARGET_TYPE, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction)&ProjectOptionsManipulatorDlg::OnTargetTypeSelect);
 	//*)
 }
 
@@ -406,6 +407,7 @@ void ProjectOptionsManipulatorDlg::OnSearchCompilerClick(wxCommandEvent& event)
    }
 
    wxSingleChoiceDialog choose_dlg(this, _T("Available compilers"), _T("Choose a new compiler"), compiler_array);
+   PlaceWindow(&choose_dlg);
    if (choose_dlg.ShowModal() == wxID_OK)
    {
      if      (event.GetId() == ID_BTN_SEARCH_COMPILER_SRC)
