@@ -4,9 +4,9 @@
  *
  * Copyright: 2010 Jens Lody
  *
- * $Revision: 11477 $
- * $Id: ReopenEditor.h 11477 2018-09-29 07:42:08Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/ReopenEditor/ReopenEditor.h $
+ * $Revision: 12887 $
+ * $Id: ReopenEditor.h 12887 2022-09-10 10:32:25Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/ReopenEditor/ReopenEditor.h $
  */
 
 #ifndef REOPEN_EDITOR_H_INCLUDED
@@ -61,7 +61,11 @@ class ReopenEditor : public cbPlugin
         bool m_IsManaged;
         /// We need this to live longer than the logger, because the InfoPane stores a pointer to
         /// this icon.
+#if wxCHECK_VERSION(3, 1, 6)
+        wxBitmapBundle m_LogIcon;
+#else
         wxBitmap m_LogIcon;
+#endif
 
     DECLARE_EVENT_TABLE()
 };
