@@ -309,7 +309,7 @@ TextParser* get_parser(int format, const char* extension, Hunspell* pMS) {
     const std::vector<w_char>& vec_wordchars_utf16 = pMS->get_wordchars_utf16();
     const std::string& vec_wordchars = pMS->get_wordchars_cpp();
     wordchars_utf16_len = vec_wordchars_utf16.size();
-    wordchars_utf16 = wordchars_utf16_len ? &vec_wordchars_utf16[0] : NULL;
+    wordchars_utf16 = wordchars_utf16_len ? vec_wordchars_utf16.data() : NULL;
     if ((strcmp(denc, "UTF-8") != 0) && !vec_wordchars.empty()) {
       const char* wchars = vec_wordchars.c_str();
       size_t c1 = vec_wordchars.size();
@@ -325,7 +325,7 @@ TextParser* get_parser(int format, const char* extension, Hunspell* pMS) {
         iconv_close(conv);
         u8_u16(new_wordchars_utf16, text_conv);
         std::sort(new_wordchars_utf16.begin(), new_wordchars_utf16.end());
-        wordchars_utf16 = &new_wordchars_utf16[0];
+        wordchars_utf16 = new_wordchars_utf16.data();
         wordchars_utf16_len = new_wordchars_utf16.size();
       }
     }
@@ -391,7 +391,7 @@ TextParser* get_parser(int format, const char* extension, Hunspell* pMS) {
 #else
   if (strcmp(denc, "UTF-8") == 0) {
     const std::vector<w_char>& vec_wordchars_utf16 = pMS->get_wordchars_utf16();
-    wordchars_utf16 = (vec_wordchars_utf16.size() == 0) ? NULL : &vec_wordchars_utf16[0];
+    wordchars_utf16 = (vec_wordchars_utf16.size() == 0) ? NULL : vec_wordchars_utf16.data();
     wordchars_utf16_len = vec_wordchars_utf16.size();
     io_utf8 = 1;
   } else {
@@ -579,9 +579,9 @@ const char* basename(const char* s, char c) {
 }
 
 #ifdef HAVE_CURSES_H
-char* scanline(char* message) {
+char* scanline(const char* message) {
   char input[INPUTLEN];
-  printw(message);
+  printw("%s", message);
   echo();
   getnstr(input, INPUTLEN);
   noecho();
@@ -1180,9 +1180,9 @@ void dialogscreen(TextParser* parser,
   mvprintw(MAXPREVLINE + 2, 0, "\n");
   for (size_t i = 0; i < wlst.size(); ++i) {
     if ((wlst.size() > 10) && (i < 10)) {
-      printw(" 0%d: %s\n", i, chenc(wlst[i], io_enc, ui_enc).c_str());
+      printw(" 0%zu: %s\n", i, chenc(wlst[i], io_enc, ui_enc).c_str());
     } else {
-      printw(" %d: %s\n", i, chenc(wlst[i], io_enc, ui_enc).c_str());
+      printw(" %u: %s\n", i, chenc(wlst[i], io_enc, ui_enc).c_str());
     }
   }
 
