@@ -24,16 +24,12 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
-// RCS-ID: $Id: codesnippetsapp.cpp 10771 2016-02-06 14:29:31Z mortenmacfly $
+// RCS-ID: $Id: codesnippetsapp.cpp 13441 2024-02-01 07:44:57Z wh11204 $
 
 #ifdef WX_PRECOMP //
 #include "wx_pch.h"
 #endif
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif //__BORLANDC__
-
 #include <wx/stdpaths.h>
 #include <wx/process.h>
 #include <wx/filename.h>
@@ -59,7 +55,6 @@
 #include "codesnippetswindow.h"
 #include "snippetsconfig.h"
 #include "snippetsimages.h"
-#include "GenericMessageBox.h"
 #include "codesnippetsevent.h"
 #include "FileImport.h"
 #include "dragscroll.h"
@@ -170,10 +165,6 @@ int CodeSnippetsApp::OnExit()
 #include "wx_pch.h"
 #endif
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif //__BORLANDC__
-
 
 // ----------------------------------------------------------------------------
 //helper functions
@@ -438,7 +429,7 @@ void CodeSnippetsAppFrame::InitCodeSnippetsAppFrame(wxFrame *frame, const wxStri
                 wxString msg = wxT("Another CodeSnippets is already running from this folder.\n");
                 msg << _T("Starting multiple CodeSnippets could scramble this configuration file.\n");
                 msg << _T("Run multiple CodeSnippets anyway?\n");
-                int answer = GenericMessageBox( msg, _T("Multiple CodeSnippets"),wxYES_NO );
+                int answer = wxMessageBox( msg, _T("Multiple CodeSnippets"),wxYES_NO );
                 if ( answer == wxYES)
                     break;
 
@@ -580,7 +571,7 @@ void CodeSnippetsAppFrame::InitCodeSnippetsAppFrame(wxFrame *frame, const wxStri
          #endif
         if ( not ::wxFileExists(m_KeepAliveFileName) )
         {
-            GenericMessageBox(wxString::Format(wxT("Error: Did not find KeepAlive File[%s]"), m_KeepAliveFileName.GetData() ));
+            wxMessageBox(wxString::Format(wxT("Error: Did not find KeepAlive File[%s]"), m_KeepAliveFileName.GetData() ));
             m_KeepAliveFileName = wxEmptyString;
             break;
         }
@@ -786,7 +777,7 @@ void CodeSnippetsAppFrame::OnFileLoad(wxCommandEvent& event)
     // Save any previously modified file
     if ( GetFileChanged() )
     {    // Ask users if they want to save the snippet xml file
-        int answer = GenericMessageBox( wxT("Save Snippets file?\n\n")+GetConfig()->SettingsSnippetsXmlPath,
+        int answer = wxMessageBox( wxT("Save Snippets file?\n\n")+GetConfig()->SettingsSnippetsXmlPath,
                                                 wxT("Open"),wxYES_NO );
         if ( answer == wxYES)
         {
@@ -1225,7 +1216,11 @@ bool CodeSnippetsAppFrame::LoadConfig()
 
     if(platform::windows)
     {
+#ifdef CB_AUTOCONF
+        data = GetAppPath() + _T("/..");
+#else
         data.assign(GetAppPath());
+#endif
     }
     else if(platform::macosx)
     {
