@@ -92,11 +92,7 @@ cbDragScrollCfg::cbDragScrollCfg(wxWindow* parent, cbDragScroll* pOwner, wxWindo
 	bSizer7->Add( StaticText3, 0, wxALIGN_CENTER_HORIZONTAL|wxALL, 5 );
 
 	Sensitivity = new wxSlider( this, wxID_ANY, 8, 1, 10, wxDefaultPosition, wxDefaultSize, wxSL_AUTOTICKS|wxSL_HORIZONTAL|wxSL_LABELS|wxSL_TOP );
-#if wxCHECK_VERSION(3, 0, 0)
 	if ( 1 ) Sensitivity->SetTickFreq(1);
-#else
-	if ( 1 ) Sensitivity->SetTickFreq(1,0);
-#endif
 	if ( 1 ) Sensitivity->SetPageSize(1);
 	if ( 0 ) Sensitivity->SetLineSize(0);
 	if ( 0 ) Sensitivity->SetThumbLength(0);
@@ -110,11 +106,7 @@ cbDragScrollCfg::cbDragScrollCfg(wxWindow* parent, cbDragScroll* pOwner, wxWindo
 	bSizer7->Add( StaticText4, 0, wxALIGN_CENTER_HORIZONTAL|wxALL, 5 );
 
 	MouseToLineRatio = new wxSlider( this, wxID_ANY, 30, 10, 100, wxDefaultPosition, wxDefaultSize, wxSL_AUTOTICKS|wxSL_HORIZONTAL|wxSL_LABELS|wxSL_TOP );
-#if wxCHECK_VERSION(3, 0, 0)
 	if ( 1 ) MouseToLineRatio->SetTickFreq(10);
-#else
-	if ( 1 ) MouseToLineRatio->SetTickFreq(10,10);
-#endif
 	if ( 1 ) MouseToLineRatio->SetPageSize(10);
 	if ( 0 ) MouseToLineRatio->SetLineSize(0);
 	if ( 0 ) MouseToLineRatio->SetThumbLength(0);
@@ -129,11 +121,7 @@ cbDragScrollCfg::cbDragScrollCfg(wxWindow* parent, cbDragScroll* pOwner, wxWindo
 
 	MouseContextDelay = new wxSlider( this, wxID_ANY, 50, 10, 500, wxDefaultPosition, wxDefaultSize, wxSL_AUTOTICKS|wxSL_HORIZONTAL|wxSL_LABELS|wxSL_TOP );
 	// Above values are: default mil delay, min, max
-#if wxCHECK_VERSION(3, 0, 0)
 	if ( 1 ) MouseContextDelay->SetTickFreq(10);
-#else
-	if ( 1 ) MouseContextDelay->SetTickFreq(10,10);
-#endif
 	if ( 1 ) MouseContextDelay->SetPageSize(10);
 	if ( 1 ) MouseContextDelay->SetLineSize(10);
 	if ( 1 ) MouseContextDelay->SetThumbLength(10);
