@@ -5,16 +5,12 @@
  * Copyright: (c) Pecan Heber etal.
  * License:   GPL
  **************************************************************/
-// RCS-ID:      $Id: cbkeybinder.cpp 11983 2020-03-12 18:24:30Z fuscated $
+// RCS-ID:      $Id: cbkeybinder.cpp 13627 2025-03-02 18:17:10Z mortenmacfly $
 
 // The majority of this code was lifted from wxKeyBinder and
 // its "minimal.cpp" sample program
 
-// Modified CodeBlocks KeyBnder v2.0 2019/04/8
-
-#if defined(__GNUG__) && !defined(__APPLE__)
-    #pragma implementation "cbkeybinder.h"
-#endif
+// Modified CodeBlocks KeyBnder 2020/04/7
 
 #include <vector>
 
@@ -37,11 +33,13 @@
 #include <wx/xrc/xmlres.h>
 #include <wx/fileconf.h>
 #include <wx/event.h>
-#if defined(__WXMSW__) && wxCHECK_VERSION(3, 0, 0)
+#if defined(__WXMSW__)
     #include <wx/msw/private/keyboard.h>
 #endif
 #include <wx/listbook.h>
+#include <wx/clipbrd.h>
 
+#include "globals.h"
 #include "logmanager.h"
 #if defined(LOGGING)
     #include "debugging.h"
@@ -70,6 +68,8 @@ namespace
 BEGIN_EVENT_TABLE(cbKeyBinder, cbPlugin)
     // add events here...
 
+    // This event issued from another plugin to request KeyBinder to refresh its key shortcuts database.
+    // It happens at CB startup and plugin enable/disable/install/uninstall if the menus change.
     EVT_MENU (idKeyBinderRefresh, cbKeyBinder::OnKeyBinderRefreshRequested)
 
 END_EVENT_TABLE()
@@ -155,53 +155,12 @@ void cbKeyBinder::OnRelease(bool /*appShutDown*/)
     // which means you must not use any of the SDK Managers
     // NB: after this function, the inherited member variable
     // IsAttached() will be FALSE...
-}
-// ----------------------------------------------------------------------------
-void cbKeyBinder::OnConfigListbookClose(wxEvent& event)
-// ----------------------------------------------------------------------------
-{
-    // The Editor configuration dialog is being destroyed.
-    // Remove this routines connected events to that dialog.
-
-
-    wxWindow* pWindow = (wxWindow*)(event.GetEventObject());
-    if (pWindow == m_pConfigListbook)
+    if (m_pKBMgr)   //(ph 2023/03/04)
     {
-        pWindow->GetEventHandler()->Disconnect(XRCID("nbMain"), wxEVT_LISTBOOK_PAGE_CHANGED, wxListbookEventHandler( cbKeyBinder::OnConfigListbookEvent), NULL, this);
-        pWindow->GetEventHandler()->Disconnect(XRCID("nbMain"), wxEVT_DESTROY, wxEventHandler( cbKeyBinder::OnConfigListbookClose), NULL, this);
-        // Dont event.Skip(). causes crash
-        return;
+        // Release() will invoke pKBMgr->Save() to write final KeyBinder.conf file data;
+        m_pKBMgr->Release();
     }
 
-    event.Skip();
-
-}//OnWindowClose
-// ----------------------------------------------------------------------------
-void cbKeyBinder::OnConfigListbookEvent(wxListbookEvent& event)
-// ----------------------------------------------------------------------------
-{
-    // This event occurs when the user clicks on MainMenu/Settings/Editor/Keyboard shortccuts .
-    // This routine will call phaseII to complete the setting dialog
-    // by scanning the menu structure and merging the user defined shortcuts.
-    // It will then display a menu tree and allow the user to modify the menu and global key shortcuts.
-
-    event.Skip();
-
-    if ( (event.GetEventType() == wxEVT_LISTBOOK_PAGE_CHANGED))
-    {
-        int sel = event.GetSelection();
-        wxListbook* plb = (wxListbook*)event.GetEventObject();
-        wxString label = plb->GetPageText(sel);
-        if (label == _("Keyboard shortcuts") )
-        {
-            wxMenuBar* pMenuBar = Manager::Get()->GetAppFrame()->GetMenuBar();
-            m_pUsrConfigPanel->Freeze();    // dont show panel updating
-            m_pUsrConfigPanel->GetKeyConfigPanelPhaseII(pMenuBar, m_pUsrConfigPanel, m_mode);
-            m_pUsrConfigPanel->Thaw();      // unfreeze updates
-        }
-    }
-
-    return;
 }
 // ----------------------------------------------------------------------------
 //  cbKeyBinder GetConfigurationPanel()  //phaseI
@@ -210,19 +169,13 @@ cbConfigurationPanel* cbKeyBinder::GetConfigurationPanel(wxWindow* parent)
 {
     // This routine will create a minimal configuration panel for
     // the Editor configuration 'Keyboard shortcuts' dialog. The actual work
-    // for this panel will done in GetConfigurationPanePhaseII() if the user
+    // for this panel will be done in GetKeyConfigPanelPhaseII() when the user
     // clicks on MainMenu\Settings\Editor\Keyboard shortcuts.
-    // See OnConfigListbookEvent().
+    // See OnPageChanging().
 
     //create and display the configuration dialog for your plugin
     if(not IsAttached()) { return nullptr;}
 
-    // Note : parent == wxListbook* lb = XRCCTRL(*this, "nbMain", wxListbook);
-    // cf., editorconfiguration.cpp
-    m_pConfigListbook = (wxListbook*)parent;
-    parent->GetEventHandler()->Connect(XRCID("nbMain"), wxEVT_LISTBOOK_PAGE_CHANGED, wxListbookEventHandler( cbKeyBinder::OnConfigListbookEvent), NULL, this);
-    parent->GetEventHandler()->Connect(XRCID("nbMain"), wxEVT_DESTROY, wxEventHandler( cbKeyBinder::OnConfigListbookClose), NULL, this);
-
     // Create a Configurtion panel and return it to CodeBlocks
     // The commented lines below are from the original wxKeyBinder
     // They may be useful later
@@ -362,7 +315,16 @@ void cbKeyBinder::OnAppStartupDone(CodeBlocksEvent& event)
 
     // Create default keybindings file keyMnuAccels.conf by scanning the app menus.
     bool created = CreateKeyBindDefaultFile(isRefreshRequest);
-    wxUnusedVar(created);
+    //-wxUnusedVar(created);
+    if (not created)
+    {
+        // failure to create Menu scan file. // **Debugging**
+        //SetCallingFunction(__FUNCTION__, __LINE__);
+        //wxString msg= wxString::Format("Failure to create menu scan file at '%s Line:%d'", __PRETTY_FUNCTION__, __LINE__);
+        //-ReportThisFailure("msg"); **Debugging**
+        //ClearCallingFunction();
+        return;
+    }
 
     // Load the menu structure accerators + the user defined accelerators.
     // if no existing cbKeyBinder??.conf, ignore the refresh request to do full keybindings.conf creation.
@@ -399,7 +361,7 @@ void cbKeyBinder::OnKeyBinderRefreshRequested(wxCommandEvent& event)
 // ----------------------------------------------------------------------------
 {
     // a process has issued: wxCommandEvent evt(wxEVT_COMMAND_MENU_SELECTED, XRCID("idKeyBinderRefresh"))
-
+    // or another plugin (eg. keymacs) needs us to refresh our database of key assignments.
     if (m_KeyBinderRefreshRequested)
         return; //already doing the job
 
@@ -408,7 +370,7 @@ void cbKeyBinder::OnKeyBinderRefreshRequested(wxCommandEvent& event)
     if (m_AppStartupDone)
     {
         CodeBlocksEvent cbevt(event.GetEventType(), event.GetId());
-        OnAppStartupDone(cbevt);
+        OnAppStartupDone(cbevt); // this is a local call, not a real event
         m_KeyBinderRefreshRequested = false;
     }
 }
@@ -429,7 +391,7 @@ wxString cbKeyBinder::GetPluginVersion()
 bool cbKeyBinder::CreateKeyBindDefaultFile(bool refresh)
 // ----------------------------------------------------------------------------
 {
-    // FIXME (ph#): Do we really need to used the old KeyBinder scan to create the new
+    // FIXME (ph#): Do we really need to use the old KeyBinder scan to create the new
     // default keybindings or can we just use the routines like clKeyboardManager::DoUpdateMenu()
     // to create the menuMap directly.
 
@@ -521,18 +483,21 @@ bool cbKeyBinder::CreateKeyBindDefaultFile(bool refresh)
             wxDELETE( pKeyProfileArray);
     }
 
-    // If %appdata%\<personality>.cbKeybinder??.conf does not exist
-    // try to convert the previous keybinder plugin versions' keybindings file if available,
+    // If %appdata%\<personality>.cbKeybinder??.conf does not exist, this is first CB installation.
+    // Try to convert the previous keybinder plugin versions' keybindings file if available,
     // currently (as of 2019/05/22) at %appdata%\<appName>\userPersonality.cbKeyBinder10.ini
+    // Note that the previsous version was cbKeyBinder10, not 20.
+    // Note that the file extension is '.ini', not '.conf'
     // The 'refresh' parm refers to a request from external processes to capture new key bindings
     int missingMenuItems = 0;
     if ( (not fnNewcbKeyBinderConf.FileExists()) and (not refresh) )
     {
         wxString plgnVersionString = GetPluginVersion();
-        long plgnVersionNum; plgnVersionString.ToLong(&plgnVersionNum);
-        int oldPlgnVersionNum = plgnVersionNum - 10;
+        long plgnVersionNum;
+        plgnVersionString.ToLong(&plgnVersionNum);
 
-        wxString oldVersionFile = wxString::Format(_T("cbKeyBinder%d.ini"), oldPlgnVersionNum);
+        // long oldPlgnVersionNum = plgnVersionNum - 10;
+        // wxString oldVersionFile = wxString::Format("cbKeyBinder%ld.ini", oldPlgnVersionNum);
         wxFileName fnOldVersionKeyBindings(ConfigManager::GetConfigFolder(), _T("cbKeyBinder10.ini"));
         fnOldVersionKeyBindings.SetName(GetUserPersonality() +_T(".") + fnOldVersionKeyBindings.GetName());
 
@@ -565,7 +530,12 @@ bool cbKeyBinder::CreateKeyBindDefaultFile(bool refresh)
     if (fnTempOldFmtMnuScan.FileExists())
     {
         //Convert menu structure scan into codelite format file keyMnuAccers.conf
-        ConvertMenuScanToKeyMnuAcceratorsConf(fnTempOldFmtMnuScan.GetFullPath(), fnTempKeyMnuAccels.GetFullPath());
+        // returns number of non-matching menu items between menu structure and keybinder file
+        // return -1 if files do not argument files cannot be opened.
+        int unMatched = ConvertMenuScanToKeyMnuAcceratorsConf(fnTempOldFmtMnuScan.GetFullPath(), fnTempKeyMnuAccels.GetFullPath());
+        //-wxUnusedVar(unMatched);
+        if (unMatched == -1) //(ph 2023/07/04)
+            return false;
     }
 
     return true;
@@ -600,15 +570,15 @@ bool cbKeyBinder::OnSaveKbOldFormatCfgFile(wxKeyProfileArray* pKeyProfArr, wxStr
     if ((ok = pKeyProfArr->Save(cfg, wxEmptyString, TRUE)))
      {
         // get the cmd count
+        #if defined(LOGGING)
         int total = 0;
         for (int i=0; i<pKeyProfArr->GetCount(); i++)
             total += pKeyProfArr->Item(i)->GetCmdCount();
-        cfg->Flush();
-        #if defined(LOGGING)
-            LOGIT(wxString::Format(wxT("All the [%d] keyprofiles ([%d] commands ")
+        LOGIT(wxString::Format(wxT("All the [%d] keyprofiles ([%d] commands ")
             wxT("in total) have been saved in \n") + fnKeyBinderCfg.GetFullPath(),
-              pKeyProfArr->GetCount(), total) );
+            pKeyProfArr->GetCount(), total) );
         #endif
+        cfg->Flush();
 
     }//endif Save
     else
@@ -640,7 +610,7 @@ int cbKeyBinder::ConvertMenuScanToKeyMnuAcceratorsConf(wxString keybinderFile, w
     if (not fncbkbini.FileExists())
     {
         wxASSERT_MSG(0, wxT("ConvertMenuScanToKeyMnuAcceratorsConf() called, but file does not exist."));
-        return false;
+        return -1;
     }
     // remove old KeyMnuAccels.conf
     if (fnclaccconf.FileExists())
@@ -708,15 +678,16 @@ int cbKeyBinder::ConvertMenuScanToKeyMnuAcceratorsConf(wxString keybinderFile, w
 
     if (missingMenuItems)
     {
-        wxString msg = wxString::Format(_("Convert found %u unmatched menu items."), (unsigned)missingMenuItems);
         #if defined(LOGGING)
+            //wxString msg = wxString::Format(_("Convert found %u unmatched menu items."), (unsigned)missingMenuItems);
             //cbMessageBox(msg, _("Converter"), wxOK, Manager::Get()->GetAppWindow());
         #endif
-        return missingMenuItems;
     }
 
     // Merge the CodeBlocks accerator table into the keyMnuAccels file.
+    SetCallingFunction(__FUNCTION__, __LINE__);
     MergeAcceleratorTable(txtacc );
+    ClearCallingFunction();
 
     return 0;
 
@@ -883,15 +854,16 @@ int cbKeyBinder::ConvertOldKeybinderIniToAcceratorsConf(wxString oldKeybinderFil
 
     if (missingMenuItems)
     {
-        wxString msg = wxString::Format(_T("KeyBinder Convert found %u unmatched menu items."), (unsigned)missingMenuItems);
         #if defined(LOGGING)
+            wxString msg = wxString::Format(_T("KeyBinder Convert found %u unmatched menu items."), (unsigned)missingMenuItems);
             LOGIT( _T("[%s]"), msg.wx_str());
         #endif
-        //-return missingMenuItems; deprecated; ok if some items missing
     }
 
     // Merge CodeBlocks global AcceratorTable into the new keyMnuAccels.conf file.
+    SetCallingFunction(__FUNCTION__, __LINE__);
     MergeAcceleratorTable(txtacc );
+    ClearCallingFunction();
 
     return 0;
 
@@ -902,10 +874,23 @@ bool cbKeyBinder::MergeAcceleratorTable(wxTextFile& textOutFile)
 {
     // Get Codeblocks main.cpp Accelerator entries.
 
+    /// Deprecated for now 2023/07/5
+    // It's causing key binding errors because the globals have duplicate id's
+    // that also match menu items, thus overriding them.
+
+    return false; //(ph 2023/07/05)
+
     // Verify output file exists.
     if (not textOutFile.IsOpened())
+    {
         if (not textOutFile.Open())
+        {
+            // **Debugging**
+            //wxString msg= wxString::Format("Global shorcut Failure at '%s Line:%d'", __PRETTY_FUNCTION__, __LINE__);
+            //ReportThisFailure(msg);
             return false;
+        }
+    }
 
     std::vector<wxAcceleratorEntry> globalAccels; //To be filled by main.cpp
 
@@ -919,7 +904,13 @@ bool cbKeyBinder::MergeAcceleratorTable(wxTextFile& textOutFile)
     LOGIT( _T("MergeAcceleratorTable() found %d global accelerators."), accelCount);
     #endif
 
-    if (not accelCount) return false;
+    if (not accelCount)
+    {
+        // **Debugging**
+        //wxString msg= wxString::Format("Global shorcut Failure at %s:%d", __PRETTY_FUNCTION__, __LINE__);
+        //ReportThisFailure(msg);
+        return false;
+    }
 
     // Format each global accelerator to be acceptable by clKeyboardManager.
     for (int ii = 0; ii<accelCount; ++ii)
@@ -1193,8 +1184,29 @@ wxArrayString cbKeyBinder::GetArrayFromStrings(const wxString& text, const wxStr
             part.Trim(false);
             part.Trim(true);
         }
-        //-if (!part.IsEmpty()) keybinder needs the empty strings
             out.Add(part);
     }
     return out;
 }
+// ----------------------------------------------------------------------------
+void cbKeyBinder::ReportThisFailure(const wxString& text)
+// ----------------------------------------------------------------------------
+{
+    wxString clipBrdText = text;
+    clipBrdText << "\nCaller: " << callingFunction;
+
+    wxString msg = "The following message has been placed in the clipBoard." ;
+    msg << "\n Please report this message by pasting it to a CodeBlocks forum message" ;
+    msg << "\n at https://forums.codeblocks.org/";
+    msg << "\n\n" << clipBrdText;
+
+
+    if (wxTheClipboard->Open())
+    {
+        wxTheClipboard->SetData(new wxTextDataObject(clipBrdText));
+        wxTheClipboard->Close();
+    }
+
+    cbMessageBox(msg, "Keybinder Failure", wxOK, Manager::Get()->GetAppWindow());
+    return ;
+}
