@@ -7,20 +7,13 @@
 // Copyright:   (c) Francesco Montorsi
 // Licence:     wxWidgets licence
 /////////////////////////////////////////////////////////////////////////////
-// RCS-ID:      $Id: menuutils.cpp 11980 2020-03-12 18:24:19Z fuscated $
+// RCS-ID:      $Id: menuutils.cpp 13627 2025-03-02 18:17:10Z mortenmacfly $
 
 // menuutils for KeyBinder v2.0 2019/04/8
-#ifdef __GNUG__
-#pragma implementation "menuutils.h"
-#endif
 
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
@@ -121,7 +114,7 @@ int FindMenuDuplicateItems(wxMenu* pMenu, wxString& rStr, int& rCount)
         if (wxMenuCmd::IsNumericMenuItem(pMenuItem)) continue;
 
         // Find matching menu item in keybinder array of commands
-        wxString menuItemLabel = pMenuItem->GetItemLabelText().Trim();
+        // wxString menuItemLabel = pMenuItem->GetItemLabelText().Trim();
         if (rStr == pMenuItem->GetItemLabelText().Trim() )
         {    rCount++;
             #if defined(LOGGING)
@@ -177,11 +170,7 @@ wxString GetFullMenuPath(int id)
         wxMenu* pBarMenu = pbar->GetMenu(i);
         if ( pBarMenu == pMenu)
         {
-            #if wxCHECK_VERSION(3, 0, 0)
             fullMenuPath.Prepend( pbar->GetMenuLabel(i) + wxT("\\"));
-            #else
-            fullMenuPath.Prepend( pbar->GetLabelTop(i) + wxT("\\"));
-            #endif
             //wxLogMessage( _T("ParentMenu[%s]"),pbar->GetLabelTop(i).c_str() );
         }
     }
@@ -304,11 +293,7 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) //for __WXGTK__
     if (IsNumericMenuItem(pLclMnuItem))
       return;
 
-#if wxCHECK_VERSION(3, 0, 0)
     wxString strText = pLclMnuItem->GetItemLabel();
-#else
-    wxString strText = pLclMnuItem->GetText();
-#endif
 
     // *bug* 2007/01/19 v1.0.15
     // Dont use  GetLabel to re-establish the menu text. It doesn't
@@ -341,11 +326,7 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) //for __WXGTK__
 
         // no more shortcuts for this menuitem: SetText()
         // will delete the hotkeys associated...
-#if wxCHECK_VERSION(3, 0, 0)
         pLclMnuItem->SetItemLabel(str);
-#else
-        pLclMnuItem->SetText(str);
-#endif
         return;
     }
 
@@ -354,14 +335,8 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) //for __WXGTK__
     wxLogMessage(_("wxMenuCmd::Update - setting the new text to [%s]"), newtext.c_str());
     #endif
 
-
     // on GTK, the SetAccel() function doesn't have any effect...
-#if wxCHECK_VERSION(3, 0, 0)
     pLclMnuItem->SetItemLabel(newtext);
-#else
-    pLclMnuItem->SetText(newtext);
-#endif
-
 #ifdef __WXGTK20__
 
     //   gtk_menu_item_set_accel_path(GTK_MENU_ITEM(m_pItem), wxGTK_CONV(newtext));
@@ -395,11 +370,7 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) // for __WXMSW__
     if (IsNumericMenuItem(pLclMnuItem))
       return;
 
-    #if wxCHECK_VERSION(3, 0, 0)
     wxString strText = pLclMnuItem->GetItemLabel();
-    #else
-    wxString strText = pLclMnuItem->GetText();
-    #endif
     //use full text to get label in order to preserve mnemonics/accelerators
     wxString strLabel = strText.BeforeFirst(_T('\t'));
     wxString newtext = strLabel; //no accel, contains mnemonic
@@ -412,14 +383,10 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) // for __WXMSW__
          wxLogMessage(_("wxMenuCmd::Update - Removing shortcuts [%d][%s] for [%d][%s]"),pLclMnuItem->GetId(), strText.wx_str(), m_nId, newtext.wx_str());
         #endif
         // set "non bitmapped" text to preserve menu width
-        #if wxCHECK_VERSION(3, 0, 0)
         pLclMnuItem->SetItemLabel(newtext);
-        #else
-        pLclMnuItem->SetText(newtext);
-        #endif
-         //now rebuild the menuitem if bitmapped
-         if (pLclMnuItem->GetBitmap().GetWidth())
-             pLclMnuItem = RebuildMenuitem(pLclMnuItem); //+v0.4.6
+        //now rebuild the menuitem if bitmapped
+        if (pLclMnuItem->GetBitmap().GetWidth())
+            pLclMnuItem = RebuildMenuitem(pLclMnuItem); //+v0.4.6
         return;
     }
 
@@ -436,11 +403,7 @@ void wxMenuCmd::Update(wxMenuItem* pSpecificMenuItem) // for __WXMSW__
     #if LOGGING
      wxLogMessage(_("wxMenuCmd::Update - Setting shortcuts for [%d][%s]"), pLclMnuItem->GetId(), newtext.wx_str());
     #endif
-    #if wxCHECK_VERSION(3, 0, 0)
     pLclMnuItem->SetItemLabel(newtext);
-    #else
-    pLclMnuItem->SetText(newtext);
-    #endif
     //now rebuild the menuitem if bitmapped
     if (pLclMnuItem->GetBitmap().GetWidth())
         pLclMnuItem = RebuildMenuitem(pLclMnuItem); //+v0.4.6
@@ -474,11 +437,7 @@ wxMenuItem* wxMenuCmd::RebuildMenuitem(wxMenuItem* pMnuItem)
     int pos = items.IndexOf(pMnuItem);
    // rebuild the menuitem
     wxMenuItem* pnewitem = new wxMenuItem(pMenu, m_nId,
-        #if wxCHECK_VERSION(3, 0, 0)
                 pMnuItem->GetItemLabel(),
-        #else
-                pMnuItem->GetText(),
-        #endif
                 pMnuItem->GetHelp(), pMnuItem->GetKind(),
                 pMnuItem->GetSubMenu() );
     pnewitem->SetBitmap(pMnuItem->GetBitmap() );
@@ -510,11 +469,7 @@ wxMenuItem* wxMenuCmd::RebuildMenuitem(wxMenuItem* pMnuItem)
 bool wxMenuCmd::IsNumericMenuItem(wxMenuItem* pwxMenuItem)   //v0.2
 // ----------------------------------------------------------------------------
 {//v0.2
-    #if wxCHECK_VERSION(3, 0, 0)
     wxString str = pwxMenuItem->GetItemLabel();
-    #else
-    wxString str = pwxMenuItem->GetText();
-    #endif
     if (str.Length() <2) return false;
     if (str.Left(1).IsNumber()) return true;
     if ( (str[0] == '&') && (str.Mid(1,1).IsNumber()) )
@@ -612,11 +567,7 @@ wxCmd *wxMenuCmd::CreateNew(wxString sCmdName, int id)
 bool wxMenuWalker::IsNumericMenuItem(wxMenuItem* pwxMenuItem)   //v0.2
 // ----------------------------------------------------------------------------
 {//v0.2
-    #if wxCHECK_VERSION(3, 0, 0)
     wxString str = pwxMenuItem->GetItemLabel();
-    #else
-    wxString str = pwxMenuItem->GetText();
-    #endif
     if (str.Length() <2) return false;
     if (str.Left(1).IsNumber()) return true;
     if ( (str[0] == '&') && (str.Mid(1,1).IsNumber()) )
@@ -749,11 +700,7 @@ void* wxMenuTreeWalker::OnMenuWalk(wxMenuBar *p, wxMenu *m, void *data)
 
         // and append a new tree branch with the appropriate label
         wxTreeItemId newId = m_pTreeCtrl->AppendItem(*id,
-        #if wxCHECK_VERSION(3, 0, 0)
             wxMenuItem::GetLabelText(p->GetMenuLabel(i)));
-        #else
-            wxMenuItem::GetLabelFromText(p->GetLabelTop(i)));
-        #endif
 
         // menu items contained in the given menu must be added
         // to the just created branch
@@ -826,12 +773,7 @@ void *wxMenuComboListWalker::OnMenuWalk(wxMenuBar *p, wxMenu *m, void *)
             if (p->GetMenu(i) == m)
                 break;
         wxASSERT(i != (int)p->GetMenuCount());
-        #if wxCHECK_VERSION(3, 0, 0)
         toadd = wxMenuItem::GetLabelText(p->GetMenuLabel(i));
-        #else
-        toadd = wxMenuItem::GetLabelFromText(p->GetLabelTop(i));
-        #endif
-
         m_strAcc = toadd;
 
     } else {
