@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 10290 $
-* $Id: libselectdlg.h 10290 2015-05-15 10:58:40Z jenslody $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/lib_finder/libselectdlg.h $
+* $Revision: 13570 $
+* $Id: libselectdlg.h 13570 2024-09-14 05:03:57Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/lib_finder/libselectdlg.h $
 */
 
 #ifndef LIBSELECTDLG_H
@@ -26,13 +26,13 @@
 
 //(*Headers(LibSelectDlg)
 #include "scrollingdialog.h"
-class wxStaticBoxSizer;
-class wxStdDialogButtonSizer;
-class wxCheckListBox;
 class wxBoxSizer;
-class wxStaticText;
-class wxRadioButton;
 class wxCheckBox;
+class wxCheckListBox;
+class wxRadioButton;
+class wxStaticBoxSizer;
+class wxStaticText;
+class wxStdDialogButtonSizer;
 //*)
 
 class LibSelectDlg: public wxScrollingDialog
@@ -64,20 +64,20 @@ class LibSelectDlg: public wxScrollingDialog
 
 		//(*Declarations(LibSelectDlg)
 		wxCheckBox* m_SetupGlobalVars;
+		wxCheckListBox* m_Libraries;
+		wxRadioButton* m_ClearAll;
+		wxRadioButton* m_ClearSelected;
 		wxRadioButton* m_DontClear;
 		wxStaticText* StaticText1;
-		wxRadioButton* m_ClearAll;
-		wxCheckListBox* m_Libraries;
-		wxRadioButton* m_ClearSelected;
 		//*)
 
 		//(*Identifiers(LibSelectDlg)
-		static const long ID_STATICTEXT1;
-		static const long ID_CHECKLISTBOX1;
-		static const long ID_RADIOBUTTON1;
-		static const long ID_RADIOBUTTON2;
-		static const long ID_RADIOBUTTON3;
-		static const long ID_CHECKBOX1;
+		static const wxWindowID ID_STATICTEXT1;
+		static const wxWindowID ID_CHECKLISTBOX1;
+		static const wxWindowID ID_RADIOBUTTON1;
+		static const wxWindowID ID_RADIOBUTTON2;
+		static const wxWindowID ID_RADIOBUTTON3;
+		static const wxWindowID ID_CHECKBOX1;
 		//*)
 
 		//(*Handlers(LibSelectDlg)
