@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 10832 $
-* $Id: processingdlg.cpp 10832 2016-04-17 21:31:19Z jenslody $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/lib_finder/processingdlg.cpp $
+* $Revision: 13551 $
+* $Id: processingdlg.cpp 13551 2024-09-14 04:37:24Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/lib_finder/processingdlg.cpp $
 */
 
 #include "processingdlg.h"
@@ -27,16 +27,15 @@
 #include <wx/dir.h>
 #include <wx/filename.h>
 #include <wx/tokenzr.h>
-#include <wx/filename.h>
 #include <prep.h>
 
 //(*InternalHeaders(ProcessingDlg)
-#include <wx/gauge.h>
-#include <wx/sizer.h>
 #include <wx/button.h>
-#include <wx/string.h>
+#include <wx/gauge.h>
 #include <wx/intl.h>
+#include <wx/sizer.h>
 #include <wx/stattext.h>
+#include <wx/string.h>
 //*)
 
 #include "librarydetectionmanager.h"
@@ -45,9 +44,9 @@
 #include "libselectdlg.h"
 
 //(*IdInit(ProcessingDlg)
-const long ProcessingDlg::ID_STATICTEXT1 = wxNewId();
-const long ProcessingDlg::ID_GAUGE1 = wxNewId();
-const long ProcessingDlg::ID_BUTTON1 = wxNewId();
+const wxWindowID ProcessingDlg::ID_STATICTEXT1 = wxNewId();
+const wxWindowID ProcessingDlg::ID_GAUGE1 = wxNewId();
+const wxWindowID ProcessingDlg::ID_BUTTON1 = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(ProcessingDlg,wxScrollingDialog)
@@ -72,10 +71,10 @@ ProcessingDlg::ProcessingDlg(wxWindow* parent,LibraryDetectionManager& Manager,T
 	StopBtn = new wxButton(this, ID_BUTTON1, _("Stop"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON1"));
 	FlexGridSizer1->Add(StopBtn, 1, wxBOTTOM|wxLEFT|wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	SetSizer(FlexGridSizer1);
-	FlexGridSizer1->Fit(this);
 	FlexGridSizer1->SetSizeHints(this);
+	Center();
 
-	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProcessingDlg::OnButton1Click);
+	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(ProcessingDlg::OnButton1Click));
 	//*)
 }
 
@@ -235,6 +234,7 @@ void ProcessingDlg::ApplyResults(bool addOnly)
     }
 
     LibSelectDlg Dlg( this, Names, addOnly );
+    PlaceWindow(&Dlg);
     Dlg.SetSelections( Selected );
 
     if ( Dlg.ShowModal() == wxID_OK )
