@@ -1915,35 +1915,51 @@ wxPdfDocument::StartTransform()
   SaveGraphicState();
 }
 
+bool
+wxPdfDocument::ScaleX(double sx)
+{
+  return Scale(sx, 100);
+}
+
 bool
 wxPdfDocument::ScaleX(double sx, double x, double y)
 {
   return Scale(sx, 100, x, y);
 }
 
+bool
+wxPdfDocument::ScaleY(double sy)
+{
+  return Scale(100, sy);
+}
+
 bool
 wxPdfDocument::ScaleY(double sy, double x, double y)
 {
   return Scale(100, sy, x, y);
 }
 
+bool
+wxPdfDocument::ScaleXY(double s)
+{
+  return Scale(s, s);
+}
+
 bool
 wxPdfDocument::ScaleXY(double s, double x, double y)
 {
   return Scale(s, s, x, y);
 }
 
+bool
+wxPdfDocument::Scale(double sx, double sy)
+{
+  return Scale(sx, sy, m_x, m_y);
+}
+
 bool
 wxPdfDocument::Scale(double sx, double sy, double x, double y)
 {
-  if (x < 0)
-  {
-    x = m_x;
-  }
-  if (y < 0)
-  {
-    y = m_y;
-  }
   if (sx == 0 || sy == 0)
   {
     wxLogError(wxString(wxS("wxPdfDocument::Scale: ")) +
@@ -1971,16 +1987,28 @@ wxPdfDocument::Scale(double sx, double sy, double x, double y)
   return true;
 }
 
+void
+wxPdfDocument::MirrorH()
+{
+  Scale(-100, 100, m_x, m_y);
+}
+
 void
 wxPdfDocument::MirrorH(double x)
 {
-  Scale(-100, 100, x);
+  Scale(-100, 100, x, m_y);
+}
+
+void
+wxPdfDocument::MirrorV()
+{
+  Scale(100, -100, m_x, m_y);
 }
 
 void
 wxPdfDocument::MirrorV(double y)
 {
-  Scale(100, -100, -1, y);
+  Scale(100, -100, m_x, y);
 }
 
 void
@@ -2014,6 +2042,11 @@ wxPdfDocument::Translate(double tx, double ty)
   Transform(tm);
 }
 
+void
+wxPdfDocument::Rotate(double angle)
+{
+  Rotate(angle, m_x, m_y);
+}
 void
 wxPdfDocument::Rotate(double angle, double x, double y)
 {
@@ -2021,14 +2054,6 @@ wxPdfDocument::Rotate(double angle, double x, double y)
   {
     StartTransform();
   }
-  if (x < 0)
-  {
-    x = m_x;
-  }
-  if (y < 0)
-  {
-    y = m_y;
-  }
   y *= m_k;
   x *= m_k;
   // calculate elements of transformation matrix
@@ -2067,29 +2092,39 @@ wxPdfDocument::Transform( double a, double b, double c, double d, double tx, dou
   Transform(tm);
 }
 
+bool
+wxPdfDocument::SkewX(double xAngle)
+{
+  return Skew(xAngle, 0, m_x, m_y);
+}
+
 bool
 wxPdfDocument::SkewX(double xAngle, double x, double y)
 {
   return Skew(xAngle, 0, x, y);
 }
 
+bool
+wxPdfDocument::SkewY(double yAngle)
+{
+  return Skew(0, yAngle, m_x, m_y);
+}
+
 bool
 wxPdfDocument::SkewY(double yAngle, double x, double y)
 {
   return Skew(0, yAngle, x, y);
 }
 
+bool
+wxPdfDocument::Skew(double xAngle, double yAngle)
+{
+  return Skew(xAngle, yAngle, m_x, m_y);
+}
+
 bool
 wxPdfDocument::Skew(double xAngle, double yAngle, double x, double y)
 {
-  if (x < 0)
-  {
-    x = m_x;
-  }
-  if (y < 0)
-  {
-    y = m_y;
-  }
   if (xAngle <= -90 || xAngle >= 90 || yAngle <= -90 || yAngle >= 90)
   {
     wxLogError(wxString(wxS("wxPdfDocument::Skew: ")) +
