@@ -484,11 +484,7 @@ void wxFlatNotebook::OnNavigationKey(wxNavigationKeyEvent& event)
 		if ( GetParent() )
 		{
 			event.SetCurrentFocus(this);
-			#if wxCHECK_VERSION(3, 0, 0)
 			GetParent()->GetEventHandler()->ProcessEvent(event);
-			#else
-			GetParent()->ProcessEvent(event);
-			#endif
 		}
 	}
 }
