@@ -5,7 +5,7 @@
 // Modified by:
 // Created:
 // Copyright:   (C) 2006, Paolo Gava
-// RCS-ID:      $Id: pie3dchartpoints.cpp 10749 2016-01-31 09:07:41Z mortenmacfly $
+// RCS-ID:      $Id: pie3dchartpoints.cpp 13182 2023-02-01 03:15:11Z ollydbg $
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
@@ -24,10 +24,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include <wx/wxprec.h>
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include <wx/wx.h>
 #endif
@@ -473,7 +469,7 @@ void wxPie3DChartPoints::Draw(
             for ( iData = 0; iData < iDatas; ++ iData )
             {
                 hp->SetPen( *wxBLACK_PEN );
-                hp->SetBrush( wxBrush(GetColor(iData), wxSOLID) );
+                hp->SetBrush( wxBrush(GetColor(iData), wxBRUSHSTYLE_SOLID));
 
                 // Calc radiants
                 percent = (double)(GetYVal(iData) * 100) / (double)ValTot;
@@ -498,7 +494,7 @@ void wxPie3DChartPoints::Draw(
                     hp->SetBrush(
                         wxBrush(wxChartColors::GetDarkColor(
                             GetColor(iData), 15),
-                        wxSOLID)
+                        wxBRUSHSTYLE_SOLID)
                     );
 
                     // Avoid redraw line
