@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7835 $
-* $Id: wxsbitmapcombobox.h 7835 2012-02-22 14:40:26Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsbitmapcombobox.h $
+* $Revision: 13547 $
+* $Id: wxsbitmapcombobox.h 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsbitmapcombobox.h $
 */
 
 #ifndef WXSBITMAPCOMBOBOX_H
@@ -39,18 +39,18 @@ class wxsBitmapComboBox: public wxsWidget
 
     private:
 
-        virtual void        OnBuildCreatingCode();
-        virtual wxObject   *OnBuildPreview(wxWindow* Parent,long Flags);
-        virtual void        OnEnumWidgetProperties(long Flags);
+        virtual void      OnBuildCreatingCode();
+        virtual wxObject* OnBuildPreview(wxWindow* Parent,long _Flags);
+        virtual void      OnEnumWidgetProperties(long _Flags);
 
-                void        FindAllImageLists(wxArrayString &aNames);
-                void        UpdateComboItemList(void);
-                void        ParseComboItem(wxString inSource, wxString &outItem, int &outIndex);
+                void      FindAllImageLists(wxArrayString &aNames);
+                void      UpdateComboItemList(void);
+                void      ParseComboItem(wxString inSource, wxString &outItem, int &outIndex);
 
 
 
-        wxString        mImageList;                 // list to use to select images
-        wxArrayString   mItems;                     // text of drop-down items
+        wxString        mImageList; //!< list to use to select images
+        wxArrayString   mItems;     //!< text of drop-down items
 };
 
 #endif
