@@ -39,9 +39,7 @@ namespace
         WXS_ST(wxFLP_OVERWRITE_PROMPT)
         WXS_ST(wxFLP_SAVE)
         WXS_ST(wxFLP_USE_TEXTCTRL)
-#if wxCHECK_VERSION(3,0,0)
         WXS_ST(wxFLP_SMALL)
-#endif // wxCHECK_VERSION
     WXS_ST_END()
 
 
@@ -94,24 +92,24 @@ void wxsFilePickerCtrl::OnBuildCreatingCode()
 /*! \brief    Build the control preview.
  *
  * \param parent wxWindow*    The parent window.
- * \param flags long                    The control flags.
+ * \param _Flags long                    The control flags.
  * \return wxObject*                     The constructed control.
  *
  */
-wxObject* wxsFilePickerCtrl::OnBuildPreview(wxWindow* Parent,long Flags)
+wxObject* wxsFilePickerCtrl::OnBuildPreview(wxWindow* Parent,long _Flags)
 {
     wxFilePickerCtrl* Preview;
     Preview = new wxFilePickerCtrl(Parent, GetId(), m_sPath, m_sMessage, m_sWildcard, Pos(Parent), Size(Parent), Style());
-    return SetupWindow(Preview,Flags);
+    return SetupWindow(Preview,_Flags);
 }
 
 /*! \brief Enumerate the control's properties.
  *
- * \param flags long    The control flags.
+ * \param _Flags long    The control flags.
  * \return void
  *
  */
-void wxsFilePickerCtrl::OnEnumWidgetProperties(cb_unused long Flags)
+void wxsFilePickerCtrl::OnEnumWidgetProperties(cb_unused long _Flags)
 {
     WXS_SHORT_STRING(wxsFilePickerCtrl, m_sMessage, _("Message"), _T("message"), wxFileSelectorPromptStr, false)
     WXS_SHORT_STRING(wxsFilePickerCtrl, m_sPath, _("Path"), _T("path"), wxEmptyString, false)
