@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10688 $
-* $Id: wxsgauge.cpp 10688 2016-01-22 12:24:56Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsgauge.cpp $
+* $Revision: 13547 $
+* $Id: wxsgauge.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsgauge.cpp $
 */
 
 #include <wx/gauge.h>
@@ -73,15 +73,15 @@ void wxsGauge::OnBuildCreatingCode()
 }
 
 
-wxObject* wxsGauge::OnBuildPreview(wxWindow* Parent,long Flags)
+wxObject* wxsGauge::OnBuildPreview(wxWindow* Parent,long _Flags)
 {
     wxGauge* Preview = new wxGauge(Parent,GetId(),Range,Pos(Parent),Size(Parent),Style());
     if ( Value )  Preview->SetValue(Value);
-    return SetupWindow(Preview,Flags);
+    return SetupWindow(Preview,_Flags);
 }
 
 
-void wxsGauge::OnEnumWidgetProperties(cb_unused long Flags)
+void wxsGauge::OnEnumWidgetProperties(cb_unused long _Flags)
 {
     WXS_LONG(wxsGauge,Value,_("Value"),_T("value"),0)
     WXS_LONG(wxsGauge,Range,_("Range"),_T("range"),100)
