@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10680 $
-* $Id: wxsmenueditor.cpp 10680 2016-01-22 10:43:35Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsmenueditor.cpp $
+* $Revision: 13547 $
+* $Id: wxsmenueditor.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsmenueditor.cpp $
 */
 
 #include "wxsmenueditor.h"
@@ -30,44 +30,47 @@
 #include <prep.h>
 
 //(*InternalHeaders(wxsMenuEditor)
+#include <wx/artprov.h>
+#include <wx/bitmap.h>
+#include <wx/image.h>
 #include <wx/intl.h>
 #include <wx/string.h>
 //*)
 
 //(*IdInit(wxsMenuEditor)
-const long wxsMenuEditor::ID_TREECTRL1 = wxNewId();
-const long wxsMenuEditor::ID_RADIOBUTTON1 = wxNewId();
-const long wxsMenuEditor::ID_RADIOBUTTON4 = wxNewId();
-const long wxsMenuEditor::ID_RADIOBUTTON2 = wxNewId();
-const long wxsMenuEditor::ID_RADIOBUTTON5 = wxNewId();
-const long wxsMenuEditor::ID_RADIOBUTTON3 = wxNewId();
-const long wxsMenuEditor::ID_STATICLINE1 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT6 = wxNewId();
-const long wxsMenuEditor::ID_TEXTCTRL4 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT1 = wxNewId();
-const long wxsMenuEditor::ID_TEXTCTRL1 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT2 = wxNewId();
-const long wxsMenuEditor::ID_TEXTCTRL2 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT3 = wxNewId();
-const long wxsMenuEditor::ID_TEXTCTRL3 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT4 = wxNewId();
-const long wxsMenuEditor::ID_CHECKBOX1 = wxNewId();
-const long wxsMenuEditor::ID_STATICTEXT5 = wxNewId();
-const long wxsMenuEditor::ID_CHECKBOX2 = wxNewId();
-const long wxsMenuEditor::ID_STATICLINE2 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON1 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON2 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON3 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON4 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON5 = wxNewId();
-const long wxsMenuEditor::ID_BUTTON6 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_TREECTRL1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_RADIOBUTTON1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_RADIOBUTTON4 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_RADIOBUTTON2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_RADIOBUTTON5 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_RADIOBUTTON3 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICLINE1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT6 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_TEXTCTRL4 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_TEXTCTRL1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_TEXTCTRL2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT3 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_TEXTCTRL3 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT4 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_CHECKBOX1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICTEXT5 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_CHECKBOX2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_STATICLINE2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON1 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON2 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON3 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON4 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON5 = wxNewId();
+const wxWindowID wxsMenuEditor::ID_BUTTON6 = wxNewId();
 //*)
 
 wxsMenuEditor::wxsMenuEditor(wxWindow* parent,wxsMenuBar* MenuBar):
     m_MenuBar(MenuBar),
-    m_Menu(0),
-    m_First(0),
-    m_Selected(0),
+    m_Menu(nullptr),
+    m_First(nullptr),
+    m_Selected(nullptr),
     m_BlockSel(false),
     m_BlockRead(false)
 {
@@ -77,10 +80,10 @@ wxsMenuEditor::wxsMenuEditor(wxWindow* parent,wxsMenuBar* MenuBar):
 }
 
 wxsMenuEditor::wxsMenuEditor(wxWindow* parent,wxsMenu* Menu):
-    m_MenuBar(0),
+    m_MenuBar(nullptr),
     m_Menu(Menu),
-    m_First(0),
-    m_Selected(0),
+    m_First(nullptr),
+    m_Selected(nullptr),
     m_BlockSel(false),
     m_BlockRead(false)
 {
@@ -93,13 +96,13 @@ void wxsMenuEditor::CreateContent(wxWindow* parent)
 {
     wxWindowID id = wxID_ANY;
     //(*Initialize(wxsMenuEditor)
-    wxStaticBoxSizer* StaticBoxSizer2;
-    wxBoxSizer* BoxSizer2;
-    wxGridSizer* GridSizer1;
     wxBoxSizer* BoxSizer1;
-    wxStaticBoxSizer* StaticBoxSizer1;
-    wxFlexGridSizer* FlexGridSizer1;
+    wxBoxSizer* BoxSizer2;
     wxBoxSizer* BoxSizer3;
+    wxFlexGridSizer* FlexGridSizer1;
+    wxGridSizer* GridSizer1;
+    wxStaticBoxSizer* StaticBoxSizer1;
+    wxStaticBoxSizer* StaticBoxSizer2;
 
     Create(parent, id, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("id"));
     BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
@@ -165,25 +168,24 @@ void wxsMenuEditor::CreateContent(wxWindow* parent)
     StaticLine2 = new wxStaticLine(this, ID_STATICLINE2, wxDefaultPosition, wxSize(10,-1), wxLI_HORIZONTAL, _T("ID_STATICLINE2"));
     StaticBoxSizer2->Add(StaticLine2, 0, wxALL|wxEXPAND, 4);
     BoxSizer2 = new wxBoxSizer(wxHORIZONTAL);
-    Button1 = new wxButton(this, ID_BUTTON1, _("<"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON1"));
-    BoxSizer2->Add(Button1, 1, wxLEFT|wxRIGHT|wxEXPAND, 2);
-    Button2 = new wxButton(this, ID_BUTTON2, _(">"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON2"));
-    BoxSizer2->Add(Button2, 1, wxLEFT|wxRIGHT|wxEXPAND, 2);
-    Button3 = new wxButton(this, ID_BUTTON3, _("^"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON3"));
-    BoxSizer2->Add(Button3, 1, wxLEFT|wxRIGHT|wxEXPAND, 2);
-    Button4 = new wxButton(this, ID_BUTTON4, _("v"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON4"));
-    BoxSizer2->Add(Button4, 1, wxLEFT|wxRIGHT|wxEXPAND, 2);
-    StaticBoxSizer2->Add(BoxSizer2, 0, wxALIGN_CENTER_HORIZONTAL, 4);
-    StaticBoxSizer2->Add(-1,-1,1, wxEXPAND, 5);
+    BitmapButton1 = new wxBitmapButton(this, ID_BUTTON1, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_GO_BACK")),wxART_BUTTON), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_BUTTON1"));
+    BoxSizer2->Add(BitmapButton1, 1, wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+    BitmapButton2 = new wxBitmapButton(this, ID_BUTTON2, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_GO_FORWARD")),wxART_BUTTON), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_BUTTON2"));
+    BoxSizer2->Add(BitmapButton2, 1, wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+    BitmapButton3 = new wxBitmapButton(this, ID_BUTTON3, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_GO_UP")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_BUTTON3"));
+    BoxSizer2->Add(BitmapButton3, 1, wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+    BitmapButton4 = new wxBitmapButton(this, ID_BUTTON4, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_GO_DOWN")),wxART_BUTTON), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_BUTTON4"));
+    BoxSizer2->Add(BitmapButton4, 1, wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+    StaticBoxSizer2->Add(BoxSizer2, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 2);
     BoxSizer3 = new wxBoxSizer(wxHORIZONTAL);
     Button5 = new wxButton(this, ID_BUTTON5, _("New"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON5"));
     BoxSizer3->Add(Button5, 1, wxRIGHT|wxEXPAND, 4);
     Button6 = new wxButton(this, ID_BUTTON6, _("Delete"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON6"));
     BoxSizer3->Add(Button6, 1, wxLEFT|wxEXPAND, 4);
-    StaticBoxSizer2->Add(BoxSizer3, 0, wxALIGN_CENTER_HORIZONTAL, 4);
+    StaticBoxSizer2->Add(BoxSizer3, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 2);
+    StaticBoxSizer2->Add(-1,-1,1, wxEXPAND, 5);
     BoxSizer1->Add(StaticBoxSizer2, 0, wxALL|wxEXPAND, 4);
     SetSizer(BoxSizer1);
-    BoxSizer1->Fit(this);
     BoxSizer1->SetSizeHints(this);
 
     Connect(ID_TREECTRL1,wxEVT_COMMAND_TREE_SEL_CHANGED,wxTreeEventHandler(wxsMenuEditor::OnContentSelectionChanged));
@@ -213,23 +215,23 @@ void wxsMenuEditor::CreateDataCopy()
 {
     if ( m_Menu )
     {
-        CreateDataCopyReq(m_Menu,0);
+        CreateDataCopyReq(m_Menu, nullptr);
     }
     else
     {
-        CreateDataCopyReq(m_MenuBar,0);
+        CreateDataCopyReq(m_MenuBar, nullptr);
     }
 }
 
 void wxsMenuEditor::CreateDataCopyReq(wxsMenu* Menu,MenuItem* Parent)
 {
-    MenuItem* LastChild = 0;
+    MenuItem* LastChild = nullptr;
     for ( int i=0; i<Menu->GetChildCount(); i++ )
     {
         wxsMenuItem* ChildMenu = (wxsMenuItem*)Menu->GetChild(i);
         MenuItem* ChildItem = new MenuItem;
-        ChildItem->m_Next = 0;
-        ChildItem->m_Child = 0;
+        ChildItem->m_Next = nullptr;
+        ChildItem->m_Child = nullptr;
         ChildItem->m_Parent = Parent;
         if ( LastChild )
         {
@@ -246,7 +248,7 @@ void wxsMenuEditor::CreateDataCopyReq(wxsMenu* Menu,MenuItem* Parent)
 
 void wxsMenuEditor::CreateDataCopyReq(wxsMenuBar* Menu,MenuItem* Parent)
 {
-    MenuItem* LastChild = 0;
+    MenuItem* LastChild = nullptr;
     for ( int i=0; i<Menu->GetChildCount(); i++ )
     {
         wxsMenu* ChildMenu = (wxsMenu*)Menu->GetChild(i);
@@ -258,8 +260,8 @@ void wxsMenuEditor::CreateDataCopyReq(wxsMenuBar* Menu,MenuItem* Parent)
         ChildItem->m_Label = ChildMenu->m_Label;
         ChildItem->m_Enabled = true;
         ChildItem->m_Checked = false;
-        ChildItem->m_Next = 0;
-        ChildItem->m_Child = 0;
+        ChildItem->m_Next = nullptr;
+        ChildItem->m_Child = nullptr;
         ChildItem->m_Parent = Parent;
         if ( LastChild )
         {
@@ -294,13 +296,13 @@ void wxsMenuEditor::CreateDataCopyReq(wxsMenuItem* Menu,MenuItem* Parent)
         Parent->m_HandlerFunction = Events.GetHandler(0);
     }
 
-    MenuItem* LastChild = 0;
+    MenuItem* LastChild = nullptr;
     for ( int i=0; i<Menu->GetChildCount(); i++ )
     {
         wxsMenuItem* ChildMenu = (wxsMenuItem*)Menu->GetChild(i);
         MenuItem* ChildItem = new MenuItem;
-        ChildItem->m_Next = 0;
-        ChildItem->m_Child = 0;
+        ChildItem->m_Next = nullptr;
+        ChildItem->m_Child = nullptr;
         ChildItem->m_Parent = Parent;
         if ( LastChild )
         {
@@ -318,7 +320,7 @@ void wxsMenuEditor::CreateDataCopyReq(wxsMenuItem* Menu,MenuItem* Parent)
 void wxsMenuEditor::DeleteDataCopy()
 {
     DeleteDataCopyReq(m_First);
-    m_First = 0;
+    m_First = nullptr;
 }
 
 void wxsMenuEditor::DeleteDataCopyReq(MenuItem* Item)
@@ -656,7 +658,7 @@ void wxsMenuEditor::OnTypeChanged(cb_unused wxCommandEvent& event)
 {
     MenuItem* Selected = m_Selected;
     SelectItem(Selected);
-    m_Selected = 0;
+    m_Selected = nullptr;
     SelectItem(Selected);
     m_Content->SetItemText(m_Selected->m_TreeId,GetItemTreeName(m_Selected));
 }
@@ -695,22 +697,25 @@ void wxsMenuEditor::OnButtonUpClick(cb_unused wxCommandEvent& event)
     {
         // Have to put outside current parent
         if ( !Parent ) return;
+        // Disconect m_Selected from the child chain
         Parent->m_Child = m_Selected->m_Next;
-        m_Selected->m_Next = Parent;
-        Parent = m_Selected->m_Parent = Parent->m_Parent;
-        MenuItem* Previous2 = GetPrevious(Parent);
-        if ( Previous2 )
+        // Insert m_Selected between parent's previous sibling (if any) and the parent
+        MenuItem* PreviousSibling = GetPrevious(Parent);
+        if ( PreviousSibling )
         {
-            Previous2->m_Next = m_Selected;
+            PreviousSibling->m_Next = m_Selected;
         }
-        else if ( Parent )
+        else if ( Parent->m_Parent )
         {
-            Parent->m_Child = m_Selected;
+            Parent->m_Parent->m_Child = m_Selected;
         }
         else
         {
             m_First = m_Selected;
         }
+
+        m_Selected->m_Parent = Parent->m_Parent;
+        m_Selected->m_Next = Parent;
     }
 
     // Rebuilding tree
@@ -749,11 +754,11 @@ void wxsMenuEditor::OnButtonDownClick(cb_unused wxCommandEvent& event)
         if ( !Parent ) return;
         if ( Previous )
         {
-            Previous->m_Next = 0;
+            Previous->m_Next = nullptr;
         }
         else
         {
-            Parent->m_Child = 0;
+            Parent->m_Child = nullptr;
         }
         m_Selected->m_Next = Parent->m_Next;
         m_Selected->m_Parent = Parent->m_Parent;
@@ -767,14 +772,14 @@ void wxsMenuEditor::OnButtonDownClick(cb_unused wxCommandEvent& event)
 wxsMenuEditor::MenuItem* wxsMenuEditor::GetPrevious(MenuItem* Item)
 {
     MenuItem* Parent = Item->m_Parent;
-    if ( !Parent && Item == m_First         ) return 0;
-    if (  Parent && Item == Parent->m_Child ) return 0;
+    if ( !Parent && Item == m_First         ) return nullptr;
+    if (  Parent && Item == Parent->m_Child ) return nullptr;
 
     for ( MenuItem* Prev = Parent ? Parent->m_Child : m_First ; Prev; Prev = Prev->m_Next )
     {
         if ( Prev->m_Next == Item ) return Prev;
     }
-    return 0;
+    return nullptr;
 }
 
 void wxsMenuEditor::OnButtonNewClick(cb_unused wxCommandEvent& event)
@@ -785,12 +790,12 @@ void wxsMenuEditor::OnButtonNewClick(cb_unused wxCommandEvent& event)
     NewItem->m_IsMember = true;
     NewItem->m_Enabled = true;
     NewItem->m_Checked = false;
-    NewItem->m_Child = 0;
+    NewItem->m_Child = nullptr;
 
     if ( !m_Selected )
     {
         // Just adding new item into m_Data
-        NewItem->m_Parent = 0;
+        NewItem->m_Parent = nullptr;
         NewItem->m_Next = m_First;
         m_First = NewItem;
     }
@@ -821,9 +826,9 @@ void wxsMenuEditor::OnButtonDelClick(cb_unused wxCommandEvent& event)
     if ( Previous )
     {
         Previous->m_Next = m_Selected->m_Next;
-        m_Selected->m_Next = 0;
+        m_Selected->m_Next = nullptr;
         DeleteDataCopyReq(m_Selected);
-        m_Selected = 0;
+        m_Selected = nullptr;
         if ( Previous->m_Next )
         {
             SelectItem(Previous->m_Next);
@@ -855,9 +860,9 @@ void wxsMenuEditor::OnButtonDelClick(cb_unused wxCommandEvent& event)
             NewSelected = m_Selected->m_Parent;
         }
 
-        m_Selected->m_Next = 0;
+        m_Selected->m_Next = nullptr;
         DeleteDataCopyReq(m_Selected);
-        m_Selected = 0;
+        m_Selected = nullptr;
         SelectItem(NewSelected);
     }
 
@@ -900,7 +905,7 @@ void wxsMenuEditor::OnButtonRightClick(cb_unused wxCommandEvent& event)
     Previous->m_Type = wxsMenuItem::Normal;
     Previous->m_Next = m_Selected->m_Next;
     m_Selected->m_Parent = Previous;
-    m_Selected->m_Next = 0;
+    m_Selected->m_Next = nullptr;
 
     if ( !Previous->m_Child )
     {
