@@ -16,9 +16,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 8704 $
-* $Id: wxsmultichoicedialog.cpp 8704 2012-12-23 20:32:03Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsmultichoicedialog.cpp $
+* $Revision: 13547 $
+* $Id: wxsmultichoicedialog.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsmultichoicedialog.cpp $
 */
 
 #include "wxsmultichoicedialog.h"
@@ -74,6 +74,7 @@ void wxsMultiChoiceDialog::OnBuildCreatingCode()
                   (m_Content.IsEmpty()?_T("0"):ChoicesName.wx_str()));
 
             BuildSetupWindowCode();
+            GetCoderContext()->AddDestroyingCode(wxString::Format(_T("%s->Destroy();\n"), GetVarName().wx_str()));
             return;
         }
 
@@ -85,9 +86,9 @@ void wxsMultiChoiceDialog::OnBuildCreatingCode()
     }
 }
 
-void wxsMultiChoiceDialog::OnEnumToolProperties(cb_unused long Flags)
+void wxsMultiChoiceDialog::OnEnumToolProperties(cb_unused long _Flags)
 {
-    WXS_SHORT_STRING(wxsMultiChoiceDialog,m_Message,_("Message"),_T("message"),_T(""),false);
-    WXS_SHORT_STRING(wxsMultiChoiceDialog,m_Caption,_("Caption"),_T("caption"),_T(""),false);
-    WXS_ARRAYSTRING (wxsMultiChoiceDialog,m_Content,_("Items"),  _T("content"),_T("item"));
+    WXS_SHORT_STRING(wxsMultiChoiceDialog,m_Message, _("Message"), "message", "", false);
+    WXS_SHORT_STRING(wxsMultiChoiceDialog,m_Caption, _("Caption"), "caption", "", false);
+    WXS_ARRAYSTRING (wxsMultiChoiceDialog,m_Content, _("Items"),   "content", "item");
 }
