@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10688 $
-* $Id: wxspanel.cpp 10688 2016-01-22 12:24:56Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxspanel.cpp $
+* $Revision: 13547 $
+* $Id: wxspanel.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxspanel.cpp $
 */
 
 #include <wx/settings.h> // wxSystemSettings, wxSYS_COLOUR_BTNFACE
@@ -86,10 +86,10 @@ void wxsPanel::OnBuildCreatingCode()
     }
 }
 
-wxObject* wxsPanel::OnBuildPreview(wxWindow* Parent,long Flags)
+wxObject* wxsPanel::OnBuildPreview(wxWindow* Parent,long _Flags)
 {
-    wxWindow* NewItem = 0;
-    if ( Flags & pfExact )
+    wxWindow* NewItem = nullptr;
+    if ( _Flags & pfExact )
     {
         NewItem = new wxPanel(Parent,GetId(),Pos(Parent),Size(Parent),Style());
     }
@@ -98,11 +98,11 @@ wxObject* wxsPanel::OnBuildPreview(wxWindow* Parent,long Flags)
         NewItem = new PanelPreview(Parent,GetId(),Pos(Parent),Size(Parent),Style(),IsRootItem());
     }
     NewItem->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE));
-    SetupWindow(NewItem,Flags);
-    AddChildrenPreview(NewItem,Flags);
+    SetupWindow(NewItem,_Flags);
+    AddChildrenPreview(NewItem,_Flags);
     return NewItem;
 }
 
-void wxsPanel::OnEnumContainerProperties(cb_unused long Flags)
+void wxsPanel::OnEnumContainerProperties(cb_unused long _Flags)
 {
 }
