@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: wxspanel.h 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxspanel.h $
+* $Revision: 13547 $
+* $Id: wxspanel.h 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxspanel.h $
 */
 
 #ifndef WXSPANEL_H
@@ -33,9 +33,13 @@ class wxsPanel : public wxsContainer
 
     protected:
 
-        virtual wxObject* OnBuildPreview(wxWindow* Parent,long Flags);
+        virtual long OnGetPropertiesFlags()
+        {
+            return wxsContainer::OnGetPropertiesFlags() | flTopLevel;
+        }
+        virtual wxObject* OnBuildPreview(wxWindow* Parent,long _Flags);
         virtual void OnBuildCreatingCode();
-        virtual void OnEnumContainerProperties(long Flags);
+        virtual void OnEnumContainerProperties(long _Flags);
 };
 
 #endif
