@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 11738 $
-* $Id: wxscolourproperty.cpp 11738 2019-06-11 20:55:08Z fuscated $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/properties/wxscolourproperty.cpp $
+* $Revision: 13627 $
+* $Id: wxscolourproperty.cpp 13627 2025-03-02 18:17:10Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/properties/wxscolourproperty.cpp $
 */
 
 #include "wxscolourproperty.h"
@@ -26,17 +26,10 @@
 #include <wx/settings.h>
 #include <wx/colordlg.h>
 #include <wx/dc.h>
-#if wxCHECK_VERSION(3, 0, 0)
 #include <wx/wxcrtvararg.h>
 #include <wx/propgrid/props.h>
-#endif
 #include "../wxsflags.h"
-
-#if wxPG_USING_WXOWNERDRAWNCOMBOBOX || wxCHECK_VERSION(3, 0, 0)
-    #include <wx/odcombo.h>
-#else
-    #include <wx/propgrid/odcombo.h>
-#endif
+#include <wx/odcombo.h>
 
 
 using namespace wxsFlags;
@@ -46,9 +39,14 @@ using namespace wxsFlags;
 
 namespace
 {
+#pragma push_macro("_")
+#undef _
+
 #if wxCHECK_VERSION(3, 1, 0)
+#define _(x)   x
     static const char* wxsColourLabels[] = {
 #else
+#define _(x)   L##x
     static const wxChar* wxsColourLabels[] = {
 #endif // wxCHECK_VERSION
         _("Default"),
@@ -81,13 +79,13 @@ namespace
         _("Listbox"),
         _("Hot light"),
         _("Gradient of active caption"),
-        _("Gradnent of inactive caption"),
+        _("Gradient of inactive caption"),
         _("Selected menu item"),
         _("Menu bar"),
-        0
+        nullptr
     };
 
-    const int wxsColourCount = (sizeof(wxsColourLabels) / sizeof(wxsColourLabels[0])) - 1;
+#pragma pop_macro("_")
 
     static const long wxsColourValues[] = {
         wxsCOLOUR_DEFAULT,
@@ -144,18 +142,13 @@ namespace
 
         /** Override in derived class to customize how colours are printed as strings.
         */
-        virtual wxString ColourToString( const wxColour& col, int index
-#if wxCHECK_VERSION(3, 0, 0)
-                                        , int argFlags = 0
-#endif
-                                         ) const;
+        virtual wxString ColourToString( const wxColour& col, int index, int argFlags = 0 ) const;
 
         /** Returns index of entry that triggers colour picker dialog
             (default is last).
         */
         virtual int GetCustomColourIndex() const;
 
-#if wxCHECK_VERSION(3, 0, 0)
         virtual wxString ValueToString( wxVariant& value, int argFlags = 0 ) const;
         virtual bool StringToValue( wxVariant& variant,
                                     const wxString& text,
@@ -166,13 +159,6 @@ namespace
         virtual wxSize OnMeasureImage( int item ) const;
         virtual void OnCustomPaint( wxDC& dc,
                                     const wxRect& rect, wxPGPaintData& paintdata );
-#else
-        WX_PG_DECLARE_BASIC_TYPE_METHODS()
-        WX_PG_DECLARE_EVENT_METHODS()
-        WX_PG_DECLARE_ATTRIBUTE_METHODS()
-
-        WX_PG_DECLARE_CUSTOM_PAINT_METHODS()
-#endif
         // Helper function to show the colour dialog
         bool QueryColourFromUser( wxVariant& variant ) const;
 
@@ -220,13 +206,7 @@ namespace
             cpv.Init( type, *wxWHITE );
 
         m_flags |= wxPG_PROP_STATIC_CHOICES; // Colour selection cannot be changed.
-
-#if wxCHECK_VERSION(3, 0, 0)
         m_value << cpv;
-#else
-        m_value = wxColourPropertyValueToVariant(cpv);
-#endif
-
         OnSetValue();
     }
 
@@ -252,23 +232,15 @@ namespace
         if ( pVariant->IsNull() )
             return wxColourPropertyValue(wxPG_COLOUR_UNSPECIFIED, wxColour());
 
-#if wxCHECK_VERSION(3, 0, 0)
     if ( pVariant->GetType() == wxS("wxColourPropertyValue") )
     {
         wxColourPropertyValue v;
         v << *pVariant;
         return v;
     }
-#else
-        wxColourPropertyValue* v1 = &wxColourPropertyValueFromVariant(*pVariant);
-        if ( v1 )
-            return *v1;
 
-        wxColour* pCol = wxGetVariantCast(*pVariant, wxColour);
-#endif
-        wxColour col;
+    wxColour col;
 
-#if wxCHECK_VERSION(3, 0, 0)
     bool variantProcessed = true;
 
     if ( pVariant->GetType() == wxS("wxColour*") )
@@ -312,30 +284,21 @@ namespace
 
     if ( !variantProcessed )
         return wxColourPropertyValue(wxPG_COLOUR_UNSPECIFIED, wxColour());
-#else
-        if ( pCol )
-            col = *pCol;
-        else
-            col << *pVariant;
-#endif
-        wxColourPropertyValue v2( wxPG_COLOUR_CUSTOM, col );
 
-        int colInd = ColToInd(col);
-        if ( colInd != wxNOT_FOUND )
-            v2.m_type = colInd;
+    wxColourPropertyValue v2( wxPG_COLOUR_CUSTOM, col );
 
-        return v2;
+    int colInd = ColToInd(col);
+    if ( colInd != wxNOT_FOUND )
+        v2.m_type = colInd;
+
+    return v2;
     }
 
     wxVariant wxsMyColourPropertyClass::DoTranslateVal( wxColourPropertyValue& v ) const
     {
-#if wxCHECK_VERSION(3, 0, 0)
     wxVariant variant;
     variant << v;
     return variant;
-#else
-        return wxColourPropertyValueToVariant(v);
-#endif
     }
 
     int wxsMyColourPropertyClass::ColToInd( const wxColour& colour ) const
@@ -365,38 +328,27 @@ namespace
     void wxsMyColourPropertyClass::OnSetValue()
     {
         // Convert from generic wxobject ptr to wxPGVariantDataColour
-#if wxCHECK_VERSION(3, 0, 0)
     if ( m_value.GetType() == wxS("wxColour*") )
     {
         wxColour* pCol = wxStaticCast(m_value.GetWxObjectPtr(), wxColour);
         m_value << *pCol;
     }
-#else
-        if ( wxPGIsVariantType(m_value, wxobject) )
-        {
-            wxASSERT( m_value.IsValueKindOf(CLASSINFO(wxColour)) );
-            wxColour* pCol = (wxColour*) m_value.GetWxObjectPtr();
-            m_value << *pCol;
-        }
-#endif
 
-        wxColourPropertyValue val = GetVal(&m_value);
+    wxColourPropertyValue val = GetVal(&m_value);
 
-        if ( val.m_type == wxPG_COLOUR_UNSPECIFIED )
-        {
-            m_value.MakeNull();
-            return;
-        }
-        else
-        {
+    if ( val.m_type == wxPG_COLOUR_UNSPECIFIED )
+    {
+        m_value.MakeNull();
+        return;
+    }
+    else
+    {
+        if ( val.m_type < wxPG_COLOUR_WEB_BASE )
+            val.m_colour = GetColour( val.m_type );
 
-            if ( val.m_type < wxPG_COLOUR_WEB_BASE )
-                val.m_colour = GetColour( val.m_type );
+        m_value = TranslateVal(val);
+    }
 
-            m_value = TranslateVal(val);
-        }
-
-#if wxCHECK_VERSION(3, 0, 0)
     int ind = wxNOT_FOUND;
 
     if ( m_value.GetType() == wxS("wxColourPropertyValue") )
@@ -443,48 +395,8 @@ namespace
         if ( ind == wxNOT_FOUND  )
             ind = GetCustomColourIndex();
     }
-#else
-        wxColourPropertyValue* pCpv = &wxColourPropertyValueFromVariant(m_value);
-        wxColour col;
-        if ( pCpv )
-            col = pCpv->m_colour;
-        else
-            col << m_value;
 
-        if ( !col.Ok() )
-        {
-            SetValueToUnspecified();
-            SetIndex(wxNOT_FOUND);
-            return;
-        }
-
-        int ind;
-
-        if ( pCpv )
-        {
-            if ( pCpv->m_type < wxPG_COLOUR_WEB_BASE )
-            {
-                ind = GetIndexForValue(pCpv->m_type);
-            }
-            else if (pCpv->m_type == wxPG_COLOUR_CUSTOM)
-            {
-                ind = GetCustomColourIndex();
-            }
-            else
-            {
-                pCpv->m_type = wxsCOLOUR_DEFAULT;
-                ind = 0;
-            }
-        }
-        else
-        {
-            ind = ColToInd(col);
-
-            if ( ind == wxNOT_FOUND )
-                ind = GetCustomColourIndex();
-        }
-#endif
-        SetIndex(ind);
+    SetIndex(ind);
     }
 
 
@@ -494,35 +406,28 @@ namespace
     }
 
     wxString wxsMyColourPropertyClass::ColourToString( const wxColour& col,
-#if wxCHECK_VERSION(3, 0, 0)
                                                        int index,
                                                        int argFlags ) const
-#else
-                                                       int index ) const
-#endif
     {
         if ( index == wxNOT_FOUND )
         {
-#if wxCHECK_VERSION(3, 0, 0)
-        if ( (argFlags & wxPG_FULL_VALUE) ||
-             GetAttributeAsLong(wxPG_COLOUR_HAS_ALPHA, 0) )
-            return wxString::Format(wxS("(%i,%i,%i,%i)"),
-                                    (int)col.Red(),
-                                    (int)col.Green(),
-                                    (int)col.Blue(),
-                                    (int)col.Alpha());
-        else
-#endif
-            return wxString::Format(wxT("(%i,%i,%i)"),
-                                    (int)col.Red(),
-                                    (int)col.Green(),
-                                    (int)col.Blue());
+            if ( (argFlags & wxPG_FULL_VALUE) ||
+                 GetAttributeAsLong(wxPG_COLOUR_HAS_ALPHA, 0) )
+                return wxString::Format(wxS("(%i,%i,%i,%i)"),
+                                        (int)col.Red(),
+                                        (int)col.Green(),
+                                        (int)col.Blue(),
+                                        (int)col.Alpha());
+            else
+                return wxString::Format(wxT("(%i,%i,%i)"),
+                                        (int)col.Red(),
+                                        (int)col.Green(),
+                                        (int)col.Blue());
         }
         else
             return m_choices.GetLabel(index);
     }
 
-#if wxCHECK_VERSION(3, 0, 0)
     wxString wxsMyColourPropertyClass::ValueToString( wxVariant& value,
                                                     int argFlags ) const
     {
@@ -548,27 +453,6 @@ namespace
 
         return ColourToString(val.m_colour, index, argFlags);
     }
-#else
-    wxString wxsMyColourPropertyClass::GetValueAsString(cb_unused int argFlags) const
-    {
-        wxColourPropertyValue val = GetVal();
-
-        int ind = GetIndex();
-
-        // Always show custom colour for textctrl-editor
-        if (val.m_type == wxPG_COLOUR_CUSTOM)
-        {
-            ind = wxNOT_FOUND;
-        }
-
-        if (val.m_type == wxsCOLOUR_DEFAULT)
-        {
-            return wxsColourLabels[ind];
-        }
-
-        return ColourToString(val.m_colour, ind);
-    }
-#endif
 
     wxSize wxsMyColourPropertyClass::OnMeasureImage( int ) const
     {
@@ -589,23 +473,20 @@ namespace
 
     bool wxsMyColourPropertyClass::QueryColourFromUser( wxVariant& variant ) const
     {
-#if wxCHECK_VERSION(3, 0, 0)
         wxASSERT( m_value.GetType() != wxPG_VARIANT_TYPE_STRING );
-#else
-        wxASSERT( m_value.GetType() != wxT("string") );
-#endif
         bool res = false;
 
         wxPropertyGrid* propgrid = GetGrid();
         wxASSERT( propgrid );
 
         // Must only occur when user triggers event
-#if wxCHECK_VERSION(3, 0, 0)
-        if ( !(propgrid->GetInternalFlags() & wxPG_FL_IN_HANDLECUSTOMEDITOREVENT) )
-#else
-        if ( !(propgrid->GetInternalFlags() & wxPG_FL_IN_ONCUSTOMEDITOREVENT) )
-#endif
+#if wxCHECK_VERSION(3, 3, 0)
+        if ( !(propgrid->GetInternalFlags() & wxPropertyGrid::wxPG_FL_IN_HANDLECUSTOMEDITOREVENT) )
             return res;
+#else
+        if ( !(propgrid->GetInternalFlags() & wxPG_FL_IN_HANDLECUSTOMEDITOREVENT) )
+            return res;
+#endif
 
         wxColourPropertyValue val = GetVal();
 
@@ -622,6 +503,7 @@ namespace
         }
 
         wxColourDialog dialog(propgrid, &data);
+        PlaceWindow(&dialog);
         if ( dialog.ShowModal() == wxID_OK )
         {
             wxColourData retData = dialog.GetColourData();
@@ -641,11 +523,7 @@ namespace
     bool wxsMyColourPropertyClass::IntToValue( wxVariant& variant, int number, int WXUNUSED(argFlags) ) const
     {
         int index = number;
-#if wxCHECK_VERSION(3, 0, 0)
         int type = m_choices.GetValue(index);
-#else
-        int type = GetValueForIndex(index);
-#endif
         if ( type == wxPG_COLOUR_CUSTOM )
         {
             QueryColourFromUser(variant);
@@ -673,13 +551,8 @@ namespace
         {
             // Must override index detection since at this point GetIndex()
             // will return old value.
-#if wxCHECK_VERSION(3, 0, 0)
             wxOwnerDrawnComboBox* cb =
                 static_cast<wxOwnerDrawnComboBox*>(propgrid->GetEditorControl());
-#else
-            wxPGOwnerDrawnComboBox* cb =
-                (wxPGOwnerDrawnComboBox*)propgrid->GetEditorControl();
-#endif
             if ( cb )
             {
                 int index = cb->GetSelection();
@@ -710,7 +583,7 @@ namespace
             int index = paintdata.m_choiceItem;
             value = wxsColourValues[index];
         }
-        else if ( !(m_flags & wxPG_PROP_UNSPECIFIED) )
+        else if ( !(m_flags & (wxPGPropertyFlags)wxPG_PROP_UNSPECIFIED) )
         {
             value = GetVal().m_type;
         }
@@ -725,11 +598,7 @@ namespace
         {
             dc.SetBrush(*wxWHITE);
             dc.DrawRectangle(rect);
-#if wxCHECK_VERSION(3, 0, 0)
-            dc.SetBrush(wxBrush(*wxBLACK,wxHATCHSTYLE_BDIAGONAL));
-#else
-            dc.SetBrush(wxBrush(*wxBLACK,wxBDIAGONAL_HATCH));
-#endif
+            dc.SetBrush(wxBrush(*wxBLACK,wxBRUSHSTYLE_BDIAGONAL_HATCH));
             dc.DrawRectangle(rect);
             return;
         }
@@ -783,12 +652,8 @@ namespace
         {
             if ( !(argFlags & wxPG_EDITABLE_VALUE ) )
             {
-#if wxCHECK_VERSION(3, 0, 0)
                 // This really should not occur...
                 // wxASSERT(false);
-#else
-                ResetNextIndex();
-#endif
                 return false;
             }
 
@@ -836,12 +701,8 @@ namespace
 
             if ( !done )
             {
-#if wxCHECK_VERSION(3, 0, 0)
                 // This really should not occur...
                 // wxASSERT(false);
-#else
-                ResetNextIndex();
-#endif
                 return false;
             }
 
@@ -973,9 +834,8 @@ void wxsColourProperty::PGCreate(wxsPropertyContainer* Object,wxPropertyGridMana
     PGRegister(Object,Grid,Grid->AppendIn(Parent,new wxsMyColourPropertyClass(GetPGName(),wxPG_LABEL,VALUE)));
 }
 
-bool wxsColourProperty::PGRead(wxsPropertyContainer* Object,wxPropertyGridManager* Grid,wxPGId Id,cb_unused long Index)
+bool wxsColourProperty::PGRead(wxsPropertyContainer* Object,cb_unused wxPropertyGridManager* Grid,wxPGId Id,cb_unused long Index)
 {
-#if wxCHECK_VERSION(3, 0, 0)
     VALUE.m_type = wxsColourValues[Id->GetChoiceSelection()];
 
     if ( VALUE.m_type == wxsCOLOUR_DEFAULT )
@@ -991,15 +851,6 @@ bool wxsColourProperty::PGRead(wxsPropertyContainer* Object,wxPropertyGridManage
         VALUE.m_colour = wxSystemSettings::GetColour((wxSystemColour)VALUE.m_type);
     }
 
-#else
-    wxVariant value = Grid->GetPropertyValue(Id);
-    wxColourPropertyValue* Val = wxGetVariantCast(value,wxColourPropertyValue);
-
-    if ( !Val ) return false;
-
-    VALUE = *Val;
-
-#endif // wxCHECK_VERSION
     return true;
 }
 
