@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10771 $
-* $Id: wxsfontproperty.cpp 10771 2016-02-06 14:29:31Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsfontproperty.cpp $
+* $Revision: 13541 $
+* $Id: wxsfontproperty.cpp 13541 2024-08-11 18:01:17Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsfontproperty.cpp $
 */
 
 #include "wxsfontproperty.h"
@@ -29,6 +29,7 @@
 #include <wx/settings.h>
 
 #include "../wxsflags.h"
+#include "globals.h"
 
 using namespace wxsFlags;
 
@@ -85,26 +86,26 @@ wxFont wxsFontData::BuildFont()
 
         if ( !Base.Ok() )                                      Base = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
 
-        if ( HasSize ) Base.SetPointSize(Size);
+        if ( HasSize )              Base.SetPointSize(Size);
         else if ( HasRelativeSize ) Base.SetPointSize((int)(Base.GetPointSize() * RelativeSize));
-        if ( HasStyle ) Base.SetStyle(Style);
-        if ( HasWeight ) Base.SetWeight(Weight);
-        if ( HasUnderlined ) Base.SetUnderlined(Underlined);
-        if ( HasFamily ) Base.SetFamily(Family);
-        if ( !Faces.empty() ) Base.SetFaceName(Face);
-        if ( HasEncoding ) Base.SetEncoding(Enc);
+        if ( HasStyle )             Base.SetStyle(Style);
+        if ( HasWeight )            Base.SetWeight(Weight);
+        if ( HasUnderlined )        Base.SetUnderlined(Underlined);
+        if ( HasFamily )            Base.SetFamily(Family);
+        if ( !Faces.empty() )       Base.SetFaceName(Face);
+        if ( HasEncoding )          Base.SetEncoding(Enc);
+
         return Base;
     }
 
     return wxFont(
-        // TODO (mortenmacfly#1#): wxDEFAULT looks like a bug to me: wxDEFAULT is 70, Size should be e.g. 8..12
-        HasSize ? Size : wxDEFAULT,
-        HasFamily ? Family : wxFONTFAMILY_DEFAULT,
-        HasStyle ? Style : wxFONTSTYLE_NORMAL,
-        HasWeight ? Weight : wxFONTWEIGHT_NORMAL,
+        HasSize       ? Size       : wxDEFAULT,            // PointSize, not FontSize!
+        HasFamily     ? Family     : wxFONTFAMILY_DEFAULT,
+        HasStyle      ? Style      : wxFONTSTYLE_NORMAL,
+        HasWeight     ? Weight     : wxFONTWEIGHT_NORMAL,
         HasUnderlined ? Underlined : false,
         Face,
-        HasEncoding ? Enc : wxFONTENCODING_DEFAULT);
+        HasEncoding   ? Enc        : wxFONTENCODING_DEFAULT);
 }
 
 wxString wxsFontData::BuildFontCode(const wxString& FontName,wxsCoderContext* Context)
@@ -294,6 +295,7 @@ wxsFontProperty::wxsFontProperty(const wxString& PGName,const wxString& DataName
 bool wxsFontProperty::ShowEditor(wxsPropertyContainer* Object)
 {
     wxsSimpleFontEditorDlg Dlg(0,VALUE);
+    PlaceWindow(&Dlg);
     return Dlg.ShowModal() == wxID_OK;
 }
 
