@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10688 $
-* $Id: wxscorrector.cpp 10688 2016-01-22 12:24:56Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/wxscorrector.cpp $
+* $Revision: 13522 $
+* $Id: wxscorrector.cpp 13522 2024-05-21 18:54:24Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxscorrector.cpp $
 */
 
 #include "wxscorrector.h"
@@ -144,11 +144,17 @@ bool wxsCorrector::FillEmpty(wxsItem* Item)
     {
         if ( Item->GetIdName().empty() )
         {
-            Ret = true;
-            SetNewIdName(Item);
-            if (!IsWxWidgetsIdPrefix(Item->GetIdName()))
+            ConfigManager* cfg = Manager::Get()->GetConfigManager("wxsmith");
+            const bool EmptyID = cfg->ReadBool("/emptyids", false);
+
+            if (!EmptyID)
             {
-                m_Ids.insert(Item->GetIdName());
+                Ret = true;
+                SetNewIdName(Item);
+                if (!IsWxWidgetsIdPrefix(Item->GetIdName()))
+                {
+                    m_Ids.insert(Item->GetIdName());
+                }
             }
         }
     }
@@ -371,7 +377,8 @@ bool wxsCorrector::FixVarName(wxString& Name)
             _T("_"));
 
         if ( FirstChar.Find(Name.GetChar(0)) == -1 )
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Variable name : \"%s\" is not a valid c++ identifier (invalid character \"%c\" at position %d)"),Name.wx_str(),wxChar(Name.GetChar(0)),0));
+            Manager::Get()->GetLogManager()->DebugLog(wxString::Format("wxSmith: Variable name : \"%s\" is not a valid c++ identifier (invalid character \"%c\" at position %d)",
+                                                                       Name, wxChar(Name.GetChar(0)), 0));
         else
             Corrected.Append(Name.GetChar(0));
 
@@ -385,10 +392,8 @@ bool wxsCorrector::FixVarName(wxString& Name)
         {
             if ( NextChars.Find(Name.GetChar(i)) == -1 )
             {
-                Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Variable name : \"%s\" is not a valid c++ identifier (invalid character \"%c\" at position %lu)"),
-                                                            Name.wx_str(),
-                                                            wxChar(Name.GetChar(i)),
-                                                            static_cast<unsigned long>(i)));
+                Manager::Get()->GetLogManager()->DebugLog(wxString::Format("wxSmith: Variable name : \"%s\" is not a valid c++ identifier (invalid character \"%c\" at position %zu)",
+                                                            Name, wxChar(Name.GetChar(i)), i));
             }
             else
                 Corrected.Append(Name.GetChar(i));
