@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 11442 $
-* $Id: wxsitem.cpp 11442 2018-08-07 07:14:29Z fuscated $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.cpp $
+* $Revision: 13547 $
+* $Id: wxsitem.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.cpp $
 */
 
 #include "wxsitem.h"
@@ -44,10 +44,10 @@ namespace
 wxsItem::wxsItem(wxsItemResData* ResourceData,const wxsItemInfo* Info,long PropertiesFlags,const wxsEventDesc* Events,const wxsStyleSet* StyleSet):
     m_Info(Info),
     m_Events(Events,this),
-    m_Parent(0),
+    m_Parent(nullptr),
     m_ResourceData(ResourceData),
     m_PropertiesFlags(PropertiesFlags),
-    m_LastPreview(0),
+    m_LastPreview(nullptr),
     m_IsSelected(false),
     m_IsExpanded(false)
 {
@@ -64,17 +64,17 @@ wxsItem::~wxsItem()
 {
 }
 
-void wxsItem::OnEnumProperties(long Flags)
+void wxsItem::OnEnumProperties(long _Flags)
 {
-    if ( (Flags & flPropGrid) && (m_Parent != 0) )
+    if ( (_Flags & flPropGrid) && (m_Parent != 0) )
     {
         // Parent item does take care of enumerating properties if we are
         // creating property grid
-        m_Parent->OnEnumChildProperties(this,Flags);
+        m_Parent->OnEnumChildProperties(this,_Flags);
     }
     else
     {
-        EnumItemProperties(Flags);
+        EnumItemProperties(_Flags);
     }
 }
 
@@ -109,12 +109,12 @@ long wxsItem::OnGetPropertiesFlags()
     return m_ResourceData->GetPropertiesFilter() | m_PropertiesFlags | ExtraFlags;
 }
 
-void wxsItem::EnumItemProperties(long Flags)
+void wxsItem::EnumItemProperties(long _Flags)
 {
-    OnEnumItemProperties(Flags);
+    OnEnumItemProperties(_Flags);
 
     // Now enumerating all properties from wxsBaseProperties
-    SubContainer(m_BaseProperties,Flags);
+    SubContainer(m_BaseProperties,_Flags);
 }
 
 void wxsItem::OnBuildDeclarationsCode()
@@ -182,10 +182,10 @@ void wxsItem::OnBuildIdCode()
         case wxsCPP:
         {
             wxString Name = GetIdName();
-            if ( !wxsPredefinedIDs::Check(Name) )
+            if ( (!wxsPredefinedIDs::Check(Name)) && (!Name.IsEmpty()) )
             {
-                wxString Enumeration = _T("static const long ") + Name + _T(";");
-                wxString Initialization =  + _T("const long ") + GetResourceData()->GetClassName() + _T("::") + Name + _T(" = wxNewId();");
+                wxString Enumeration = _T("static const wxWindowID ") + Name + _T(";");
+                wxString Initialization =  + _T("const wxWindowID ") + GetResourceData()->GetClassName() + _T("::") + Name + _T(" = wxNewId();");
                 if ( GetCoderContext()->m_IdEnumerations.Index(Enumeration) == wxNOT_FOUND )
                 {
                     AddIdCode(Enumeration,Initialization);
@@ -202,8 +202,8 @@ void wxsItem::OnBuildIdCode()
 
 void wxsItem::OnBuildXRCFetchingCode()
 {
-    long Flags = GetPropertiesFlags();
-    if ( (Flags&flVariable) && (Flags&flId) )
+    long PropsFlags = GetPropertiesFlags();
+    if ( (PropsFlags&flVariable) && (PropsFlags&flId) )
     {
         AddXRCFetchingCode(
             GetVarName() + _T(" = ")
@@ -360,9 +360,9 @@ void wxsItem::BuildItemTree(wxsResourceTree* Tree,wxsResourceItemId Parent,int P
 //    }
 }
 
-wxObject* wxsItem::BuildPreview(wxWindow* Parent,long Flags)
+wxObject* wxsItem::BuildPreview(wxWindow* Parent,long _Flags)
 {
-    wxObject* Preview = OnBuildPreview(Parent,Flags);
+    wxObject* Preview = OnBuildPreview(Parent,_Flags);
     m_LastPreview = Preview;
     return Preview;
 }
@@ -491,7 +491,7 @@ void wxsItem::Codef(const wxChar* Fmt,...)
     va_list ap;
     va_start(ap,Fmt);
 
-    Codef(GetCoderContext(),Fmt,GetCoderContext()->m_BuildingCode,ap);
+    Codef(GetCoderContext(), Fmt, GetCoderContext()->m_BuildingCode, ap);
 
     va_end(ap);
 }
@@ -506,7 +506,7 @@ void wxsItem::Codef(const wxString &Fmt,...)
     va_list ap;
     va_start(ap,Fmt.wx_str());
 
-    Codef(GetCoderContext(),Fmt,GetCoderContext()->m_BuildingCode,ap);
+    Codef(GetCoderContext(), Fmt.c_str(), GetCoderContext()->m_BuildingCode, ap);
 
     va_end(ap);
 }
@@ -517,7 +517,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
     wxsCodingLang Language = Context->m_Language;
     wxString WindowParent = Context->m_WindowParent;
-    long Flags = Context->m_Flags;
+    long PropsFlags = Context->m_Flags;
     const bool Translation = m_ResourceData->GetTranslation();
 
     while ( *Fmt )
@@ -619,7 +619,14 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                         {
                             switch ( Language )
                             {
-                                case wxsCPP: Result << GetIdName(); break;
+                                case wxsCPP:
+                                {
+                                    if (GetIdName().IsEmpty())
+                                        Result << _T("wxID_ANY");
+                                    else
+                                        Result << GetIdName();
+                                    break;
+                                }
                                 case wxsUnknownLanguage: // fall-through
                                 default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                             }
@@ -637,9 +644,14 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('N'):
                         {
-                            if ( Flags & flId )
+                            if ( PropsFlags & flId )
                             {
-                                Result << wxsCodeMarks::WxString(wxsCPP,GetIdName(),false);
+                                if (GetIdName().IsEmpty())
+                                {
+                                    Result.RemoveLast(2); // Remove the last ,
+                                }
+                                else
+                                    Result << wxsCodeMarks::WxString(wxsCPP,GetIdName(),false);
                             }
                             else
                             {
@@ -659,7 +671,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
-                            else if ( Flags & flVariable )
+                            else if ( PropsFlags & flVariable )
                             {
                                 if ( IsPointer() )
                                 {
@@ -685,7 +697,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('P'):
                         {
-                            if ( Flags & flPosition )
+                            if ( PropsFlags & flPosition )
                             {
                                 Result << m_BaseProperties.m_Position.GetPositionCode(Context);
                             }
@@ -707,7 +719,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
-                            else if ( Flags & flVariable )
+                            else if ( PropsFlags & flVariable )
                             {
                                 if ( IsPointer() )
                                 {
@@ -733,7 +745,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('S'):
                         {
-                            if ( Flags & flSize )
+                            if ( PropsFlags & flSize )
                             {
                                 Result << m_BaseProperties.m_Size.GetSizeCode(Context);
                             }
@@ -759,7 +771,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('V'):
                         {
-                            if ( Flags & flValidator && !m_BaseProperties.m_Validator.IsEmpty() )
+                            if ( PropsFlags & flValidator && !m_BaseProperties.m_Validator.IsEmpty() )
                             {
                                 Result << m_BaseProperties.m_Validator;
                             }
@@ -992,9 +1004,9 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
     }
 }
 
-wxWindow* wxsItem::SetupWindow(wxWindow* Window,long Flags)
+wxWindow* wxsItem::SetupWindow(wxWindow* Window,long _Flags)
 {
-    bool IsExact = (Flags&pfExact) != 0;
+    bool IsExact = (_Flags&pfExact) != 0;
     long PropertiesFlags = GetPropertiesFlags();
 
     if ( PropertiesFlags&flMinMaxSize && IsExact )
@@ -1173,7 +1185,7 @@ void wxsItem::ShowPopup(wxMenu* Menu)
     }
 }
 
-void wxsItem::OnUpdateFlags(long& Flags)
+void wxsItem::OnUpdateFlags(long& _Flags)
 {
-    Flags = GetPropertiesFlags();
+    _Flags = GetPropertiesFlags();
 }
