@@ -15,12 +15,17 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10771 $
-* $Id: wxsitemeditor.cpp 10771 2016-02-06 14:29:31Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/wxsitemeditor.cpp $
+* $Revision: 13541 $
+* $Id: wxsitemeditor.cpp 13541 2024-08-11 18:01:17Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxsitemeditor.cpp $
 */
 
 #include <wx/dcmemory.h>
+
+#if wxCHECK_VERSION(3, 1, 6)
+#include <wx/bmpbndl.h>
+#endif
+
 #include "wxsitemeditor.h"
 #include "wxsitemeditorcontent.h"
 #include "wxsitemfactory.h"
@@ -41,6 +46,8 @@ namespace
     const long wxsDelId        = wxNewId();
     const long wxsPreviewId    = wxNewId();
     const long wxsQuickPropsId = wxNewId();
+    const long wxsCutId        = wxNewId();
+    const long wxsCopyId       = wxNewId();
 
     inline int ToolIconSize() { return Manager::Get()->GetConfigManager(_T("wxsmith"))->ReadInt(_T("/tooliconsize"),32L); }
     inline int PalIconSize()  { return Manager::Get()->GetConfigManager(_T("wxsmith"))->ReadInt(_T("/paletteiconsize"),16L); }
@@ -48,26 +55,26 @@ namespace
 
 wxsItemEditor::wxsItemEditor(wxWindow* parent,wxsItemRes* Resource):
     wxsEditor(parent,wxEmptyString,Resource),
-    m_Data(0),
-    m_Content(0),
-    m_WidgetsSet(0),
-    m_VertSizer(0),
-    m_HorizSizer(0),
-    m_QPSizer(0),
-    m_OpsSizer(0),
-    m_QPArea(0),
-    m_InsIntoBtn(0),
-    m_InsBeforeBtn(0),
-    m_InsAfterBtn(0),
-    m_DelBtn(0),
-    m_PreviewBtn(0),
-    m_QuickPanelBtn(0),
-    m_TopPreview(0),
-    m_PreviewBackground(0),
+    m_Data(nullptr),
+    m_Content(nullptr),
+    m_WidgetsSet(nullptr),
+    m_VertSizer(nullptr),
+    m_HorizSizer(nullptr),
+    m_QPSizer(nullptr),
+    m_OpsSizer(nullptr),
+    m_QPArea(nullptr),
+    m_InsIntoBtn(nullptr),
+    m_InsBeforeBtn(nullptr),
+    m_InsAfterBtn(nullptr),
+    m_DelBtn(nullptr),
+    m_PreviewBtn(nullptr),
+    m_QuickPanelBtn(nullptr),
+    m_TopPreview(nullptr),
+    m_PreviewBackground(nullptr),
     m_InsType(itPoint),
     m_InsTypeMask(itPoint),
     m_QuickPropsOpen(false),
-    m_PopupCaller(0)
+    m_PopupCaller(nullptr)
 {
     InitializeResourceData();
     InitializeVisualStuff();
@@ -91,12 +98,12 @@ void wxsItemEditor::InitializeResourceData()
 
     if ( GetItemRes()->GetEditMode() == wxsItemRes::File )
     {
-        InitFilename(GetXrcFileName());
+        InitFilename(UnixFilename(m_Data->GetXrcFileName()));
         SetTitle(m_Shortname);
     }
     else
     {
-        InitFilename(GetWxsFileName());
+        InitFilename(UnixFilename(m_Data->GetWxsFileName()));
         SetTitle(m_Shortname);
     }
 
@@ -191,10 +198,10 @@ void wxsItemEditor::RebuildPreview()
     // If there's previous preview, deleting it
     if ( m_PreviewBackground )
     {
-        m_Content->SetSizer(0);
+        m_Content->SetSizer(nullptr);
         m_PreviewBackground->Destroy();
-        m_PreviewBackground = 0;
-        m_TopPreview = 0;
+        m_PreviewBackground = nullptr;
+        m_TopPreview = nullptr;
     }
 
     // Generating preview
@@ -205,8 +212,8 @@ void wxsItemEditor::RebuildPreview()
     {
         Manager::Get()->GetLogManager()->DebugLog(_T("One of root items returned class not derived from wxWindow"));
         m_PreviewBackground->Destroy();
-        m_PreviewBackground = 0;
-        m_TopPreview = 0;
+        m_PreviewBackground = nullptr;
+        m_TopPreview = nullptr;
     }
     else
     {
@@ -216,15 +223,8 @@ void wxsItemEditor::RebuildPreview()
         BackgroundSizer->Fit(m_PreviewBackground);
         wxSizer* NewSizer = new wxGridSizer(1);
         NewSizer->Add(m_PreviewBackground,0,wxALL,10);
-#if !wxCHECK_VERSION(3, 0, 0)
-        m_Content->SetVirtualSizeHints(1,1);
-#endif
         m_Content->SetSizer(NewSizer);
-#if wxCHECK_VERSION(3, 0, 0)
         NewSizer->FitInside(m_Content);
-#else
-        NewSizer->SetVirtualSizeHints(m_Content);
-#endif
         m_PreviewBackground->Layout();
         m_Content->Layout();
         m_HorizSizer->Layout();
@@ -421,7 +421,7 @@ void wxsItemEditor::InsertRequest(const wxString& Name)
 
     switch ( m_InsType )
     {
-        case itAfter:
+        case itAfter: // fall-through
             RefIndex++;
             // We don't break here - continuing on itBefore code
 
@@ -503,36 +503,55 @@ void wxsItemEditor::InsertRequest(const wxString& Name)
 
 void wxsItemEditor::InitializeImages()
 {
-    if ( m_ImagesLoaded ) return;
-    wxString basePath = ConfigManager::GetDataFolder() + _T("/images/wxsmith/");
+    if (m_ImagesLoaded)
+        return;
 
+    const wxString basePath(ConfigManager::GetDataFolder() + "/images/wxsmith/");
+    const int toolSize = ToolIconSize();
+
+#if wxCHECK_VERSION(3, 1, 6)
+    const wxSize imgSize(toolSize, toolSize);
+
+    m_InsPointImg        = cbLoadBitmapBundleFromSVG(basePath + "insertpoint.svg", imgSize);
+    m_InsIntoImg         = cbLoadBitmapBundleFromSVG(basePath + "insertinto.svg", imgSize);
+    m_InsAfterImg        = cbLoadBitmapBundleFromSVG(basePath + "insertafter.svg", imgSize);
+    m_InsBeforeImg       = cbLoadBitmapBundleFromSVG(basePath + "insertbefore.svg", imgSize);
+    m_InsPointSelImg     = cbLoadBitmapBundleFromSVG(basePath + "insertpoint_selected.svg", imgSize);
+    m_InsIntoSelImg      = cbLoadBitmapBundleFromSVG(basePath + "insertinto_selected.svg", imgSize);
+    m_InsAfterSelImg     = cbLoadBitmapBundleFromSVG(basePath + "insertafter_selected.svg", imgSize);
+    m_InsBeforeSelImg    = cbLoadBitmapBundleFromSVG(basePath + "insertbefore_selected.svg", imgSize);
+    m_DelImg             = cbLoadBitmapBundleFromSVG(basePath + "deletewidget.svg", imgSize);
+    m_PreviewImg         = cbLoadBitmapBundleFromSVG(basePath + "showpreview.svg", imgSize);
+    m_QuickPropsImgOpen  = cbLoadBitmapBundleFromSVG(basePath + "quickpropsopen.svg", imgSize);
+    m_QuickPropsImgClose = cbLoadBitmapBundleFromSVG(basePath + "quickpropsclose.svg", imgSize);
+#else
     static const wxString NormalNames[] =
     {
-        _T("insertpoint32.png"),
-        _T("insertinto32.png"),
-        _T("insertafter32.png"),
-        _T("insertbefore32.png"),
-        _T("deletewidget32.png"),
-        _T("showpreview32.png"),
-        _T("quickpropsopen32.png"),
-        _T("quickpropsclose32.png"),
-        _T("selected32.png")
+        "insertpoint32.png",
+        "insertinto32.png",
+        "insertafter32.png",
+        "insertbefore32.png",
+        "deletewidget32.png",
+        "showpreview32.png",
+        "quickpropsopen32.png",
+        "quickpropsclose32.png",
+        "selected32.png"
     };
 
     static const wxString SmallNames[] =
     {
-        _T("insertpoint16.png"),
-        _T("insertinto16.png"),
-        _T("insertafter16.png"),
-        _T("insertbefore16.png"),
-        _T("deletewidget16.png"),
-        _T("showpreview16.png"),
-        _T("quickpropsopen16.png"),
-        _T("quickpropsclose16.png"),
-        _T("selected16.png")
+        "insertpoint16.png",
+        "insertinto16.png",
+        "insertafter16.png",
+        "insertbefore16.png",
+        "deletewidget16.png",
+        "showpreview16.png",
+        "quickpropsopen16.png",
+        "quickpropsclose16.png",
+        "selected16.png"
     };
 
-    const wxString* Array = ( ToolIconSize() == 16L ) ? SmallNames : NormalNames;
+    const wxString* Array = (toolSize == 16) ? SmallNames : NormalNames;
 
     m_InsPointImg.LoadFile(basePath + Array[0]);
     m_InsIntoImg.LoadFile(basePath + Array[1]);
@@ -543,6 +562,7 @@ void wxsItemEditor::InitializeImages()
     m_QuickPropsImgOpen.LoadFile(basePath + Array[6]);
     m_QuickPropsImgClose.LoadFile(basePath + Array[7]);
     m_SelectedImg.LoadFile(basePath + Array[8]);
+#endif
 
     m_ImagesLoaded = true;
 }
@@ -597,16 +617,33 @@ void wxsItemEditor::SetInsertionType(int Type)
 
 void wxsItemEditor::RebuildInsTypeIcons()
 {
-    BuildInsTypeIcon(m_InsPointBtn,m_InsPointImg,itPoint);
-    BuildInsTypeIcon(m_InsIntoBtn,m_InsIntoImg,itInto);
-    BuildInsTypeIcon(m_InsBeforeBtn,m_InsBeforeImg,itBefore);
-    BuildInsTypeIcon(m_InsAfterBtn,m_InsAfterImg,itAfter);
+#if wxCHECK_VERSION(3, 1, 6)
+    BuildInsTypeIcon(m_InsPointBtn,  m_InsPointImg,  m_InsPointSelImg,  itPoint);
+    BuildInsTypeIcon(m_InsIntoBtn,   m_InsIntoImg,   m_InsIntoSelImg,   itInto);
+    BuildInsTypeIcon(m_InsBeforeBtn, m_InsBeforeImg, m_InsBeforeSelImg, itBefore);
+    BuildInsTypeIcon(m_InsAfterBtn,  m_InsAfterImg,  m_InsAfterSelImg,  itAfter);
+#else
+    BuildInsTypeIcon(m_InsPointBtn,  m_InsPointImg,  itPoint);
+    BuildInsTypeIcon(m_InsIntoBtn,   m_InsIntoImg,   itInto);
+    BuildInsTypeIcon(m_InsBeforeBtn, m_InsBeforeImg, itBefore);
+    BuildInsTypeIcon(m_InsAfterBtn,  m_InsAfterImg,  itAfter);
+#endif
 }
 
-void wxsItemEditor::BuildInsTypeIcon(wxBitmapButton* Btn,const wxImage& Original,int ButtonType)
+#if wxCHECK_VERSION(3, 1, 6)
+void wxsItemEditor::BuildInsTypeIcon(wxBitmapButton* Btn, const wxBitmapBundle& Original, const wxBitmapBundle& Checked, int ButtonType)
 {
-    bool Selected = (m_InsType & ButtonType) != 0;
-    bool Enabled = (m_InsTypeMask & ButtonType) != 0;
+    const bool Selected = (m_InsType & ButtonType) != 0;
+    const bool Enabled = (m_InsTypeMask & ButtonType) != 0;
+    Btn->SetBitmapLabel((!Enabled || !Selected) ? Original : Checked);
+    Btn->Enable(Enabled);
+    Btn->Refresh();
+}
+#else
+void wxsItemEditor::BuildInsTypeIcon(wxBitmapButton* Btn, const wxImage& Original, int ButtonType)
+{
+    const bool Selected = (m_InsType & ButtonType) != 0;
+    const bool Enabled = (m_InsTypeMask & ButtonType) != 0;
 
     if ( !Enabled || !Selected )
     {
@@ -614,16 +651,18 @@ void wxsItemEditor::BuildInsTypeIcon(wxBitmapButton* Btn,const wxImage& Original
     }
     else
     {
-        wxBitmap Copy = Original;
+        wxBitmap Copy(Original);
         wxMemoryDC DC;
         DC.SelectObject(Copy);
-        DC.DrawBitmap(m_SelectedImg,0,0);
+        DC.DrawBitmap(m_SelectedImg, 0, 0);
+        DC.SelectObject(wxNullBitmap);
         Btn->SetBitmapLabel(Copy);
     }
 
     Btn->Enable(Enabled);
     Btn->Refresh();
 }
+#endif
 
 void wxsItemEditor::RebuildQuickPropsIcon()
 {
@@ -722,11 +761,7 @@ void wxsItemEditor::BuildPalette(wxNotebook* Palette)
             }
         }
         CurrentPanel->SetSizer(RowSizer);
-#if wxCHECK_VERSION(3, 0, 0)
         RowSizer->FitInside(CurrentPanel);
-#else
-        RowSizer->SetVirtualSizeHints(CurrentPanel);
-#endif
     }
 }
 
@@ -799,7 +834,7 @@ void wxsItemEditor::RebuildQuickProps(wxsItem* Selection)
     int QPx, QPy;
     // TODO: Check if content of previous QPPanel shouldn't be stored into item
     m_QPArea->GetViewStart(&QPx,&QPy);
-    m_QPArea->SetSizer(0);
+    m_QPArea->SetSizer(nullptr);
     m_QPArea->DestroyChildren();
     m_QPSizer = new wxBoxSizer(wxVERTICAL);
     m_QPArea->SetSizer(m_QPSizer);
@@ -865,7 +900,15 @@ void wxsItemEditor::StartInsertPointSequence(const wxsItemInfo* Info)
 void wxsItemEditor::ShowPopup(wxsItem* Item,wxMenu* Popup)
 {
     m_PopupCaller = Item;
-    PopupMenu(Popup);
+
+    Item->SetIsSelected( true );
+
+    Popup->Append(wxsCutId,_("Cut"));
+    Popup->Append(wxsCopyId,_("Copy"));
+    Popup->Append(wxsInsBeforeId,_("Paste Before Selected"));
+    Popup->Append(wxsInsIntoId,_("Paste Inside Selected"));
+    Popup->Append(wxsInsAfterId,_("Paste After Selected"));
+    wxWindow::PopupMenu(Popup);
 }
 
 void wxsItemEditor::OnPopup(wxCommandEvent& event)
@@ -879,6 +922,20 @@ void wxsItemEditor::OnPopup(wxCommandEvent& event)
     }
 }
 
+#if wxCHECK_VERSION(3, 1, 6)
+wxBitmapBundle wxsItemEditor::m_InsPointImg;
+wxBitmapBundle wxsItemEditor::m_InsIntoImg;
+wxBitmapBundle wxsItemEditor::m_InsBeforeImg;
+wxBitmapBundle wxsItemEditor::m_InsAfterImg;
+wxBitmapBundle wxsItemEditor::m_InsPointSelImg;
+wxBitmapBundle wxsItemEditor::m_InsIntoSelImg;
+wxBitmapBundle wxsItemEditor::m_InsBeforeSelImg;
+wxBitmapBundle wxsItemEditor::m_InsAfterSelImg;
+wxBitmapBundle wxsItemEditor::m_DelImg;
+wxBitmapBundle wxsItemEditor::m_PreviewImg;
+wxBitmapBundle wxsItemEditor::m_QuickPropsImgOpen;
+wxBitmapBundle wxsItemEditor::m_QuickPropsImgClose;
+#else
 wxImage wxsItemEditor::m_InsPointImg;
 wxImage wxsItemEditor::m_InsIntoImg;
 wxImage wxsItemEditor::m_InsBeforeImg;
@@ -888,6 +945,8 @@ wxImage wxsItemEditor::m_PreviewImg;
 wxImage wxsItemEditor::m_QuickPropsImgOpen;
 wxImage wxsItemEditor::m_QuickPropsImgClose;
 wxImage wxsItemEditor::m_SelectedImg;
+#endif
+
 wxsItemEditor::WindowSet wxsItemEditor::m_AllEditors;
 bool wxsItemEditor::m_ImagesLoaded = false;
 
