@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: wxswidget.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/wxswidget.cpp $
+* $Revision: 13547 $
+* $Id: wxswidget.cpp 13547 2024-09-14 04:35:04Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxswidget.cpp $
 */
 
 #include "wxswidget.h"
@@ -35,9 +35,9 @@ wxsWidget::wxsWidget(
 
 }
 
-void wxsWidget::OnEnumItemProperties(long Flags)
+void wxsWidget::OnEnumItemProperties(long _Flags)
 {
-    OnEnumWidgetProperties(Flags);
+    OnEnumWidgetProperties(_Flags);
 }
 
 void wxsWidget::OnAddItemQPP(wxsAdvQPP* QPP)
