@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10874 $
-* $Id: wxwidgetsresfactory.cpp 10874 2016-07-16 20:00:28Z jenslody $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmith/wxwidgets/wxwidgetsresfactory.cpp $
+* $Revision: 13381 $
+* $Id: wxwidgetsresfactory.cpp 13381 2023-10-27 12:55:51Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxwidgetsresfactory.cpp $
 */
 #include "wxwidgetsresfactory.h"
 #include "wxsdialogres.h"
@@ -32,8 +32,9 @@
 
 #include <wx/choicdlg.h>
 #include <tinywxuni.h>
-#include <sqplus.h>
-#include <sc_base_types.h>
+#include "scriptingmanager.h"
+#include "scripting/bindings/sc_utils.h"
+#include "scripting/bindings/sc_typeinfo_all.h"
 
 namespace
 {
@@ -51,10 +52,10 @@ namespace
 
     const wxChar* NamesPtr[ResourcesCount] =
     {
-        _("wxDialog"),
-        _("wxScrollingDialog"),
-        _("wxFrame"),
-        _("wxPanel")
+        wxT("wxDialog"),
+        wxT("wxScrollingDialog"),
+        wxT("wxFrame"),
+        wxT("wxPanel")
     };
 
     wxArrayString Names(ResourcesCount,NamesPtr);
@@ -69,7 +70,9 @@ namespace
       * \param MainResHeader - name of header file with main resource (frame/dialog), relative to cbp file's path
       * \param WxsFile - name of wxs file with main resource (frame/dialog), relative to cbp file's path
       */
-    void AddWxExtensions(cbProject* Project,const wxString& AppSource,const wxString& MainResSource,const wxString& MainResHeader,const wxString& WxsFile)
+    static void AddWxExtensions(cbProject* Project, const wxString& AppSource,
+                                const wxString& MainResSource, const wxString& MainResHeader,
+                                const wxString& WxsFile)
     {
         wxsProject* WxsProject = wxSmith::Get()->GetSmithProject(Project);
 
@@ -145,8 +148,21 @@ namespace
         //              and show results of wizard :)
         MainResource->EditOpen();
     }
-}
 
+    SQInteger CallAddWxExtensions(HSQUIRRELVM v)
+    {
+        // env table, Project, AppSource, MainResSource, MainResHeader, WxsFile
+        ScriptBindings::ExtractParams6<
+            ScriptBindings::SkipParam, cbProject *, const wxString *, const wxString *,
+            const wxString *, const wxString *
+        > extractor(v);
+        if (!extractor.Process("WxsAddWxExtensions"))
+            return extractor.ErrorMessage();
+
+        AddWxExtensions(extractor.p1, *extractor.p2, *extractor.p3, *extractor.p4, *extractor.p5);
+        return 0;
+    }
+}
 
 wxWidgetsResFactory::wxWidgetsResFactory()
 {
@@ -156,11 +172,13 @@ void wxWidgetsResFactory::OnAttach()
 {
     // TODO: Call OnAttach for item factories
 
-    // Registering wizard function in scripting manager
-    Manager::Get()->GetScriptingManager();
-    if (SquirrelVM::GetVMPtr())
+    HSQUIRRELVM vm = Manager::Get()->GetScriptingManager()->GetVM();
+    if (vm)
     {
-        SqPlus::RegisterGlobal(AddWxExtensions,"WxsAddWxExtensions");
+        ScriptBindings::PreserveTop preserveTop(vm);
+        sq_pushroottable(vm);
+        ScriptBindings::BindMethod(vm, _SC("WxsAddWxExtensions"), CallAddWxExtensions, nullptr);
+        sq_poptop(vm); // Pop root table
     }
 }
 
@@ -168,14 +186,13 @@ void wxWidgetsResFactory::OnRelease()
 {
     // TODO: Call OnRelease for item factories
 
-    // Unregistering wizard function
-    Manager::Get()->GetScriptingManager();
-    HSQUIRRELVM v = SquirrelVM::GetVMPtr();
-    if ( v )
+    HSQUIRRELVM v = Manager::Get()->GetScriptingManager()->GetVM();
+    if (v)
     {
+        ScriptBindings::PreserveTop preserveTop(v);
         sq_pushroottable(v);
-        sq_pushstring(v,"WxsAddWxExtensions",-1);
-        sq_deleteslot(v,-2,false);
+        sq_pushstring(v, _SC("WxsAddWxExtensions"), -1);
+        sq_deleteslot(v, -2, false);
         sq_poptop(v);
     }
 }
@@ -201,7 +218,7 @@ wxsResource* wxWidgetsResFactory::OnCreate(int Number,wxsProject* Project)
         case wxPanelId:           return new wxsPanelRes(Project);
         default:                  break;
     }
-    return 0;
+    return nullptr;
 }
 
 bool wxWidgetsResFactory::OnCanHandleExternal(const wxString& FileName)
@@ -212,7 +229,7 @@ bool wxWidgetsResFactory::OnCanHandleExternal(const wxString& FileName)
 wxsResource* wxWidgetsResFactory::OnBuildExternal(const wxString& FileName)
 {
     TiXmlDocument Doc;
-    if ( !TinyXML::LoadDocument(FileName,&Doc) ) return 0;
+    if ( !TinyXML::LoadDocument(FileName,&Doc) ) return nullptr;
 
     wxArrayString ResourcesFound;
     wxArrayElement XmlElements;
@@ -220,7 +237,7 @@ wxsResource* wxWidgetsResFactory::OnBuildExternal(const wxString& FileName)
     if ( !Res )
     {
         // TODO: Some message box about invalid XRC resource structure
-        return 0;
+        return nullptr;
     }
 
     for ( TiXmlElement* Object = Res->FirstChildElement("object"); Object; Object=Object->NextSiblingElement("object") )
@@ -237,7 +254,7 @@ wxsResource* wxWidgetsResFactory::OnBuildExternal(const wxString& FileName)
     if ( ResourcesFound.empty() )
     {
         // TODO: Message box that there are no resoures which could be edited here
-        return 0;
+        return nullptr;
     }
 
     int Choice = 0;
@@ -250,12 +267,12 @@ wxsResource* wxWidgetsResFactory::OnBuildExternal(const wxString& FileName)
             ResourcesFound);
         if ( Choice<0 )
         {
-            return 0;
+            return nullptr;
         }
     }
 
     TiXmlElement* Object = XmlElements[Choice];
-    if ( !Object ) return 0;
+    if ( !Object ) return nullptr;
 
     wxString Class = cbC2U(Object->Attribute("class"));
     switch ( Names.Index(Class) )
@@ -266,12 +283,13 @@ wxsResource* wxWidgetsResFactory::OnBuildExternal(const wxString& FileName)
         case wxPanelId:           return new wxsPanelRes(FileName,Object);
         default:                  break;
     }
-    return 0;
+    return nullptr;
 }
 
 bool wxWidgetsResFactory::OnNewWizard(int Number,wxsProject* Project)
 {
-    wxsNewWindowDlg Dlg(0,NamesPtr[Number],Project);
+    wxsNewWindowDlg Dlg(nullptr, NamesPtr[Number], Project);
+    PlaceWindow(&Dlg);
     return Dlg.ShowModal() == wxID_OK;
 }
 
