@@ -15,40 +15,38 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 10610 $
-* $Id: wxsAxis.h 10610 2015-12-07 05:32:34Z jenslody $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmithContribItems/wxSmithPlot/wxsAxis.h $
+* $Revision: 13627 $
+* $Id: wxsAxis.h 13627 2025-03-02 18:17:10Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmithContribItems/wxSmithPlot/wxsAxis.h $
 */
 
-#ifndef WXSSTATICTEXT1_H
-#define WXSSTATICTEXT1_H
+#ifndef WXSAXIS_H
+#define WXSAXIS_H
 
-#include    <wxwidgets/wxswidget.h>
+#include <wxwidgets/wxswidget.h>
 
-#include    <wx/stattext.h>
-#include    <mathplot.h>
+#include <wx/stattext.h>
+#include <mathplot.h>
 
 /** \brief Class for wxsStaticText widget */
 class wxsAxis: public wxsWidget
 {
     public:
-
         wxsAxis(wxsItemResData* Data);
 
     private:
-
         virtual void      OnBuildCreatingCode();
         virtual wxObject* OnBuildPreview(wxWindow* Parent,long Flags);
         virtual void      OnBuildDeclarationsCode();
         virtual void      OnEnumWidgetProperties(long Flags);
+                wxString  GetAlignString();
 
-        long            mType;              // 0=X-axis, 1=Y-axis
-        wxString        mLabel;             // label the axis
-        long            mAlign;             // position the axis
-        bool            mTics;              // show tic marks
-        wxsColourData   mPenColour;         // color to draw
-        wxsFontData     mPenFont;           // for drawing the text
-
+        long          mType;      // 0=X-axis, 1=Y-axis
+        wxString      mLabel;     // label the axis
+        long          mAlign;     // position the axis
+        bool          mTics;      // show tic marks
+        wxsColourData mPenColour; // color to draw
+        wxsFontData   mPenFont;   // for drawing the text
 };
 
-#endif
+#endif // WXSAXIS_H
