@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 11806 $
-* $Id: wxschart.cpp 11806 2019-07-22 19:54:48Z fuscated $
-* $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/contrib/wxSmithContribItems/wxchart/wxschart.cpp $
+* $Revision: 12197 $
+* $Id: wxschart.cpp 12197 2020-08-11 08:14:14Z fuscated $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmithContribItems/wxchart/wxschart.cpp $
 */
 
 #include "wxschart.h"
@@ -196,13 +196,9 @@ void wxsChart::OnEnumWidgetProperties(cb_unused long Flags)
 
 void wxsChart::OnAddExtraProperties(wxsPropertyGridManager* Grid)
 {
-    #if wxCHECK_VERSION(3, 0, 0) || wxCHECK_PROPGRID_VERSION(1, 4, 0)
     Grid->SelectPage(0);
-    #else
-    Grid->SetTargetPage(0);
-    #endif
 
-    m_ChartPointsCountId = Grid->Append(NEW_IN_WXPG14X wxIntProperty(_("Number of data sets"), wxPG_LABEL, (int)m_ChartPointsDesc.Count()));
+    m_ChartPointsCountId = Grid->Append(new wxIntProperty(_("Number of data sets"), wxPG_LABEL, (int)m_ChartPointsDesc.Count()));
 
     for ( int i=0; i<(int)m_ChartPointsDesc.Count(); i++ )
     {
@@ -214,11 +210,7 @@ void wxsChart::OnAddExtraProperties(wxsPropertyGridManager* Grid)
 
 void wxsChart::OnExtraPropertyChanged(wxsPropertyGridManager* Grid,wxPGId Id)
 {
-    #if wxCHECK_VERSION(3, 0, 0) || wxCHECK_PROPGRID_VERSION(1, 4, 0)
     Grid->SelectPage(0);
-    #else
-    Grid->SetTargetPage(0);
-    #endif
 
     if ( Id == m_ChartPointsCountId )
     {
@@ -245,11 +237,7 @@ void wxsChart::OnExtraPropertyChanged(wxsPropertyGridManager* Grid,wxPGId Id)
             // We have to remove some entries
             for ( int i=NewValue; i<OldValue; i++ )
             {
-                #if wxCHECK_VERSION(3, 0, 0) || wxCHECK_PROPGRID_VERSION(1, 4, 0)
                 Grid->DeleteProperty(m_ChartPointsDesc[i]->Id);
-                #else
-                Grid->Delete(m_ChartPointsDesc[i]->Id);
-                #endif
                 delete m_ChartPointsDesc[i];
             }
 
@@ -357,7 +345,7 @@ void wxsChart::AppendPropertyForSet(wxsPropertyGridManager* Grid,int Position)
     ChartPointsDesc* Desc = m_ChartPointsDesc[Position];
     wxString SetName = wxString::Format(_("Set %d"),Position+1);
 
-    Desc->Id = Grid->Append(NEW_IN_WXPG14X wxParentProperty(SetName,wxPG_LABEL));
+    Desc->Id = Grid->Append(new wxParentProperty(SetName,wxPG_LABEL));
     Desc->Id->ChangeFlag(wxPG_PROP_READONLY, true);
 
     static const wxChar* Types[] =
@@ -373,9 +361,9 @@ void wxsChart::AppendPropertyForSet(wxsPropertyGridManager* Grid,int Position)
         Bar, Bar3D, Pie, Pie3D, Points, Points3D, Line, Line3D, Area, Area3D
     };
 
-    Desc->TypeId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxEnumProperty(_("Type"), wxPG_LABEL,Types,Values,Desc->Type));
-    Desc->NameId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxStringProperty(_("Name"), wxPG_LABEL,Desc->Name));
-    Desc->PointsCountId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxIntProperty(_("Number of points"), wxPG_LABEL, (int)Desc->Points.Count()));
+    Desc->TypeId = Grid->AppendIn(Desc->Id, new wxEnumProperty(_("Type"), wxPG_LABEL,Types,Values,Desc->Type));
+    Desc->NameId = Grid->AppendIn(Desc->Id, new wxStringProperty(_("Name"), wxPG_LABEL,Desc->Name));
+    Desc->PointsCountId = Grid->AppendIn(Desc->Id, new wxIntProperty(_("Number of points"), wxPG_LABEL, (int)Desc->Points.Count()));
 
     for ( int i=0; i<(int)Desc->Points.Count(); i++ )
     {
@@ -429,11 +417,7 @@ bool wxsChart::HandleChangeInSet(wxsPropertyGridManager* Grid,wxPGId Id,int Posi
         {
             for ( int i=NewValue; i<OldValue; i++ )
             {
-                #if wxCHECK_VERSION(3, 0, 0) || wxCHECK_PROPGRID_VERSION(1, 4, 0)
                 Grid->DeleteProperty((Desc->Points[i])->Id);
-                #else
-                Grid->Delete((Desc->Points[i])->Id);
-                #endif
                 delete Desc->Points[i];
             }
 
@@ -469,11 +453,11 @@ void wxsChart::AppendPropertyForPoint(wxsPropertyGridManager* Grid,ChartPointsDe
     PointDesc* Desc = SetDesc->Points[Position];
     wxString Name = wxString::Format(_("Point %d"),Position+1);
 
-    Desc->Id = Grid->AppendIn(SetDesc->Id, NEW_IN_WXPG14X wxParentProperty(Name,wxPG_LABEL));
+    Desc->Id = Grid->AppendIn(SetDesc->Id, new wxParentProperty(Name,wxPG_LABEL));
     Desc->Id->ChangeFlag(wxPG_PROP_READONLY, true);
-    Desc->NameId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxStringProperty(_("Name"), wxPG_LABEL,Desc->Name));
-    Desc->XId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxStringProperty(_("X"), wxPG_LABEL,wxString::Format(_T("%lf"),Desc->X)));
-    Desc->YId = Grid->AppendIn(Desc->Id, NEW_IN_WXPG14X wxStringProperty(_("Y"), wxPG_LABEL,wxString::Format(_T("%lf"),Desc->Y)));
+    Desc->NameId = Grid->AppendIn(Desc->Id, new wxStringProperty(_("Name"), wxPG_LABEL,Desc->Name));
+    Desc->XId = Grid->AppendIn(Desc->Id, new wxStringProperty(_("X"), wxPG_LABEL,wxString::Format(_T("%lf"),Desc->X)));
+    Desc->YId = Grid->AppendIn(Desc->Id, new wxStringProperty(_("Y"), wxPG_LABEL,wxString::Format(_T("%lf"),Desc->Y)));
 }
 
 bool wxsChart::HandleChangeInPoint(wxsPropertyGridManager* Grid,wxPGId Id,ChartPointsDesc* SetDesc,int Position,bool Global)
