@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 10655 $
- * $Id: databreakpointdlg.cpp 10655 2016-01-17 13:58:05Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/debuggergdb/databreakpointdlg.cpp $
+ * $Revision: 13562 $
+ * $Id: databreakpointdlg.cpp 13562 2024-09-14 04:43:57Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/debuggergdb/databreakpointdlg.cpp $
  */
 
 #include "databreakpointdlg.h"
@@ -12,14 +12,14 @@
 
 //(*InternalHeaders(DataBreakpointDlg)
 #include <wx/button.h>
-#include <wx/string.h>
 #include <wx/intl.h>
+#include <wx/string.h>
 //*)
 
 //(*IdInit(DataBreakpointDlg)
-const long DataBreakpointDlg::ID_CHK_ENABLED = wxNewId();
-const long DataBreakpointDlg::ID_TXT_DATA_EXPRESION = wxNewId();
-const long DataBreakpointDlg::ID_RDO_CONDITION = wxNewId();
+const wxWindowID DataBreakpointDlg::ID_CHK_ENABLED = wxNewId();
+const wxWindowID DataBreakpointDlg::ID_TXT_DATA_EXPRESION = wxNewId();
+const wxWindowID DataBreakpointDlg::ID_RDO_CONDITION = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(DataBreakpointDlg,wxScrollingDialog)
@@ -37,14 +37,14 @@ DataBreakpointDlg::DataBreakpointDlg(wxWindow *parent, const wxString& dataExpre
     m_enabled = new wxCheckBox(this, ID_CHK_ENABLED, _("Enabled"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHK_ENABLED"));
     m_enabled->SetValue(false);
     bszMain->Add(m_enabled, 0, wxTOP|wxLEFT|wxRIGHT|wxEXPAND, 8);
-    m_dataExpression = new wxTextCtrl(this, ID_TXT_DATA_EXPRESION, wxEmptyString, wxDefaultPosition, wxSize(265,23), wxTE_PROCESS_ENTER, wxDefaultValidator, _T("ID_TXT_DATA_EXPRESION"));
+    m_dataExpression = new wxTextCtrl(this, ID_TXT_DATA_EXPRESION, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER, wxDefaultValidator, _T("ID_TXT_DATA_EXPRESION"));
     m_dataExpression->SetFocus();
     bszMain->Add(m_dataExpression, 1, wxTOP|wxLEFT|wxRIGHT|wxEXPAND, 8);
     wxString __wxRadioBoxChoices_1[3] =
     {
-    	_("Break on read"),
-    	_("Break on write"),
-    	_("Break on read or write")
+      _("Break on read"),
+      _("Break on write"),
+      _("Break on read or write")
     };
     m_condition = new wxRadioBox(this, ID_RDO_CONDITION, _("Condition"), wxDefaultPosition, wxDefaultSize, 3, __wxRadioBoxChoices_1, 1, 0, wxDefaultValidator, _T("ID_RDO_CONDITION"));
     bszMain->Add(m_condition, 0, wxTOP|wxLEFT|wxRIGHT|wxEXPAND, 8);
@@ -54,7 +54,6 @@ DataBreakpointDlg::DataBreakpointDlg(wxWindow *parent, const wxString& dataExpre
     StdDialogButtonSizer1->Realize();
     bszMain->Add(StdDialogButtonSizer1, 0, wxALL|wxEXPAND, 8);
     SetSizer(bszMain);
-    bszMain->Fit(this);
     bszMain->SetSizeHints(this);
     Center();
     //*)
