@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 11633 $
- * $Id: parsewatchvalue.cpp 11633 2019-04-20 16:56:13Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/debuggergdb/parsewatchvalue.cpp $
+ * $Revision: 13106 $
+ * $Id: parsewatchvalue.cpp 13106 2022-12-10 08:21:40Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/debuggergdb/parsewatchvalue.cpp $
  */
 
 #include <sdk.h>
@@ -67,7 +67,7 @@ struct Token
     bool hasRepeatedChar;
 };
 
-wxRegEx regexRepeatedChars(wxT("^((\\\\'.{1,6}\\\\')|('.{1,6}'))[ \\t](<repeats[ \\t][0-9]+[ \\t]times>)"),
+wxRegEx regexRepeatedChars(wxT("^((\\\\'.{1,6}\\\\')|('.{1,6}'))[[:blank:]](<repeats[[:blank:]][0-9]+[[:blank:]]times>)"),
 #ifndef __WXMAC__
                            wxRE_ADVANCED);
 #else
@@ -332,8 +332,8 @@ inline cb::shared_ptr<GDBWatch> AddChild(cb::shared_ptr<GDBWatch> parent, wxStri
     return child;
 }
 
-wxRegEx regexRepeatedChar(wxT(".+[ \\t](<repeats[ \\t][0-9]+[ \\t]times>)$"));
-wxRegEx regexFortranArray(wxT("^\\([0-9,]+)$"));
+wxRegEx regexRepeatedChar(wxT(".+[[:blank:]](<repeats[[:blank:]][0-9]+[[:blank:]]times>)$"));
+wxRegEx regexFortranArray(wxT("^\\([0-9,]+\\)$"));
 
 inline bool ParseGDBWatchValue(cb::shared_ptr<GDBWatch> watch, wxString const &value, int &start, int length)
 {
@@ -930,7 +930,7 @@ bool ParseCDBWatchValue(cb::shared_ptr<GDBWatch> watch, wxString const &value)
         if (set_type)
             watch->SetType(tokens[1]);
 
-        static wxRegEx class_line(wxT("[ \\t]*\\+(0x[0-9a-f]+)[ \\t]([a-zA-Z0-9_]+)[ \\t]+:[ \\t]+(.+)"));
+        static wxRegEx class_line(wxT("[[:blank:]]*\\+(0x[0-9a-f]+)[[:blank:]]([a-zA-Z0-9_]+)[[:blank:]]+:[[:blank:]]+(.+)"));
         if (!class_line.IsValid())
         {
             int *p = NULL;
@@ -1008,11 +1008,11 @@ void TokenizeGDBLocals(std::vector<GDBLocalVariable> &results, wxString const &v
             break;
         case wxT('"'):
             if (!inChar && !escaped)
-                inString=!inString;
+                inString = !inString;
             break;
         case wxT('\''):
             if (!inString && !escaped)
-                inChar=!inChar;
+                inChar = !inChar;
             break;
         default:
             break;
@@ -1023,7 +1023,7 @@ void TokenizeGDBLocals(std::vector<GDBLocalVariable> &results, wxString const &v
     results.push_back(GDBLocalVariable(value, start, value.length() - start));
 }
 
-const wxRegEx reExamineMemoryLine(wxT("[ \t]*(0x[0-9a-f]+)[ \t]<.+>:[ \t]+(.+)"));
+const wxRegEx reExamineMemoryLine(wxT("[[:blank:]]*(0x[0-9a-f]+)[[:blank:]]<.+>:[[:blank:]]+(.+)"));
 
 bool ParseGDBExamineMemoryLine(wxString &resultAddr, std::vector<uint8_t> &resultValues,
                                const wxString &outputLine)
