@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 11822 $
- * $Id: projectsimporter.cpp 11822 2019-08-01 22:04:41Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/projectsimporter/projectsimporter.cpp $
+ * $Revision: 12995 $
+ * $Id: projectsimporter.cpp 12995 2022-10-28 07:22:31Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/projectsimporter/projectsimporter.cpp $
  */
 
 #include "sdk.h"
@@ -61,27 +61,49 @@ void ProjectsImporter::BuildMenu(wxMenuBar* menuBar)
     if (!IsAttached() || !menuBar)
         return;
 
-    m_Menu = Manager::Get()->LoadMenu(_T("project_import_menu"), false);
-    if (!m_Menu)
+    std::unique_ptr <wxMenu> menu(Manager::Get()->LoadMenu("project_import_menu", false));
+    if (!menu)
         return;
 
     wxMenu* fileMenu = menuBar->GetMenu(0);
-    if (fileMenu)
+    if (!fileMenu)
+        return;
+
+    wxMenuItem* importMenuItem;
+    const int importMenuId = fileMenu->FindItem(_("&Import project"));
+    if (importMenuId == wxNOT_FOUND)
     {
-        int menuId = 0, id = 0;
         wxMenuItemList menuItems = fileMenu->GetMenuItems();
-        menuId = fileMenu->FindItem(_("R&ecent files"));
+        const int menuId = fileMenu->FindItem(_("R&ecent files"));
         wxMenuItem* recentFileItem = fileMenu->FindItem(menuId);
-        id = menuItems.IndexOf(recentFileItem);
+        int id = menuItems.IndexOf(recentFileItem);
         if (id == wxNOT_FOUND)
             id = 7;
         else
             ++id;
 
         // The position is hard-coded to "Recent Files" menu. Please adjust it if necessary
-        fileMenu->Insert(++id, wxNewId(), _("&Import project"), m_Menu);
+        importMenuItem = fileMenu->Insert(++id, wxNewId(), _("&Import project"), new wxMenu());
         fileMenu->InsertSeparator(++id);
     }
+    else
+    {
+        importMenuItem = fileMenu->FindItem(importMenuId);
+    }
+
+    if (!importMenuItem)
+        return;
+
+    if (!importMenuItem->IsSubMenu())
+        importMenuItem->SetSubMenu(new wxMenu());
+
+    wxMenu* importSubMenu = importMenuItem->GetSubMenu();
+    if (importSubMenu->GetMenuItemCount())
+        importSubMenu->AppendSeparator();
+
+    wxMenuItemList m_List = menu->GetMenuItems();
+    for (wxMenuItemList::iterator it = m_List.begin(); it != m_List.end(); ++it)
+        importSubMenu->Append(menu->Remove(*it));
 }
 
 bool ProjectsImporter::CanHandleFile(const wxString& filename) const
@@ -137,8 +159,8 @@ int ProjectsImporter::LoadProject(const wxString& filename)
     {
         wxBusyCursor wait;
 
-        Manager::Get()->GetLogManager()->Log(F(_("Importing %s: "), filename.wx_str()));
-        IBaseLoader* loader = 0L;
+        Manager::Get()->GetLogManager()->Log(wxString::Format(_("Importing %s: "), filename));
+        IBaseLoader* loader = nullptr;
         FileType ft = FileTypeOf(filename);
         switch (ft)
         {
@@ -234,7 +256,7 @@ int ProjectsImporter::LoadWorkspace(const wxString& filename)
         return -1;
     }
 
-    Manager::Get()->GetLogManager()->Log(F(_("Importing %s: "), filename.wx_str()));
+    Manager::Get()->GetLogManager()->Log(wxString::Format(_("Importing %s: "), filename));
     FileType ft = FileTypeOf(filename);
     IBaseWorkspaceLoader* pWsp = 0;
     switch (ft)
