@@ -2,17 +2,17 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 10270 $
- * $Id: genericsinglechoicelist.cpp 10270 2015-05-15 10:57:08Z jenslody $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/plugins/scriptedwizard/genericsinglechoicelist.cpp $
+ * $Revision: 13564 $
+ * $Id: genericsinglechoicelist.cpp 13564 2024-09-14 04:44:50Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/scriptedwizard/genericsinglechoicelist.cpp $
  */
 
 #include <sdk.h>
 #ifndef CB_PRECOMP
     #include <wx/arrstr.h>
     //(*InternalHeadersPCH(GenericSingleChoiceList)
-    #include <wx/string.h>
     #include <wx/intl.h>
+    #include <wx/string.h>
     //*)
 #endif // CB_PRECOMP
 
@@ -20,13 +20,13 @@
 
 
 //(*IdInit(GenericSingleChoiceList)
-const long GenericSingleChoiceList::ID_STATICTEXT1 = wxNewId();
-const long GenericSingleChoiceList::ID_LISTBOX1 = wxNewId();
+const wxWindowID GenericSingleChoiceList::ID_STATICTEXT1 = wxNewId();
+const wxWindowID GenericSingleChoiceList::ID_LISTBOX1 = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(GenericSingleChoiceList,wxPanel)
-	//(*EventTable(GenericSingleChoiceList)
-	//*)
+    //(*EventTable(GenericSingleChoiceList)
+    //*)
 END_EVENT_TABLE()
 
 GenericSingleChoiceList::GenericSingleChoiceList(wxWindow* parent,wxWindowID id)
@@ -40,15 +40,14 @@ GenericSingleChoiceList::GenericSingleChoiceList(wxWindow* parent,wxWindowID id)
 	lblDescr = new wxStaticText(this, ID_STATICTEXT1, _("Description"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
 	BoxSizer1->Add(lblDescr, 0, wxALL|wxEXPAND, 8);
 	StaticBoxSizer1 = new wxStaticBoxSizer(wxVERTICAL, this, _("Please make a selection"));
-	GenericChoiceList = new wxListBox(this, ID_LISTBOX1, wxDefaultPosition, wxSize(232,131), 0, 0, wxLB_SINGLE|wxLB_HSCROLL, wxDefaultValidator, _T("ID_LISTBOX1"));
+	GenericChoiceList = new wxListBox(this, ID_LISTBOX1, wxDefaultPosition, wxDefaultSize, 0, 0, wxLB_SINGLE|wxLB_HSCROLL, wxDefaultValidator, _T("ID_LISTBOX1"));
 	StaticBoxSizer1->Add(GenericChoiceList, 1, wxALL|wxEXPAND, 4);
 	BoxSizer1->Add(StaticBoxSizer1, 1, wxALL|wxEXPAND|wxFIXED_MINSIZE, 8);
 	SetSizer(BoxSizer1);
-	BoxSizer1->Fit(this);
 	BoxSizer1->SetSizeHints(this);
 	//*)
 
-	GenericChoiceList->SetName(_T("GenericChoiceList"));
+    GenericChoiceList->SetName(_T("GenericChoiceList"));
 }
 
 GenericSingleChoiceList::~GenericSingleChoiceList()
