@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 10769 $
- * $Id: base64.cpp 10769 2016-02-06 14:26:58Z mortenmacfly $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/base64.cpp $
+ * $Revision: 12578 $
+ * $Id: base64.cpp 12578 2021-12-14 08:57:56Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/base64.cpp $
  */
 
 //*********************************************************************
@@ -22,9 +22,7 @@
 
 #include "base64.h"
 
-#if wxCHECK_VERSION(3, 0, 0)
 #include <wx/unichar.h>
-#endif
 
 const wxChar fillchar = '=';
 
@@ -105,29 +103,17 @@ wxString wxBase64::Decode(const wxString& data)
         c1 = cvt.Find(data[i]);
         wxASSERT_MSG(c1 >= 0, _T("invalid base64 input"));
         c = (c << 2) | ((c1 >> 4) & 0x3);
-        #if wxCHECK_VERSION(3, 0, 0)
         ret.Append(static_cast<wxUniChar>(c), 1);
-        #else
-        ret.Append(c, 1);
-        #endif
         if (++i < len)
         {
             c = data[i];
             if ((char)fillchar == c)
                 break;
 
-            #if wxCHECK_VERSION(3, 0, 0)
             c = cvt.Find(static_cast<wxUniChar>(c));
-            #else
-            c = cvt.Find(c);
-            #endif
             wxASSERT_MSG(c >= 0, _T("invalid base64 input"));
             c1 = ((c1 << 4) & 0xf0) | ((c >> 2) & 0xf);
-            #if wxCHECK_VERSION(3, 0, 0)
             ret.Append(static_cast<wxUniChar>(c1), 1);
-            #else
-            ret.Append(c1, 1);
-            #endif
         }
 
         if (++i < len)
@@ -136,18 +122,10 @@ wxString wxBase64::Decode(const wxString& data)
             if ((char)fillchar == c1)
                 break;
 
-            #if wxCHECK_VERSION(3, 0, 0)
             c1 = cvt.Find(static_cast<wxUniChar>(c1));
-            #else
-            c1 = cvt.Find(c1);
-            #endif
             wxASSERT_MSG(c1 >= 0, _T("invalid base64 input"));
             c = ((c << 6) & 0xc0) | c1;
-            #if wxCHECK_VERSION(3, 0, 0)
             ret.Append(static_cast<wxUniChar>(c), 1);
-            #else
-            ret.Append(c, 1);
-            #endif
         }
     }
 
