@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 11349 $
- * $Id: findreplacedlg.cpp 11349 2018-03-27 21:59:55Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/findreplacedlg.cpp $
+ * $Revision: 13627 $
+ * $Id: findreplacedlg.cpp 13627 2025-03-02 18:17:10Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/findreplacedlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -21,7 +21,9 @@
     #include <wx/intl.h>
     #include <wx/notebook.h>
     #include <wx/radiobox.h>
+    #include <wx/regex.h>
     #include <wx/sizer.h>
+    #include <wx/stattext.h>
     #include <wx/textctrl.h>
     #include <wx/xrc/xmlres.h>
 
@@ -46,6 +48,9 @@ DEFINE_EVENT_TYPE(wxDEFERRED_FOCUS_EVENT)
 BEGIN_EVENT_TABLE(FindReplaceDlg, wxScrollingDialog)
     EVT_ACTIVATE(                        FindReplaceDlg::OnActivate)
     EVT_CHECKBOX(XRCID("chkRegEx1"),     FindReplaceDlg::OnRegEx)
+    EVT_CHECKBOX(XRCID("chkRegEx2"),     FindReplaceDlg::OnSettingsChange)
+    EVT_CHECKBOX(XRCID("chkMatchCase1"), FindReplaceDlg::OnSettingsChange)
+    EVT_CHECKBOX(XRCID("chkMatchCase2"), FindReplaceDlg::OnSettingsChange)
 
     // Special events for Find/Replace
     EVT_CHECKBOX(XRCID("chkMultiLine1"), FindReplaceDlg::OnMultiChange)
@@ -56,6 +61,10 @@ BEGIN_EVENT_TABLE(FindReplaceDlg, wxScrollingDialog)
     EVT_BUTTON(XRCID("btnBrowsePath"),   FindReplaceDlg::OnBrowsePath)
     EVT_BUTTON(XRCID("btnSelectTarget"), FindReplaceDlg::OnSelectTarget)
     EVT_CHOICE(XRCID("chProject"),       FindReplaceDlg::OnSearchProject)
+    EVT_TEXT(XRCID("cmbFind1"),          FindReplaceDlg::OnSettingsChange)
+    EVT_TEXT(XRCID("cmbFind2"),          FindReplaceDlg::OnSettingsChange)
+    EVT_TEXT(XRCID("txtMultiLineFind1"), FindReplaceDlg::OnSettingsChange)
+    EVT_TEXT(XRCID("txtMultiLineFind2"), FindReplaceDlg::OnSettingsChange)
 
     EVT_COMMAND(wxID_ANY, wxDEFERRED_FOCUS_EVENT, FindReplaceDlg::OnDeferredFocus)
 END_EVENT_TABLE()
@@ -68,7 +77,7 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
 {
     wxXmlResource::Get()->LoadObject(this, parent, _T("dlgFindReplace"),_T("wxScrollingDialog"));
     ConfigManager* cfg = Manager::Get()->GetConfigManager(_T("editor"));
-
+    m_advancedRegex = cfg->ReadBool(_T("/use_advanced_regexes"), false);
 
     // load last searches
     FillComboWithLastValues(XRCCTRL(*this, "cmbFind1",    wxComboBox), CONF_GROUP _T("/last"));
@@ -122,6 +131,8 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
     XRCCTRL(*this, "chkFixEOLs2",         wxCheckBox)->SetValue(cfg->ReadBool(CONF_GROUP _T("/fix_eols2"), false));
     XRCCTRL(*this, "chkFixEOLs2",         wxCheckBox)->Enable(XRCCTRL(*this, "chkMultiLine2", wxCheckBox)->GetValue());
     XRCCTRL(*this, "chkDelOldSearchRes2", wxCheckBox)->SetValue(cfg->ReadBool(CONF_GROUP _T("/delete_old_searches2"), true));
+    XRCCTRL(*this, "chkAutoOpen2",        wxCheckBox)->SetValue(cfg->ReadBool(CONF_GROUP _T("/auto_open_first_result2"), true));
+    XRCCTRL(*this, "chkAutoOpen2",        wxCheckBox)->Enable(XRCCTRL(*this, "rbScope2", wxRadioBox)->GetSelection() != 0);
 
     wxSize szReplaceMulti = XRCCTRL(*this, "nbReplaceMulti", wxPanel)->GetEffectiveMinSize();
     XRCCTRL(*this, "nbReplaceSingle", wxPanel)->SetMinSize(szReplaceMulti);
@@ -169,14 +180,16 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
 
     wxChoice *chProject = XRCCTRL(*this, "chProject", wxChoice);
     wxChoice *chTarget = XRCCTRL(*this, "chTarget", wxChoice);
-    for(unsigned int i=0;i<pa->size();++i)
+    chProject->Freeze();
+    const unsigned int numProjects = pa->size();
+    for (unsigned int i = 0; i < numProjects; ++i)
     {
-        chProject->AppendString((*pa)[i]->GetTitle());
+        chProject->Append((*pa)[i]->GetTitle());
         if ((*pa)[i] == active_project)
         {
             chProject->SetSelection(i);
-            chTarget->Clear();
-            chTarget->AppendString(_("All project files"));
+            chTarget->Freeze();
+            chTarget->Append(_("All project files"));
 
             const bool selectScopeAll = cfg->ReadBool(CONF_GROUP _T("/target_scope_all"), true);
 
@@ -201,9 +214,13 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
                 }
                 chTarget->Enable(false);
             }
+
+            chTarget->Thaw();
         }
     }
 
+    chProject->Thaw();
+
     wxRadioBox* rbScope = XRCCTRL(*this, "rbScope2", wxRadioBox);
     EditorManager* edMgr = Manager::Get()->GetEditorManager();
     bool filesOpen = false;
@@ -257,12 +274,12 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
 
     if (findMode)
     {
-        SetTitle(_T("Find"));
+        SetTitle(_("Find"));
         XRCCTRL(*this, "nbReplaceSingle",        wxPanel)->Hide();
         XRCCTRL(*this, "nbReplaceInFilesSingle", wxPanel)->Hide();
-        XRCCTRL(*this, "nbReplace",              wxNotebook)->SetPageText(0,_T("Find"));
-        XRCCTRL(*this, "nbReplace",              wxNotebook)->SetPageText(1,_T("Find in files"));
-        XRCCTRL(*this, "wxID_OK",                wxButton)->SetLabel(_T("&Find"));
+        XRCCTRL(*this, "nbReplace",              wxNotebook)->SetPageText(0, _("Find"));
+        XRCCTRL(*this, "nbReplace",              wxNotebook)->SetPageText(1, _("Find in files"));
+        XRCCTRL(*this, "wxID_OK",                wxButton)->SetLabel(_("&Find"));
         XRCCTRL(*this, "chkFixEOLs1",            wxCheckBox)->Hide();
         XRCCTRL(*this, "chkFixEOLs2",            wxCheckBox)->Hide();
         XRCCTRL(*this, "chkDelOldSearchRes2",    wxCheckBox)->Show();
@@ -290,6 +307,8 @@ FindReplaceDlg::FindReplaceDlg(wxWindow* parent, const wxString& initial, bool h
 
     // NOTE (jens#1#): Dynamically connect these events, to avoid asserts in debug-mode
     Connect(XRCID("nbReplace"), wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED, wxNotebookEventHandler(FindReplaceDlg::OnReplaceChange));
+
+    CheckFindValue();
 }
 
 FindReplaceDlg::~FindReplaceDlg()
@@ -344,11 +363,12 @@ FindReplaceDlg::~FindReplaceDlg()
     cfg->Write(CONF_GROUP _T("/start_word2"), flgLimitTo && valLimitTo == 1);
     cfg->Write(CONF_GROUP _T("/start_file2"), flgLimitTo && valLimitTo == 2);
 
-    cfg->Write(CONF_GROUP _T("/fix_eols2"),            XRCCTRL(*this, "chkFixEOLs2",         wxCheckBox)->GetValue());
-    cfg->Write(CONF_GROUP _T("/match_case2"),          XRCCTRL(*this, "chkMatchCase2",       wxCheckBox)->GetValue());
-    cfg->Write(CONF_GROUP _T("/regex2"),               XRCCTRL(*this, "chkRegEx2",           wxCheckBox)->GetValue());
-    cfg->Write(CONF_GROUP _T("/scope2"),               XRCCTRL(*this, "rbScope2",            wxRadioBox)->GetSelection());
-    cfg->Write(CONF_GROUP _T("/delete_old_searches2"), XRCCTRL(*this, "chkDelOldSearchRes2", wxCheckBox)->GetValue());
+    cfg->Write(CONF_GROUP _T("/fix_eols2"),               XRCCTRL(*this, "chkFixEOLs2",         wxCheckBox)->GetValue());
+    cfg->Write(CONF_GROUP _T("/match_case2"),             XRCCTRL(*this, "chkMatchCase2",       wxCheckBox)->GetValue());
+    cfg->Write(CONF_GROUP _T("/regex2"),                  XRCCTRL(*this, "chkRegEx2",           wxCheckBox)->GetValue());
+    cfg->Write(CONF_GROUP _T("/scope2"),                  XRCCTRL(*this, "rbScope2",            wxRadioBox)->GetSelection());
+    cfg->Write(CONF_GROUP _T("/delete_old_searches2"),    XRCCTRL(*this, "chkDelOldSearchRes2", wxCheckBox)->GetValue());
+    cfg->Write(CONF_GROUP _T("/auto_open_first_result2"), XRCCTRL(*this, "chkAutoOpen2",        wxCheckBox)->GetValue());
 
     cfg->Write(CONF_GROUP _T("/search_path"),      XRCCTRL(*this, "txtSearchPath",        wxTextCtrl)->GetValue());
     SaveComboValues(XRCCTRL(*this, "cmbSearchMask", wxComboBox), CONF_GROUP _T("/search_masks"));
@@ -380,8 +400,6 @@ wxString FindReplaceDlg::GetReplaceString() const
 {
     if ( IsMultiLine() )
     {
-        wxString tmpString;
-
         if ( IsFindInFiles() )
             return XRCCTRL(*this, "txtMultiLineReplace2", wxTextCtrl)->GetValue();
         return XRCCTRL(*this, "txtMultiLineReplace1", wxTextCtrl)->GetValue();
@@ -584,6 +602,8 @@ void FindReplaceDlg::OnScopeChange(cb_unused wxCommandEvent& event)
         (XRCCTRL(*this, "nbReplace", wxNotebook)->GetPage(1))->Layout();
     else
         (XRCCTRL(*this, "nbReplace", wxNotebook)->GetPage(0))->Layout();
+
+    XRCCTRL(*this, "chkAutoOpen2", wxCheckBox)->Enable(rbScope->GetSelection() != 0);
 }
 
 void FindReplaceDlg::OnBrowsePath(cb_unused wxCommandEvent& event)
@@ -603,10 +623,13 @@ void FindReplaceDlg::OnSearchProject(cb_unused wxCommandEvent& event)
         return;
     cbProject *active_project=(*Manager::Get()->GetProjectManager()->GetProjects())[i];
     const bool targAll = (chTarget->GetSelection() == 0);
+    chTarget->Freeze();
     chTarget->Clear();
-    chTarget->AppendString(_("All project files"));
+    chTarget->Append(_("All project files"));
     for(int j=0;j<active_project->GetBuildTargetsCount();++j)
-        chTarget->AppendString(active_project->GetBuildTarget(j)->GetTitle());
+        chTarget->Append(active_project->GetBuildTarget(j)->GetTitle());
+
+    chTarget->Thaw();
     const int targIdx = chTarget->FindString(active_project->GetActiveBuildTarget(), true);
     chTarget->SetSelection(targAll || targIdx < 0 ? 0 : targIdx);
 }
@@ -644,6 +667,7 @@ void FindReplaceDlg::OnReplaceChange(wxNotebookEvent& event)
 
     wxCommandEvent e(wxDEFERRED_FOCUS_EVENT,wxID_ANY);
     AddPendingEvent(e);
+    CheckFindValue();
     event.Skip();
 }
 
@@ -666,6 +690,7 @@ void FindReplaceDlg::OnDeferredFocus(cb_unused wxCommandEvent& event)
 void FindReplaceDlg::OnRegEx(cb_unused wxCommandEvent& event)
 {
     XRCCTRL(*this, "rbDirection", wxRadioBox)->Enable(!XRCCTRL(*this, "chkRegEx1", wxCheckBox)->GetValue());
+    CheckFindValue();
 }
 
 void FindReplaceDlg::OnActivate(wxActivateEvent& event)
@@ -739,6 +764,7 @@ void FindReplaceDlg::OnMultiChange(wxCommandEvent& event)
         (XRCCTRL(*this, "nbReplace", wxNotebook)->GetPage(1))->Layout();
 
     Refresh();
+    CheckFindValue();
     event.Skip();
 }
 
@@ -802,6 +828,7 @@ void FindReplaceDlg::OnSelectTarget(cb_unused wxCommandEvent& event)
 
     IncrementalSelectArrayIterator iterator(targetNames);
     IncrementalSelectDialog dlg(this, &iterator, _("Select target..."), _("Choose target:"));
+    PlaceWindow(&dlg);
     if (dlg.ShowModal() == wxID_OK)
     {
         wxChoice *chTarget = XRCCTRL(*this, "chTarget", wxChoice);
@@ -826,3 +853,71 @@ void FindReplaceDlg::OnSelectTarget(cb_unused wxCommandEvent& event)
         }
     }
 }
+
+bool FindReplaceDlg::GetHasToOpenFirstResult() const
+{
+    return (XRCCTRL(*this, "rbScope2", wxRadioBox)->GetSelection() != 0) &&
+           (XRCCTRL(*this, "chkAutoOpen2", wxCheckBox)->GetValue());
+}
+
+void FindReplaceDlg::OnSettingsChange(wxCommandEvent& event)
+{
+    CheckFindValue();
+    event.Skip();
+}
+
+void FindReplaceDlg::CheckFindValue()
+{
+    wxString statusText;
+    const wxString value(GetFindString());
+    if (value.empty())
+    {
+        statusText = _("Search string cannot be empty");
+    }
+#ifdef wxHAS_REGEX_ADVANCED
+    else if (GetRegEx())
+    {
+        if (m_advancedRegex)
+        {
+            int flags = wxRE_ADVANCED;
+            if (!GetMultiLine())
+                flags |= wxRE_NEWLINE;
+
+            if (!GetMatchCase())
+                flags |= wxRE_ICASE;
+
+            wxRegEx r(value, flags);
+            if (!r.IsValid())
+                statusText = _("Invalid advanced regular expression");
+        }
+    }
+#endif
+
+    XRCCTRL(*this, "stStatus", wxStaticText)->SetLabel(statusText);
+    const bool isOk = statusText.empty();
+    XRCCTRL(*this, "wxID_OK", wxButton)->Enable(isOk);
+
+    // Colours
+    const wxColour bg(isOk ? wxNullColour : *wxRED);
+    const wxColour fg(isOk ? wxNullColour : *wxWHITE);
+
+    wxComboBox *cb1 = XRCCTRL(*this, "cmbFind1", wxComboBox);
+    cb1->SetBackgroundColour(bg);
+    cb1->SetForegroundColour(fg);
+    cb1->Refresh();
+
+    wxComboBox *cb2 = XRCCTRL(*this, "cmbFind2", wxComboBox);
+    cb2->SetBackgroundColour(bg);
+    cb2->SetForegroundColour(fg);
+    cb2->Refresh();
+
+    wxTextCtrl *tc1 = XRCCTRL(*this, "txtMultiLineFind1", wxTextCtrl);
+    tc1->SetBackgroundColour(bg);
+    tc1->SetForegroundColour(fg);
+    tc1->Refresh();
+
+    wxTextCtrl *tc2 = XRCCTRL(*this, "txtMultiLineFind2", wxTextCtrl);
+    tc2->SetBackgroundColour(bg);
+    tc2->SetForegroundColour(fg);
+    tc2->Refresh();
+}
