@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 11437 $
- * $Id: newfromtemplatedlg.cpp 11437 2018-08-07 07:13:40Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/newfromtemplatedlg.cpp $
+ * $Revision: 13043 $
+ * $Id: newfromtemplatedlg.cpp 13043 2022-11-17 08:05:48Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/newfromtemplatedlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -87,9 +87,20 @@ NewFromTemplateDlg::NewFromTemplateDlg(TemplateOutputType initial, const wxArray
     m_WizardIndex(-1)
 {
     //ctor
-    wxXmlResource::Get()->LoadObject(this, nullptr, _T("dlgNewFromTemplate"),_T("wxScrollingDialog"));
+    wxXmlResource::Get()->LoadObject(this, nullptr, "dlgNewFromTemplate", "wxScrollingDialog");
     m_Wizards = Manager::Get()->GetPluginManager()->GetOffersFor(ptWizard);
 
+    if (initial == totProject)
+        SetTitle(_("New project"));
+    else if (initial == totTarget)
+        SetTitle(_("New build target"));
+    else if (initial == totFiles)
+        SetTitle(_("New file"));
+    else if (initial == totCustom)
+        SetTitle(_("New custom"));
+    else if (initial == totUser)
+        SetTitle(_("New from template"));
+
     wxListbook* lb = XRCCTRL(*this, "nbMain", wxListbook);
     SetSettingsIconsStyle(lb->GetListView(), sisNoIcons);
 
@@ -104,7 +115,7 @@ NewFromTemplateDlg::NewFromTemplateDlg(TemplateOutputType initial, const wxArray
     XRCCTRL(*this, "listCustoms", wxListCtrl)->SetImageList(new wxImageList(32, 32), wxIMAGE_LIST_SMALL);
 
     // load view prefs
-    XRCCTRL(*this, "rbView", wxRadioBox)->SetSelection(Manager::Get()->GetConfigManager(_T("new_from_template"))->ReadInt(_T("/view"), 0));
+    XRCCTRL(*this, "rbView", wxRadioBox)->SetSelection(Manager::Get()->GetConfigManager("new_from_template")->ReadInt("/view", 0));
     ChangeView();
 
     BuildCategories();
@@ -195,11 +206,7 @@ void NewFromTemplateDlg::BuildCategoriesFor(TemplateOutputType otype, wxChoice*
     cat->SetSelection(0);
 }
 
-#if wxCHECK_VERSION(3, 0, 0)
 inline int wxCALLBACK SortTemplates(wxIntPtr item1, wxIntPtr item2, cb_unused wxIntPtr sortData)
-#else
-inline int wxCALLBACK SortTemplates(long item1, long item2, cb_unused long sortData)
-#endif
 {
     ListItemData* data1 = reinterpret_cast<ListItemData*>(item1);
     ListItemData* data2 = reinterpret_cast<ListItemData*>(item2);
@@ -259,7 +266,7 @@ void NewFromTemplateDlg::BuildListFor(TemplateOutputType otype, wxListCtrl* list
                 int index = list->InsertItem(0, plugin->GetTitle(w), iconIndex);
                 if (index != -1)
                 {
-                    list->SetItemData(index, (wxIntPtr)(new ListItemData(nullptr, plugin, w)));
+                    list->SetItemPtrData(index, (wxUIntPtr)(new ListItemData(nullptr, plugin, w)));
                     // if the script exists in the user's configuration, mark that it's been customized
                     wxString script = ConfigManager::GetFolder(sdDataUser) + _T("/templates/wizard/") + plugin->GetScriptFilename(w);
                     if (wxFileExists(script))
