@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 11282 $
- * $Id: pipedprocess.cpp 11282 2018-01-31 23:48:23Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/pipedprocess.cpp $
+ * $Revision: 13049 $
+ * $Id: pipedprocess.cpp 13049 2022-11-19 02:18:52Z ollydbg $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/pipedprocess.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -50,11 +50,12 @@ class cbTextInputStream : public wxTextInputStream
             memset((void*)m_lastBytes, 0, 10);
             for (size_t inlen = 0; inlen < 9; inlen++)
             {
-                // actually read the next character
+                // actually read the next character byte
                 m_lastBytes[inlen] = m_input.GetC();
 
                 if (m_input.LastRead() <= 0)
                     return wxEOT;
+                // inlen is the byte index we get copied from the input byte stream
                 if (m_allowMBconversion)
                 {
                     int retlen = (int) m_conv->MB2WC(wbuf, m_lastBytes, 2); // returns -1 for failure
@@ -82,9 +83,11 @@ class cbTextInputStream : public wxTextInputStream
         {
             wxString line;
 
+            std::string lineBytes;
+
             while ( m_input.CanRead() && !m_input.Eof() )
             {
-                wxChar c = NextChar();
+                char c = m_input.GetC();
                 if (m_input.LastRead() <= 0)
                     break;
 
@@ -94,7 +97,18 @@ class cbTextInputStream : public wxTextInputStream
                 if (EatEOL(c))
                     break;
 
-                line += c;
+                lineBytes += c;
+            }
+            // for the compiler output, it could be either the file content and the file path
+            // the file content could be in any encoding, mostly the utf-8 format.
+            // for the file path, it usually contains the legacy MBCS encoding(ANSI string).
+            // so, we firstly try to convert from UTF8, if failed, try the wxConvLocal
+            line = wxString::FromUTF8(lineBytes.c_str());
+            if (line.empty())
+            {
+                line = wxString(lineBytes.c_str()); // use the wxConvLocal(the default)
+                if (line.empty())
+                    return lineBytes; // if wxConvLocal still fails, return the raw byte string
             }
             return line;
         }
@@ -123,23 +137,35 @@ PipedProcess::PipedProcess(PipedProcess** pvThis, wxEvtHandler* parent, int id,
         wxSetWorkingDirectory(unixDir);
     if (pipe)
         Redirect();
+
+    m_timerPollProcess.SetOwner(this, idTimerPollProcess);
 }
 
 // class destructor
 PipedProcess::~PipedProcess()
 {
-    // insert your code here
+    if (m_timerPollProcess.IsRunning())
+        m_timerPollProcess.Stop();
 }
 
-int PipedProcess::Launch(const wxString& cmd, cb_unused unsigned int pollingInterval)
+int PipedProcess::Launch(const wxString& cmd, int flags)
 {
     m_Stopped = false;
-    m_Pid = wxExecute(cmd, wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER, this);
+
+    // wxWidgets < 3.1.0 on Unix has a bug in wxExecute() with non-ASCII characters
+    // See https://github.com/wxWidgets/wxWidgets/issues/16206
+#if !defined __WXGTK__ || wxCHECK_VERSION(3, 1, 0)
+    m_Pid = wxExecute(cmd, flags, this);
+#else
+    char* currentLocale = wxStrdup(wxSetlocale(LC_ALL, ""));
+    m_Pid = wxExecute(cmd, flags, this);
+    wxSetlocale(LC_ALL, currentLocale);
+    free(currentLocale);
+#endif
+
     if (m_Pid)
-    {
-//        m_timerPollProcess.SetOwner(this, idTimerPollProcess);
-//        m_timerPollProcess.Start(pollingInterval);
-    }
+        m_timerPollProcess.Start(1000);
+
     return m_Pid;
 }
 
@@ -235,8 +261,9 @@ void PipedProcess::OnTimer(cb_unused wxTimerEvent& event)
     wxWakeUpIdle();
 }
 
-void PipedProcess::OnIdle(cb_unused wxIdleEvent& event)
+void PipedProcess::OnIdle(wxIdleEvent& event)
 {
     while ( HasInput() )
         ;
+    event.Skip();
 }
