@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 11119 $
- * $Id: projectfileoptionsdlg.cpp 11119 2017-08-01 21:49:34Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/projectfileoptionsdlg.cpp $
+ * $Revision: 13191 $
+ * $Id: projectfileoptionsdlg.cpp 13191 2023-02-03 23:06:49Z bluehazzard $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/projectfileoptionsdlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -41,7 +41,6 @@
 #include <wx/textfile.h>
 
 BEGIN_EVENT_TABLE(ProjectFileOptionsDlg, wxScrollingDialog)
-    EVT_CHECKBOX (XRCID("chkReadOnly"), ProjectFileOptionsDlg::OnReadOnlyCheck)
     EVT_CHOICE   (XRCID("cmbBuildStageCompiler"), ProjectFileOptionsDlg::OnCompilerCombo)
     EVT_UPDATE_UI(-1, ProjectFileOptionsDlg::OnUpdateUI)
 END_EVENT_TABLE()
@@ -147,7 +146,7 @@ ProjectFileOptionsDlg::ProjectFileOptionsDlg(wxWindow* parent, ProjectFile* pf)
     m_FileName(),
     m_LastBuildStageCompilerSel(-1)
 {
-    wxXmlResource::Get()->LoadObject(this, parent, _T("dlgProjectFileOptions"),_T("wxScrollingDialog"));
+    wxXmlResource::Get()->LoadObject(this, parent, "dlgProjectFileOptions", "wxScrollingDialog");
     XRCCTRL(*this, "wxID_OK", wxButton)->SetDefault();
 
     if (pf)
@@ -174,24 +173,39 @@ ProjectFileOptionsDlg::ProjectFileOptionsDlg(wxWindow* parent, ProjectFile* pf)
         FillCompilers();
         UpdateBuildCommand();
 
-        XRCCTRL(*this, "txtProject",         wxTextCtrl)->SetValue(prj?(prj->GetTitle() + _T("\n") + prj->GetFilename()):_T("-"));
-        XRCCTRL(*this, "txtProjectBasePath", wxTextCtrl)->SetValue(prj?prj->GetCommonTopLevelPath():_T("-"));
+        XRCCTRL(*this, "txtProject",         wxTextCtrl)->SetValue(prj ? (prj->GetTitle() + "\n" + prj->GetFilename()) : wxString("-"));
+        XRCCTRL(*this, "txtProjectBasePath", wxTextCtrl)->SetValue(prj ? prj->GetCommonTopLevelPath() : wxString("-"));
         XRCCTRL(*this, "txtAbsName",         wxTextCtrl)->SetValue(m_FileNameStr);
         XRCCTRL(*this, "txtRelName",         wxTextCtrl)->SetValue(pf->relativeFilename);
 
-        SetTitle(_("Properties of ") + wxString(_("\"")) + pf->relativeFilename + wxString(_("\"")));
+        SetTitle(wxString::Format(_("Properties of \"%s\""), pf->relativeFilename.wx_str()));
     }
     XRCCTRL(*this, "txtObjName",               wxTextCtrl)->Enable(false);
     // included files not implemented yet -> hide it
     XRCCTRL(*this, "staticIncludedFilesLabel", wxStaticText)->Hide();
     XRCCTRL(*this, "staticIncludedFiles",      wxStaticText)->Hide();
 
-    if (pf->AutoGeneratedBy())
+    if (pf && pf->AutoGeneratedBy())
     {
         XRCCTRL(*this, "tabBuild",    wxPanel)->Enable(false);
         XRCCTRL(*this, "tabAdvanced", wxPanel)->Enable(false);
     }
     XRCCTRL(*this, "lblAutoGen", wxStaticText)->Show(pf->AutoGeneratedBy());
+    XRCCTRL(*this, "lblGlobId", wxStaticText)->Show(pf->IsGlobValid());
+    wxTextCtrl* txtGlob = XRCCTRL(*this, "txtGlob", wxTextCtrl);
+    txtGlob->Show(pf->IsGlobValid());
+    if (pf->IsGlobValid())
+    {
+        ProjectGlob pjGlob = pf->GetParentProject()->SearchGlob(pf->globId);
+        if (pjGlob.IsValid())
+        {
+            txtGlob->SetValue(wxString::Format(_("%s\nrecursive: %s, mask:\"%s\""), pjGlob.GetPath(), pjGlob.GetRecursive() ? _("yes") : _("no"), pjGlob.GetWildCard() ));
+        }
+        else
+        {
+            txtGlob->SetValue(_("Could not find glob this file is part of"));
+        }
+    }
 }
 
 ProjectFileOptionsDlg::ProjectFileOptionsDlg(wxWindow* parent, const wxString& fileName) :
@@ -200,7 +214,7 @@ ProjectFileOptionsDlg::ProjectFileOptionsDlg(wxWindow* parent, const wxString& f
     m_FileName(),
     m_LastBuildStageCompilerSel(-1)
 {
-    wxXmlResource::Get()->LoadObject(this, parent, _T("dlgProjectFileOptions"),_T("wxScrollingDialog"));
+    wxXmlResource::Get()->LoadObject(this, parent, "dlgProjectFileOptions", "wxScrollingDialog");
     XRCCTRL(*this, "wxID_OK", wxButton)->SetDefault();
 
     FillGeneralProperties();
@@ -208,38 +222,15 @@ ProjectFileOptionsDlg::ProjectFileOptionsDlg(wxWindow* parent, const wxString& f
     XRCCTRL(*this, "txtAbsName", wxTextCtrl)->SetValue(m_FileNameStr);
     // This must be always hidden for non-project files.
     XRCCTRL(*this, "lblAutoGen", wxStaticText)->Show(false);
+    XRCCTRL(*this, "lblGlobId", wxStaticText)->Show(false);
 
-    SetTitle(_("Properties of ") + wxString(_("\"")) + m_FileNameStr + wxString(_("\"")));
+    SetTitle(wxString::Format(_("Properties of \"%s\""), m_FileNameStr));
 }
 
 ProjectFileOptionsDlg::~ProjectFileOptionsDlg()
 {
 }
 
-void ProjectFileOptionsDlg::OnReadOnlyCheck(wxCommandEvent& event)
-{
-    if (m_FileNameStr.IsEmpty() || !m_FileName.FileExists())
-        return;
-
-    if (event.IsChecked())
-    {
-        // make read-only
-        if ( !ToggleFileReadOnly(true) )
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Unable to set file '%s' read-only (probably missing access rights)."), m_FileNameStr.wx_str()));
-    }
-    else
-    {
-        // make writeable
-        if ( !ToggleFileReadOnly(false) )
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Unable to set file '%s' writeable (probably missing access rights)."), m_FileNameStr.wx_str()));
-    }
-
-    // Update UI
-    XRCCTRL(*this, "chkReadOnly", wxCheckBox)->SetValue(!m_FileName.IsFileWritable());
-
-    Manager::Get()->GetEditorManager()->CheckForExternallyModifiedFiles();
-}
-
 void ProjectFileOptionsDlg::OnCompilerCombo(wxCommandEvent& event)
 {
     if (m_LastBuildStageCompilerSel != event.GetSelection())
@@ -295,11 +286,26 @@ void ProjectFileOptionsDlg::EndModal(int retCode)
 
         // make sure we have a compiler var, if the file is to be compiled
         if (m_ProjectFile->compile && m_ProjectFile->compilerVar.IsEmpty())
-            m_ProjectFile->compilerVar = _T("CPP");
+            m_ProjectFile->compilerVar = "CPP";
 
         cbProject* prj = m_ProjectFile->GetParentProject();
         prj->SetModified(true);
         Manager::Get()->GetProjectManager()->GetUI().RebuildTree();
+
+        // Check if read-only status has changed
+        const bool readOnlyStatus = XRCCTRL(*this, "chkReadOnly", wxCheckBox)->GetValue();
+        if (readOnlyStatus != m_ReadOnlyInitialStatus)
+        {
+            if (!m_FileNameStr.empty() && m_FileName.FileExists())
+            {
+                if (ToggleFileReadOnly(readOnlyStatus))
+                    Manager::Get()->GetEditorManager()->CheckForExternallyModifiedFiles();
+                else
+                    Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Unable to set file '%s' %s (probably missing access rights).",
+                                                                               m_FileNameStr,
+                                                                               readOnlyStatus ? "read-only" : "writeable"));
+            }
+        }
     }
 
     wxScrollingDialog::EndModal(retCode);
@@ -325,21 +331,23 @@ void ProjectFileOptionsDlg::FillGeneralProperties()
         long int comment_lines = 0;
         long int codecomments_lines = 0;
         CountLines(m_FileName, colour_set->GetCommentToken(lang), code_lines, codecomments_lines, comment_lines, empty_lines, total_lines);
-        XRCCTRL(*this, "staticTotalLines",   wxStaticText)->SetLabel(wxString::Format(_T("%ld"), total_lines));
-        XRCCTRL(*this, "staticEmptyLines",   wxStaticText)->SetLabel(wxString::Format(_T("%ld"), empty_lines));
-        XRCCTRL(*this, "staticActualLines",  wxStaticText)->SetLabel(wxString::Format(_T("%ld"), code_lines + codecomments_lines));
-        XRCCTRL(*this, "staticCommentLines", wxStaticText)->SetLabel(wxString::Format(_T("%ld"), comment_lines));
+        XRCCTRL(*this, "staticTotalLines",   wxStaticText)->SetLabel(wxString::Format("%ld", total_lines));
+        XRCCTRL(*this, "staticEmptyLines",   wxStaticText)->SetLabel(wxString::Format("%ld", empty_lines));
+        XRCCTRL(*this, "staticActualLines",  wxStaticText)->SetLabel(wxString::Format("%ld", code_lines + codecomments_lines));
+        XRCCTRL(*this, "staticCommentLines", wxStaticText)->SetLabel(wxString::Format("%ld", comment_lines));
         XRCCTRL(*this, "staticEmptyLines",   wxStaticText)->GetContainingSizer()->Layout();
     }
     wxFile file(m_FileName.GetFullPath());
     if (file.IsOpened())
     {
-        long length = static_cast<long>(file.Length());
+        const long length = static_cast<long>(file.Length());
         XRCCTRL(*this, "staticFileSize", wxStaticText)->SetLabel(wxString::Format(_("%ld Bytes"), length));
         XRCCTRL(*this, "staticFileSize", wxStaticText)->GetContainingSizer()->Layout();
         file.Close();
     }
-    XRCCTRL(*this, "chkReadOnly", wxCheckBox)->SetValue(!m_FileName.IsFileWritable());
+
+    m_ReadOnlyInitialStatus = !m_FileName.IsFileWritable();
+    XRCCTRL(*this, "chkReadOnly", wxCheckBox)->SetValue(m_ReadOnlyInitialStatus);
     wxDateTime modTime = m_FileName.GetModificationTime();
     XRCCTRL(*this, "staticDateTimeStamp", wxStaticText)->SetLabel(
         wxString::Format(_("%02hd/%02hd/%d %02hd:%02hd:%02hd"), modTime.GetDay(),
@@ -404,13 +412,13 @@ bool ProjectFileOptionsDlg::ToggleFileReadOnly(bool setReadOnly)
     if (res != 0)
     {
         if      (errno == ENOENT)
-            Manager::Get()->GetLogManager()->DebugLog(_T("Error calling chmod (ENOENT)."));
+            Manager::Get()->GetLogManager()->DebugLog("Error calling chmod (ENOENT).");
         else if (errno == EINVAL)
-            Manager::Get()->GetLogManager()->DebugLog(_T("Error calling chmod (EINVAL)."));
+            Manager::Get()->GetLogManager()->DebugLog("Error calling chmod (EINVAL).");
         else if (errno == EBADF)
-            Manager::Get()->GetLogManager()->DebugLog(_T("Error calling chmod (EBADF)."));
+            Manager::Get()->GetLogManager()->DebugLog("Error calling chmod (EBADF).");
         else
-            Manager::Get()->GetLogManager()->DebugLog(_T("Error calling chmod."));
+            Manager::Get()->GetLogManager()->DebugLog("Error calling chmod.");
         return false; // chmod error
     }
 #else
@@ -419,7 +427,7 @@ bool ProjectFileOptionsDlg::ToggleFileReadOnly(bool setReadOnly)
     int res  = chmod(m_FileNameStr.mb_str(wxConvUTF8), mask | X_MODE_MASK);
     if (res != 0)
     {
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("Error calling chmod : errno = %d."), errno));
+        Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Error calling chmod : errno = %d.", errno));
         return false; // chmod error
     }
 
