@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 9203 $
- * $Id: searchresultslog.cpp 9203 2013-07-08 23:07:22Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/searchresultslog.cpp $
+ * $Revision: 12822 $
+ * $Id: searchresultslog.cpp 12822 2022-05-29 19:10:32Z bluehazzard $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/searchresultslog.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -71,12 +71,12 @@ void cbSearchResultsLog::SyncEditor(int selIndex)
     file = filename.GetFullPath();
 
     wxListItem li;
-    li.m_itemId = selIndex;
-    li.m_col = 1;
-    li.m_mask = wxLIST_MASK_TEXT;
+    li.SetId(selIndex);
+    li.SetColumn(1);
+    li.SetMask(wxLIST_MASK_TEXT);
     control->GetItem(li);
     long line = 0;
-    li.m_text.ToLong(&line);
+    li.GetText().ToLong(&line);
     cbEditor* ed = Manager::Get()->GetEditorManager()->Open(file);
     if (!line || !ed)
         return;
@@ -103,3 +103,8 @@ void cbSearchResultsLog::OnDoubleClick(cb_unused wxCommandEvent& event)
 
     SyncEditor(index);
 } // end of OnDoubleClick
+
+bool cbSearchResultsLog::IsVisible()
+{
+    return control->IsShownOnScreen();
+}
