@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 11435 $
- * $Id: toolsmanager.cpp 11435 2018-08-07 07:13:14Z fuscated $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/sdk/toolsmanager.cpp $
+ * $Revision: 12998 $
+ * $Id: toolsmanager.cpp 12998 2022-10-30 16:47:04Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/toolsmanager.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -129,11 +129,7 @@ bool ToolsManager::Execute(const cbTool* tool)
 
     // log info so user can troubleshoot
     dir = wxGetCwd(); // read in the actual working dir
-    #if wxCHECK_VERSION(3, 0, 0)
-    Manager::Get()->GetLogManager()->Log(F(_("Launching tool '%s': %s (in %s)"), tool->GetName().wx_str(), cmdline.wx_str(), dir.wx_str()));
-    #else
-    Manager::Get()->GetLogManager()->Log(F(_("Launching tool '%s': %s (in %s)"), tool->GetName().c_str(), cmdline.c_str(), dir.c_str()));
-    #endif
+    Manager::Get()->GetLogManager()->Log(wxString::Format(_("Launching tool '%s': %s (in %s)"), tool->GetName(), cmdline, dir));
 
     bool pipe = true;
     int flags = wxEXEC_ASYNC;
@@ -251,30 +247,31 @@ cbTool* ToolsManager::GetToolByIndex(int index)
 
 void ToolsManager::LoadTools()
 {
-    ConfigManager* cfg = Manager::Get()->GetConfigManager(_T("tools"));
-    wxArrayString list = cfg->EnumerateSubPaths(_("/"));
+    ConfigManager* cfg = Manager::Get()->GetConfigManager("tools");
+    wxArrayString list = cfg->EnumerateSubPaths("/");
     for (unsigned int i = 0; i < list.GetCount(); ++i)
     {
         cbTool tool;
-        tool.SetName( cfg->Read(_T("/") + list[i] + _T("/name")));
-        if (tool.GetName().IsEmpty())
+        tool.SetName( cfg->Read("/" + list[i] + "/name"));
+        if (tool.GetName().empty())
             continue;
-        tool.SetCommand(cfg->Read(_T("/") + list[i] + _T("/command")));
-        if (tool.GetCommand().IsEmpty())
+        tool.SetCommand(cfg->Read("/" + list[i] + "/command"));
+        if (tool.GetCommand().empty())
             continue;
-        tool.SetParams(cfg->Read(_T("/") + list[i] + _T("/params")));
-        tool.SetWorkingDir(cfg->Read(_T("/") + list[i] + _T("/workingDir")));
-        tool.SetLaunchOption(static_cast<cbTool::eLaunchOption>(cfg->ReadInt(_T("/") + list[i] + _T("/launchOption"))));
+        tool.SetParams(cfg->Read("/" + list[i] + "/params"));
+        tool.SetWorkingDir(cfg->Read("/" + list[i] + "/workingDir"));
+        tool.SetLaunchOption(static_cast<cbTool::eLaunchOption>(cfg->ReadInt("/" + list[i] + "/launchOption")));
 
         AddTool(&tool, false);
     }
-    Manager::Get()->GetLogManager()->Log(F(_("Configured %d tools"), m_Tools.GetCount()));
+
+    Manager::Get()->GetLogManager()->Log(wxString::Format(_("Configured %zu tools"), m_Tools.GetCount()));
 }
 
 void ToolsManager::SaveTools()
 {
-    ConfigManager* cfg = Manager::Get()->GetConfigManager(_T("tools"));
-    wxArrayString list = cfg->EnumerateSubPaths(_("/"));
+    ConfigManager* cfg = Manager::Get()->GetConfigManager("tools");
+    wxArrayString list = cfg->EnumerateSubPaths("/");
     for (unsigned int i = 0; i < list.GetCount(); ++i)
     {
         cfg->DeleteSubPath(list[i]);
@@ -290,12 +287,12 @@ void ToolsManager::SaveTools()
         wxString tmp;
         tmp.Printf(_T("tool%2.2d"), count++);
 
-        elem << _T("/") << tmp  << _T("/");
-        cfg->Write(elem + _T("name"), tool->GetName());
-        cfg->Write(elem + _T("command"), tool->GetCommand());
-        cfg->Write(elem + _T("params"), tool->GetParams());
-        cfg->Write(elem + _T("workingDir"), tool->GetWorkingDir());
-        cfg->Write(elem + _T("launchOption"), static_cast<int>(tool->GetLaunchOption()));
+        elem << '/' << tmp << '/';
+        cfg->Write(elem + "name", tool->GetName());
+        cfg->Write(elem + "command", tool->GetCommand());
+        cfg->Write(elem + "params", tool->GetParams());
+        cfg->Write(elem + "workingDir", tool->GetWorkingDir());
+        cfg->Write(elem + "launchOption", static_cast<int>(tool->GetLaunchOption()));
     }
 }
 
@@ -364,7 +361,7 @@ void ToolsManager::OnToolClick(wxCommandEvent& event)
 {
     cbTool* tool = GetToolByMenuId(event.GetId());
     if (!Execute(tool))
-        cbMessageBox(_("Could not execute ") + tool->GetName());
+        cbMessageBox(wxString::Format(_("Could not execute %s"), tool->GetName()));
 }
 
 void ToolsManager::OnIdle(wxIdleEvent& event)
@@ -376,18 +373,17 @@ void ToolsManager::OnIdle(wxIdleEvent& event)
             event.RequestMore();
         }
     }
-    else
-        event.Skip();
+    event.Skip();
 }
 
 void ToolsManager::OnToolStdOutput(CodeBlocksEvent& event)
 {
-    Manager::Get()->GetLogManager()->Log(_T("stdout> ") + event.GetString());
+    Manager::Get()->GetLogManager()->Log("stdout> "+event.GetString());
 }
 
 void ToolsManager::OnToolErrOutput(CodeBlocksEvent& event)
 {
-    Manager::Get()->GetLogManager()->Log(_T("stderr> ") + event.GetString());
+    Manager::Get()->GetLogManager()->Log("stderr> "+event.GetString());
 }
 
 void ToolsManager::OnToolTerminated(CodeBlocksEvent& event)
@@ -395,5 +391,5 @@ void ToolsManager::OnToolTerminated(CodeBlocksEvent& event)
     m_Pid = 0;
     m_pProcess = nullptr;
 
-    Manager::Get()->GetLogManager()->Log(F(_T("Tool execution terminated with status %d"), event.GetInt()));
+    Manager::Get()->GetLogManager()->Log(wxString::Format(_("Tool execution terminated with status %d"), event.GetInt()));
 }
