@@ -16,19 +16,19 @@ class ExamineMemoryDlg : public wxPanel, public cbExamineMemoryDlg
     public:
         ExamineMemoryDlg(wxWindow* parent);
 
-        wxWindow* GetWindow() { return this; }
+        wxWindow* GetWindow() override { return this; }
 
         // used for Freeze()/Thaw() calls
-        void Begin();
-        void End();
+        void Begin() override;
+        void End() override;
 
-        void Clear();
-        wxString GetBaseAddress();
-        void SetBaseAddress(const wxString &addr);
-        int GetBytes();
-        void AddError(const wxString& err);
-        void AddHexByte(const wxString& addr, const wxString& hexbyte);
-        void EnableWindow(bool enable);
+        void Clear() override;
+        wxString GetBaseAddress() override;
+        void SetBaseAddress(const wxString &addr) override;
+        int GetBytes() override;
+        void AddError(const wxString& err) override;
+        void AddHexByte(const wxString& addr, const wxString& hexbyte) override;
+        void EnableWindow(bool enable) override;
     protected:
         void OnGo(wxCommandEvent& event);
 
@@ -36,7 +36,7 @@ class ExamineMemoryDlg : public wxPanel, public cbExamineMemoryDlg
         wxTextCtrl* m_pText;
         size_t m_ByteCounter;
         wxChar m_LineText[67]; // 16*3 "7F " + 3 "   " + 16 "."
-        unsigned long m_LastRowStartingAddress;
+        uint64_t m_LastRowStartingAddress;
     private:
         DECLARE_EVENT_TABLE()
 };
