@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 9263 $
- * $Id: recentitemslist.cpp 9263 2013-08-17 09:20:28Z mortenmacfly $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/src/recentitemslist.cpp $
+ * $Revision: 13119 $
+ * $Id: recentitemslist.cpp 13119 2022-12-15 11:24:09Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/src/recentitemslist.cpp $
  */
 
 
@@ -89,7 +89,6 @@ void RecentItemsList::AskToRemoveFileFromHistory(size_t id, bool cannot_open)
         query << question;
 
     AnnoyingDialog dialog(_("Remove file from list"), query, wxART_QUESTION);
-    PlaceWindow(&dialog);
     if (dialog.ShowModal() == AnnoyingDialog::rtYES)
     {
         m_list->RemoveFileFromHistory(id);
@@ -162,8 +161,7 @@ void RecentItemsList::BuildMenu(wxMenu *menu)
         menu->InsertSeparator(0);
         for (size_t i = 0; i < m_list->GetCount(); ++i)
         {
-            const wxString &name = wxString::Format(_T("&%lu "), static_cast<unsigned long>(i + 1))
-                                   + m_list->GetHistoryFile(i);
+            const wxString &name = wxString::Format("&%zu ", i + 1) + m_list->GetHistoryFile(i);
             menu->Insert(menu->GetMenuItemCount() - 2, m_firstMenuItemID + i, name);
         }
     }
@@ -192,7 +190,7 @@ wxMenu* RecentItemsList::GetMenu()
 void RecentItemsList::RefreshStartHerePage()
 {
     // update start here page
-    EditorBase* sh = Manager::Get()->GetEditorManager()->GetEditor(g_StartHereTitle);
+    EditorBase* sh = Manager::Get()->GetEditorManager()->GetEditor(GetStartHereTitle());
     if (sh)
         ((StartHerePage*)sh)->Reload();
 }
