@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 10927 $
- * $Id: mainframe.cpp 10927 2016-12-04 06:14:19Z mortenmacfly $
- * $HeadURL: svn://svn.code.sf.net/p/codeblocks/code/branches/release-20.xx/src/tools/cb_share_config/mainframe.cpp $
+ * $Revision: 13567 $
+ * $Id: mainframe.cpp 13567 2024-09-14 04:46:09Z mortenmacfly $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/tools/cb_share_config/mainframe.cpp $
  */
 
 #include "mainframe.h"
@@ -37,27 +37,27 @@
 //***********************************************************************
 
 //(*InternalHeaders(MainFrame)
-#include <wx/settings.h>
 #include <wx/intl.h>
+#include <wx/settings.h>
 #include <wx/string.h>
 //*)
 
 //(*IdInit(MainFrame)
-const long MainFrame::ID_LBL_STEPS = wxNewId();
-const long MainFrame::ID_LBL_FILE_SRC = wxNewId();
-const long MainFrame::ID_LBL_FILE_DST = wxNewId();
-const long MainFrame::ID_TXT_FILE_SRC = wxNewId();
-const long MainFrame::ID_BTN_FILE_SRC = wxNewId();
-const long MainFrame::ID_TXT_FILE_DST = wxNewId();
-const long MainFrame::ID_BTN_FILE_DST = wxNewId();
-const long MainFrame::ID_CFG_SRC = wxNewId();
-const long MainFrame::ID_LST_CFG = wxNewId();
-const long MainFrame::ID_BTN_TRANSFER = wxNewId();
-const long MainFrame::ID_BTN_UNCHECK = wxNewId();
-const long MainFrame::ID_BTN_EXPORT_ALL = wxNewId();
-const long MainFrame::ID_BTN_EXPORT = wxNewId();
-const long MainFrame::ID_BTN_SAVE = wxNewId();
-const long MainFrame::ID_BTN_CLOSE = wxNewId();
+const wxWindowID MainFrame::ID_LBL_STEPS = wxNewId();
+const wxWindowID MainFrame::ID_LBL_FILE_SRC = wxNewId();
+const wxWindowID MainFrame::ID_LBL_FILE_DST = wxNewId();
+const wxWindowID MainFrame::ID_TXT_FILE_SRC = wxNewId();
+const wxWindowID MainFrame::ID_BTN_FILE_SRC = wxNewId();
+const wxWindowID MainFrame::ID_TXT_FILE_DST = wxNewId();
+const wxWindowID MainFrame::ID_BTN_FILE_DST = wxNewId();
+const wxWindowID MainFrame::ID_CFG_SRC = wxNewId();
+const wxWindowID MainFrame::ID_LST_CFG = wxNewId();
+const wxWindowID MainFrame::ID_BTN_TRANSFER = wxNewId();
+const wxWindowID MainFrame::ID_BTN_UNCHECK = wxNewId();
+const wxWindowID MainFrame::ID_BTN_EXPORT_ALL = wxNewId();
+const wxWindowID MainFrame::ID_BTN_EXPORT = wxNewId();
+const wxWindowID MainFrame::ID_BTN_SAVE = wxNewId();
+const wxWindowID MainFrame::ID_BTN_CLOSE = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(MainFrame,wxFrame)
@@ -72,12 +72,12 @@ MainFrame::MainFrame(wxWindow* parent,wxWindowID id) :
   mFileDst(wxT("")), mCfgDst(0), mCfgDstValid(false), mNodesDst()
 {
 	//(*Initialize(MainFrame)
-	wxButton* btnSave;
 	wxButton* btnClose;
 	wxButton* btnExport;
 	wxButton* btnExportAll;
-	wxButton* btnUncheck;
+	wxButton* btnSave;
 	wxButton* btnTransfer;
+	wxButton* btnUncheck;
 
 	Create(parent, id, _("Welcome to Code::Blocks Share Config"), wxDefaultPosition, wxDefaultSize, wxCAPTION|wxDEFAULT_DIALOG_STYLE|wxSYSTEM_MENU|wxRESIZE_BORDER|wxCLOSE_BOX|wxMINIMIZE_BOX, _T("id"));
 	SetMinSize(wxSize(640,480));
@@ -100,7 +100,7 @@ MainFrame::MainFrame(wxWindow* parent,wxWindowID id) :
 	flsFileSrc->AddGrowableCol(0);
 	txtFileSrc = new wxTextCtrl(this, ID_TXT_FILE_SRC, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY, wxDefaultValidator, _T("ID_TXT_FILE_SRC"));
 	flsFileSrc->Add(txtFileSrc, 0, wxEXPAND, 0);
-	btnFileSrc = new wxButton(this, ID_BTN_FILE_SRC, _("..."), wxDefaultPosition, wxSize(32,-1), 0, wxDefaultValidator, _T("ID_BTN_FILE_SRC"));
+	btnFileSrc = new wxButton(this, ID_BTN_FILE_SRC, _T("..."), wxDefaultPosition, wxSize(32,-1), 0, wxDefaultValidator, _T("ID_BTN_FILE_SRC"));
 	btnFileSrc->SetToolTip(_("Select the source C::B configuration file."));
 	flsFileSrc->Add(btnFileSrc, 0, wxLEFT|wxALIGN_RIGHT|wxALIGN_TOP, 5);
 	grsFile->Add(flsFileSrc, 0, wxRIGHT|wxEXPAND, 5);
@@ -108,7 +108,7 @@ MainFrame::MainFrame(wxWindow* parent,wxWindowID id) :
 	flsFileDst->AddGrowableCol(0);
 	txtFileDst = new wxTextCtrl(this, ID_TXT_FILE_DST, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY, wxDefaultValidator, _T("ID_TXT_FILE_DST"));
 	flsFileDst->Add(txtFileDst, 0, wxEXPAND, 0);
-	btnFileDst = new wxButton(this, ID_BTN_FILE_DST, _("..."), wxDefaultPosition, wxSize(32,-1), 0, wxDefaultValidator, _T("ID_BTN_FILE_DST"));
+	btnFileDst = new wxButton(this, ID_BTN_FILE_DST, _T("..."), wxDefaultPosition, wxSize(32,-1), 0, wxDefaultValidator, _T("ID_BTN_FILE_DST"));
 	btnFileDst->SetToolTip(_("Select the destination C::B configuration file."));
 	flsFileDst->Add(btnFileDst, 0, wxLEFT|wxALIGN_RIGHT|wxALIGN_TOP, 5);
 	grsFile->Add(flsFileDst, 0, wxLEFT|wxEXPAND, 5);
@@ -135,14 +135,13 @@ MainFrame::MainFrame(wxWindow* parent,wxWindowID id) :
 	btnSave->SetToolTip(_("Save the selection on the right into the C::B destination config file."));
 	grsAction->Add(btnSave, 0, wxLEFT|wxALIGN_LEFT|wxALIGN_TOP, 5);
 	grsAction->Add(-1,-1,1, wxEXPAND, 0);
-	grsAction->Add(0,0,0, wxEXPAND, 0);
+	grsAction->Add(-1,-1,0, wxEXPAND, 0);
 	btnClose = new wxButton(this, ID_BTN_CLOSE, _("Close"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BTN_CLOSE"));
 	btnClose->SetToolTip(_("Close the application."));
 	grsAction->Add(btnClose, 0, wxALIGN_RIGHT|wxALIGN_TOP, 0);
 	bszMain->Add(grsAction, 0, wxLEFT|wxRIGHT|wxEXPAND, 5);
 	SetSizer(bszMain);
-	bszMain->Fit(this);
-	bszMain->SetSizeHints(this);
+	Fit();
 	Center();
 
 	Connect(ID_BTN_FILE_SRC,wxEVT_COMMAND_BUTTON_CLICKED,wxCommandEventHandler(MainFrame::OnBtnFileSrcClick));
@@ -223,9 +222,9 @@ void MainFrame::OnBtnTransferClick(wxCommandEvent& /*event*/)
     {
       // Set all (checked) variables of lstEnvVars
       int items_selected = 0;
-      for (unsigned int i = 0; i < clbCfgSrc->GetCount(); ++i)
+      for (unsigned int i=0; i<clbCfgSrc->GetCount(); ++i)
       {
-        if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size() > i))
+        if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size()>i))
         {
           items_selected++;
 
@@ -270,7 +269,7 @@ void MainFrame::OnBtnTransferClick(wxCommandEvent& /*event*/)
 
 void MainFrame::OnBtnUncheckClick(wxCommandEvent& /*event*/)
 {
-  for (unsigned int i=0; i < clbCfgSrc->GetCount(); ++i)
+  for (unsigned int i=0; i<clbCfgSrc->GetCount(); ++i)
     clbCfgSrc->Check(i, false);
 }// OnBtnUncheckClick
 
@@ -287,64 +286,24 @@ void MainFrame::OnBtnExportAllClick(wxCommandEvent& /*event*/)
                    "WARNING: Existing files in the target directory will be OVERWRITTEN."),
                wxT("Information"), wxICON_INFORMATION);
 
-  wxDirDialog dlg(this, wxT("Choose target directory"), wxEmptyString,
-                  wxDD_DEFAULT_STYLE | wxDD_DIR_MUST_EXIST);
-  if (wxID_OK != dlg.ShowModal())
-    return; // Cancel
-
-  wxString dirname = dlg.GetPath();
-  size_t   errors  = 0;
-
-  for (unsigned int i=0; i < clbCfgSrc->GetCount(); ++i)
+  bool items_selected = false;
+  for (unsigned int i=0; i<clbCfgSrc->GetCount(); ++i)
   {
-    TiXmlDocument* doc = new TiXmlDocument();
-    if (!doc)
+    if (clbCfgSrc->IsChecked(i))
     {
-      wxMessageBox(wxT("Cannot create empty XML document...?!"),
-                   wxT("Error"), wxICON_EXCLAMATION | wxOK);
-      return;
+      items_selected = true;
+      break;
     }
-
-    TiXmlDeclaration* decl = new TiXmlDeclaration("1.0", "UTF-8", "yes");
-    TiXmlElement*     root = new TiXmlElement("CodeBlocksConfig");
-    // NOTE (Morten#1#): This has to be in sync with C::B SDK (configmanager)!
-    root->SetAttribute("version", 1);
-
-    doc->LinkEndChild(decl);
-    doc->LinkEndChild(root);
-
-    if (mNodesSrc.size() <= i)
-      continue;
-
-    AttachNode(i, root);
-
-    wxString      path     = clbCfgSrc->GetString(i);
-    wxArrayString path_arr = PathToArray(path);
-    wxString filename = dirname
-                      + wxFileName::GetPathSeparator()
-                      + path_arr.Item(0);
-    for (size_t p=1; p<path_arr.GetCount(); p++)
-      filename += wxT("_") + path_arr.Item(p);
-    filename += wxT(".conf");
-    if (filename.IsEmpty())
-      continue;
-
-    if ( !TiXmlSaveDocument(filename, doc) )
-      errors++;
-
-    delete doc;
   }// for
 
-  if (errors)
+  if (items_selected)
   {
-    wxMessageBox(wxT("Could not save all backup configuration files."),
-                 wxT("Warning"), wxICON_EXCLAMATION | wxOK);
+    bool selected_only = (wxYES == wxMessageBox(wxT("DO you want to export only the selected nodes?"),
+                                                wxT("Question"), wxICON_QUESTION | wxYES_NO | wxNO_DEFAULT));
+    DoExport(selected_only);
   }
   else
-  {
-    wxMessageBox(wxT("Backup configuration files have been saved."),
-                 wxT("Information"), wxICON_INFORMATION | wxOK);
-  }
+    DoExport(false);
 }// OnBtnExportAllClick
 
 //***********************************************************************
@@ -377,9 +336,9 @@ void MainFrame::OnBtnExportClick(wxCommandEvent& /*event*/)
 
   // Save all (checked) variables of lstEnvVars
   int items_selected = 0;
-  for (unsigned int i=0; i < clbCfgSrc->GetCount(); ++i)
+  for (unsigned int i=0; i<clbCfgSrc->GetCount(); ++i)
   {
-    if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size() > i))
+    if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size()>i))
     {
       items_selected++;
       AttachNode(i, root);
@@ -905,6 +864,73 @@ void MainFrame::AttachNode(size_t idx, TiXmlElement* root)
 
 //***********************************************************************
 
+void MainFrame::DoExport(bool selected_only)
+{
+  wxDirDialog dlg(this, wxT("Choose target directory"), wxEmptyString,
+                  wxDD_DEFAULT_STYLE | wxDD_DIR_MUST_EXIST);
+  if (wxID_OK != dlg.ShowModal())
+    return; // Cancel
+
+  wxString dirname = dlg.GetPath();
+  size_t   errors  = 0;
+
+  for (unsigned int i=0; i<clbCfgSrc->GetCount(); ++i)
+  {
+    if (selected_only && !clbCfgSrc->IsChecked(i))
+      continue;
+
+    TiXmlDocument* doc = new TiXmlDocument();
+    if (!doc)
+    {
+      wxMessageBox(wxT("Cannot create empty XML document...?!"),
+                   wxT("Error"), wxICON_EXCLAMATION | wxOK);
+      return;
+    }
+
+    TiXmlDeclaration* decl = new TiXmlDeclaration("1.0", "UTF-8", "yes");
+    TiXmlElement*     root = new TiXmlElement("CodeBlocksConfig");
+    // NOTE (Morten#1#): This has to be in sync with C::B SDK (configmanager)!
+    root->SetAttribute("version", 1);
+
+    doc->LinkEndChild(decl);
+    doc->LinkEndChild(root);
+
+    if (mNodesSrc.size() <= i)
+      continue;
+
+    AttachNode(i, root);
+
+    wxString      path     = clbCfgSrc->GetString(i);
+    wxArrayString path_arr = PathToArray(path);
+    wxString filename = dirname
+                      + wxFileName::GetPathSeparator()
+                      + path_arr.Item(0);
+    for (size_t p=1; p<path_arr.GetCount(); p++)
+      filename += wxT("_") + path_arr.Item(p);
+    filename += wxT(".conf");
+    if (filename.IsEmpty())
+      continue;
+
+    if ( !TiXmlSaveDocument(filename, doc) )
+      errors++;
+
+    delete doc;
+  }// for
+
+  if (errors)
+  {
+    wxMessageBox(wxT("Could not save all backup configuration files."),
+                 wxT("Warning"), wxICON_EXCLAMATION | wxOK);
+  }
+  else
+  {
+    wxMessageBox(wxT("Backup configuration files have been saved."),
+                 wxT("Information"), wxICON_INFORMATION | wxOK);
+  }
+}// DoExport
+
+//***********************************************************************
+
 wxArrayString MainFrame::PathToArray(const wxString& path)
 {
   wxString      path_modifications = path;
