@@ -301,36 +301,56 @@ bool CCodeBlocksWorkspace::GenerateMakefile
         // targets
         CMakefileRule& rule_all = m_Makefile.AddRule("all",section);
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            rule_all.Dependencies().Insert(m_TargetNames[i]);
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+                rule_all.Dependencies().Insert(target_name);
         }
         section++;
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            CString makefile_path = m_MakefilePaths[i];
-            CMakefileRule& rule_target = m_Makefile.AddRule(m_TargetNames[i],section);
-            rule_target.Dependencies().Insert(m_TargetDeps[i]);
-            line = "$(MAKE)";
-            if (!makefile_path.IsEmpty()) {
-                line += " -C "+pl->ProtectPath(pl->Pd(makefile_path),Config.QuotePathMode());
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                CString makefile_path_ex = m_MakefilePaths[i];
+                CMakefileRule& rule_target = m_Makefile.AddRule(target_name,section);
+                rule_target.Dependencies().Insert(m_TargetDeps[i]);
+                line = "$(MAKE)";
+                if (!makefile_path_ex.IsEmpty()) {
+                    line += " -C "+pl->ProtectPath(pl->Pd(makefile_path_ex),Config.QuotePathMode());
+                }
+                line += " all -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
+                rule_target.Commands().Insert(line);
             }
-            line += " all -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
-            rule_target.Commands().Insert(line);
         }
         section++;
         //
         CMakefileRule& rule_clean = m_Makefile.AddRule("clean",section);
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            rule_clean.Dependencies().Insert("clean_"+m_TargetNames[i]);
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+                rule_clean.Dependencies().Insert("clean_"+target_name);
         }
         section++;
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            CString makefile_path = m_MakefilePaths[i];
-            CMakefileRule& rule_clean_target = m_Makefile.AddRule("clean_"+m_TargetNames[i],section);
-            line = "$(MAKE)";
-            if (!makefile_path.IsEmpty()) {
-                line += " -C "+pl->ProtectPath(pl->Pd(makefile_path),Config.QuotePathMode());
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                CString makefile_path_ex = m_MakefilePaths[i];
+                CMakefileRule& rule_clean_target = m_Makefile.AddRule("clean_"+target_selected,section);
+                line = "$(MAKE)";
+                if (!makefile_path_ex.IsEmpty()) {
+                    line += " -C "+pl->ProtectPath(pl->Pd(makefile_path_ex),Config.QuotePathMode());
+                }
+                line += " clean -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
+                rule_clean_target.Commands().Insert(line);
             }
-            line += " clean -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
-            rule_clean_target.Commands().Insert(line);
         }
         // save makefile
         CStringList& text = m_Makefile.Update();
@@ -415,46 +435,76 @@ void CCodeBlocksWorkspace::GenerateMakefileText(const CString& FileName,
         // targets
         line = "all:";
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            line.Append(" ").Append(m_TargetNames[i]);
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                line.Append(" ").Append(target_name);
+            }
         }
         m_MakefileText.Insert(line);
         m_MakefileText.Insert("");
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            CString makefile_path = m_MakefilePaths[i];
-            line = m_TargetNames[i]+":";
-            m_MakefileText.Insert(line);
-            line = "\t$(MAKE)";
-            if (!makefile_path.IsEmpty()) {
-                line += " -C "+pl->ProtectPath(pl->Pd(makefile_path),Config.QuotePathMode());
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                CString makefile_path_ex = m_MakefilePaths[i];
+                line = target_name+":";
+                m_MakefileText.Insert(line);
+                line = "\t$(MAKE)";
+                if (!makefile_path_ex.IsEmpty()) {
+                    line += " -C "+pl->ProtectPath(pl->Pd(makefile_path_ex),Config.QuotePathMode());
+                }
+                line += " all -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
+                m_MakefileText.Insert(line);
+                m_MakefileText.Insert("");
             }
-            line += " all -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
-            m_MakefileText.Insert(line);
-            m_MakefileText.Insert("");
         }
         //
         line = "clean:";
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            line.Append(" clean_").Append(m_TargetNames[i]);
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                line.Append(" clean_").Append(target_name);
+            }
         }
         m_MakefileText.Insert(line);
         m_MakefileText.Insert("");
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            CString makefile_path = m_MakefilePaths[i];
-            line = "clean_"+m_TargetNames[i]+":";
-            m_MakefileText.Insert(line);
-            line = "\t$(MAKE)";
-            if (!makefile_path.IsEmpty()) {
-                line += " -C "+pl->ProtectPath(pl->Pd(makefile_path),Config.QuotePathMode());
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                CString makefile_path_ex = m_MakefilePaths[i];
+                line = "clean_"+target_name+":";
+                m_MakefileText.Insert(line);
+                line = "\t$(MAKE)";
+                if (!makefile_path_ex.IsEmpty()) {
+                    line += " -C "+pl->ProtectPath(pl->Pd(makefile_path_ex),Config.QuotePathMode());
+                }
+                line += " clean -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
+                m_MakefileText.Insert(line);
+                m_MakefileText.Insert("");
             }
-            line += " clean -f "+pl->ProtectPath(pl->Pd(m_MakefileNames[i])+platform_suffix,Config.QuotePathMode());
-            m_MakefileText.Insert(line);
-            m_MakefileText.Insert("");
         }
         //
         line = ".PHONY:";
         for (int i = 0; i < m_TargetNames.GetCount(); i++) {
-            line.Append(" ").Append(m_TargetNames[i]);
-            line.Append(" clean_").Append(m_TargetNames[i]);
+            CString target_name = m_TargetNames[i];
+            bool target_selected = ((Config.Targets().GetCount()==0) ||
+                                    ((Config.Targets().GetCount()>0) && (Config.Targets().FindString(target_name)>=0)));
+            if (target_selected)
+            {
+                line.Append(" ").Append(target_name);
+                line.Append(" clean_").Append(target_name);
+            }
         }
         m_MakefileText.Insert(line);
         m_MakefileText.Insert("");
